/*
 * EBSD-Image
 * Copyright (C) 2010 Philippe T. Pinard
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.ebsdimage.io.exp.ops.indexing.op;

import static org.ebsdimage.io.exp.ops.indexing.op.KriegerLassen1994XmlTags.ATTR_MAX_INDEX;
import static org.ebsdimage.io.exp.ops.indexing.op.KriegerLassen1994XmlTags.ATTR_SCATTER_TYPE;
import static org.ebsdimage.io.exp.ops.indexing.op.KriegerLassen1994XmlTags.TAG_NAME;

import org.ebsdimage.core.exp.ops.indexing.op.KriegerLassen1994;
import org.jdom.Element;
import org.jdom.IllegalNameException;

import ptpshared.utility.xml.JDomUtil;
import ptpshared.utility.xml.ObjectXmlLoader;
import crystallography.core.ScatteringFactorsEnum;

/**
 * XML loader for a <code>KriegerLassen1994</code> operation.
 * 
 * @author Philippe T. Pinard
 */
public class KriegerLassen1994XmlLoader implements ObjectXmlLoader {

    /**
     * Loads a <code>KriegerLassen1994</code> operation from an XML
     * <code>Element</code>.
     * 
     * @param element
     *            an XML <code>Element</code>
     * @return a <code>KriegerLassen1994</code> operation
     * @throws IllegalNameException
     *             if the <code>Element</code> tag name is incorrect.
     */
    @Override
    public KriegerLassen1994 load(Element element) {
        if (!element.getName().equals(TAG_NAME))
            throw new IllegalNameException("Name of the element should be "
                    + TAG_NAME + " not " + element.getName() + ".");

        int maxIndex =
                JDomUtil.getIntegerFromAttribute(element, ATTR_MAX_INDEX,
                        KriegerLassen1994.DEFAULT_MAX_INDEX);

        ScatteringFactorsEnum scatterType =
                ScatteringFactorsEnum.valueOf(JDomUtil.getStringFromAttributeDefault(
                        element, ATTR_SCATTER_TYPE,
                        KriegerLassen1994.DEFAULT_SCATTER_TYPE.toString()));

        return new KriegerLassen1994(maxIndex, scatterType);
    }

}
