/*
 * EBSD-Image
 * Copyright (C) 2010 Philippe T. Pinard
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package crystallography.core;

import static crystallography.core.CrystalSystem.*;
import static crystallography.core.LaueGroup.*;
import static org.junit.Assert.assertEquals;

import org.junit.Test;

public class SpaceGroupsTest {

    @Test
    public void testFromIndex() {
        for (int i = 1; i <= 230; i++)
            assertEquals(i, SpaceGroups.fromIndex(i).index);
    }



    @Test
    public void testFromSymbol() {
        SpaceGroup sg;
        for (int i = 1; i <= 230; i++) {
            sg = SpaceGroups.fromIndex(i);
            assertEquals(i, SpaceGroups.fromSymbol(sg.symbol).index);
        }
    }



    @Test
    public void testListCrystalSystem() {
        assertEquals(2, SpaceGroups.list(TRICLINIC).length);
        assertEquals(13, SpaceGroups.list(MONOCLINIC).length);
        assertEquals(59, SpaceGroups.list(ORTHORHOMBIC).length);
        assertEquals(68, SpaceGroups.list(TETRAGONAL).length);
        assertEquals(32, SpaceGroups.list(TRIGONAL).length);
        assertEquals(27, SpaceGroups.list(HEXAGONAL).length);
        assertEquals(36, SpaceGroups.list(CUBIC).length);
    }



    @Test
    public void testListLaueGroup() {
        assertEquals(2, SpaceGroups.list(LG1).length);
        assertEquals(13, SpaceGroups.list(LG2m).length);
        assertEquals(59, SpaceGroups.list(LGmmm).length);
        assertEquals(14, SpaceGroups.list(LG4m).length);
        assertEquals(54, SpaceGroups.list(LG4mmm).length);
        assertEquals(8, SpaceGroups.list(LG3).length);
        assertEquals(24, SpaceGroups.list(LG3m).length);
        assertEquals(9, SpaceGroups.list(LG6m).length);
        assertEquals(18, SpaceGroups.list(LG6mmm).length);
        assertEquals(12, SpaceGroups.list(LGm3).length);
        assertEquals(24, SpaceGroups.list(LGm3m).length);
    }



    @Test
    public void testGenerators() {
        assertEquals(1, SpaceGroups.SG1.getGenerators().length);
        assertEquals(2, SpaceGroups.SG2.getGenerators().length);
        assertEquals(2, SpaceGroups.SG3.getGenerators().length);
        assertEquals(2, SpaceGroups.SG4.getGenerators().length);
        assertEquals(4, SpaceGroups.SG5.getGenerators().length);
        assertEquals(2, SpaceGroups.SG6.getGenerators().length);
        assertEquals(2, SpaceGroups.SG7.getGenerators().length);
        assertEquals(4, SpaceGroups.SG8.getGenerators().length);
        assertEquals(4, SpaceGroups.SG9.getGenerators().length);
        assertEquals(4, SpaceGroups.SG10.getGenerators().length);
        assertEquals(4, SpaceGroups.SG11.getGenerators().length);
        assertEquals(8, SpaceGroups.SG12.getGenerators().length);
        assertEquals(4, SpaceGroups.SG13.getGenerators().length);
        assertEquals(4, SpaceGroups.SG14.getGenerators().length);
        assertEquals(8, SpaceGroups.SG15.getGenerators().length);
        assertEquals(4, SpaceGroups.SG16.getGenerators().length);
        assertEquals(4, SpaceGroups.SG17.getGenerators().length);
        assertEquals(4, SpaceGroups.SG18.getGenerators().length);
        assertEquals(4, SpaceGroups.SG19.getGenerators().length);
        assertEquals(8, SpaceGroups.SG20.getGenerators().length);
        assertEquals(8, SpaceGroups.SG21.getGenerators().length);
        assertEquals(16, SpaceGroups.SG22.getGenerators().length);
        assertEquals(8, SpaceGroups.SG23.getGenerators().length);
        assertEquals(8, SpaceGroups.SG24.getGenerators().length);
        assertEquals(4, SpaceGroups.SG25.getGenerators().length);
        assertEquals(4, SpaceGroups.SG26.getGenerators().length);
        assertEquals(4, SpaceGroups.SG27.getGenerators().length);
        assertEquals(4, SpaceGroups.SG28.getGenerators().length);
        assertEquals(4, SpaceGroups.SG29.getGenerators().length);
        assertEquals(4, SpaceGroups.SG30.getGenerators().length);
        assertEquals(4, SpaceGroups.SG31.getGenerators().length);
        assertEquals(4, SpaceGroups.SG32.getGenerators().length);
        assertEquals(4, SpaceGroups.SG33.getGenerators().length);
        assertEquals(4, SpaceGroups.SG34.getGenerators().length);
        assertEquals(8, SpaceGroups.SG35.getGenerators().length);
        assertEquals(8, SpaceGroups.SG36.getGenerators().length);
        assertEquals(8, SpaceGroups.SG37.getGenerators().length);
        assertEquals(8, SpaceGroups.SG38.getGenerators().length);
        assertEquals(8, SpaceGroups.SG39.getGenerators().length);
        assertEquals(8, SpaceGroups.SG40.getGenerators().length);
        assertEquals(8, SpaceGroups.SG41.getGenerators().length);
        assertEquals(16, SpaceGroups.SG42.getGenerators().length);
        assertEquals(16, SpaceGroups.SG43.getGenerators().length);
        assertEquals(8, SpaceGroups.SG44.getGenerators().length);
        assertEquals(8, SpaceGroups.SG45.getGenerators().length);
        assertEquals(8, SpaceGroups.SG46.getGenerators().length);
        assertEquals(8, SpaceGroups.SG47.getGenerators().length);
        assertEquals(8, SpaceGroups.SG48.getGenerators().length);
        assertEquals(8, SpaceGroups.SG49.getGenerators().length);
        assertEquals(8, SpaceGroups.SG50.getGenerators().length);
        assertEquals(8, SpaceGroups.SG51.getGenerators().length);
        assertEquals(8, SpaceGroups.SG52.getGenerators().length);
        assertEquals(8, SpaceGroups.SG53.getGenerators().length);
        assertEquals(8, SpaceGroups.SG54.getGenerators().length);
        assertEquals(8, SpaceGroups.SG55.getGenerators().length);
        assertEquals(8, SpaceGroups.SG56.getGenerators().length);
        assertEquals(8, SpaceGroups.SG57.getGenerators().length);
        assertEquals(8, SpaceGroups.SG58.getGenerators().length);
        assertEquals(8, SpaceGroups.SG59.getGenerators().length);
        assertEquals(8, SpaceGroups.SG60.getGenerators().length);
        assertEquals(8, SpaceGroups.SG61.getGenerators().length);
        assertEquals(8, SpaceGroups.SG62.getGenerators().length);
        assertEquals(16, SpaceGroups.SG63.getGenerators().length);
        assertEquals(16, SpaceGroups.SG64.getGenerators().length);
        assertEquals(16, SpaceGroups.SG65.getGenerators().length);
        assertEquals(16, SpaceGroups.SG66.getGenerators().length);
        assertEquals(16, SpaceGroups.SG67.getGenerators().length);
        assertEquals(16, SpaceGroups.SG68.getGenerators().length);
        assertEquals(32, SpaceGroups.SG69.getGenerators().length);
        assertEquals(32, SpaceGroups.SG70.getGenerators().length);
        assertEquals(16, SpaceGroups.SG71.getGenerators().length);
        assertEquals(16, SpaceGroups.SG72.getGenerators().length);
        assertEquals(16, SpaceGroups.SG73.getGenerators().length);
        assertEquals(16, SpaceGroups.SG74.getGenerators().length);
        assertEquals(4, SpaceGroups.SG75.getGenerators().length);
        assertEquals(4, SpaceGroups.SG76.getGenerators().length);
        assertEquals(4, SpaceGroups.SG77.getGenerators().length);
        assertEquals(4, SpaceGroups.SG78.getGenerators().length);
        assertEquals(8, SpaceGroups.SG79.getGenerators().length);
        assertEquals(8, SpaceGroups.SG80.getGenerators().length);
        assertEquals(4, SpaceGroups.SG81.getGenerators().length);
        assertEquals(8, SpaceGroups.SG82.getGenerators().length);
        assertEquals(8, SpaceGroups.SG83.getGenerators().length);
        assertEquals(8, SpaceGroups.SG84.getGenerators().length);
        assertEquals(8, SpaceGroups.SG85.getGenerators().length);
        assertEquals(8, SpaceGroups.SG86.getGenerators().length);
        assertEquals(16, SpaceGroups.SG87.getGenerators().length);
        assertEquals(16, SpaceGroups.SG88.getGenerators().length);
        assertEquals(8, SpaceGroups.SG89.getGenerators().length);
        assertEquals(8, SpaceGroups.SG90.getGenerators().length);
        assertEquals(8, SpaceGroups.SG91.getGenerators().length);
        assertEquals(8, SpaceGroups.SG92.getGenerators().length);
        assertEquals(8, SpaceGroups.SG93.getGenerators().length);
        assertEquals(8, SpaceGroups.SG94.getGenerators().length);
        assertEquals(8, SpaceGroups.SG95.getGenerators().length);
        assertEquals(8, SpaceGroups.SG96.getGenerators().length);
        assertEquals(16, SpaceGroups.SG97.getGenerators().length);
        assertEquals(16, SpaceGroups.SG98.getGenerators().length);
        assertEquals(8, SpaceGroups.SG99.getGenerators().length);
        assertEquals(8, SpaceGroups.SG100.getGenerators().length);
        assertEquals(8, SpaceGroups.SG101.getGenerators().length);
        assertEquals(8, SpaceGroups.SG102.getGenerators().length);
        assertEquals(8, SpaceGroups.SG103.getGenerators().length);
        assertEquals(8, SpaceGroups.SG104.getGenerators().length);
        assertEquals(8, SpaceGroups.SG105.getGenerators().length);
        assertEquals(8, SpaceGroups.SG106.getGenerators().length);
        assertEquals(16, SpaceGroups.SG107.getGenerators().length);
        assertEquals(16, SpaceGroups.SG108.getGenerators().length);
        assertEquals(16, SpaceGroups.SG109.getGenerators().length);
        assertEquals(16, SpaceGroups.SG110.getGenerators().length);
        assertEquals(8, SpaceGroups.SG111.getGenerators().length);
        assertEquals(8, SpaceGroups.SG112.getGenerators().length);
        assertEquals(8, SpaceGroups.SG113.getGenerators().length);
        assertEquals(8, SpaceGroups.SG114.getGenerators().length);
        assertEquals(8, SpaceGroups.SG115.getGenerators().length);
        assertEquals(8, SpaceGroups.SG116.getGenerators().length);
        assertEquals(8, SpaceGroups.SG117.getGenerators().length);
        assertEquals(8, SpaceGroups.SG118.getGenerators().length);
        assertEquals(16, SpaceGroups.SG119.getGenerators().length);
        assertEquals(16, SpaceGroups.SG120.getGenerators().length);
        assertEquals(16, SpaceGroups.SG121.getGenerators().length);
        assertEquals(16, SpaceGroups.SG122.getGenerators().length);
        assertEquals(16, SpaceGroups.SG123.getGenerators().length);
        assertEquals(16, SpaceGroups.SG124.getGenerators().length);
        assertEquals(16, SpaceGroups.SG125.getGenerators().length);
        assertEquals(16, SpaceGroups.SG126.getGenerators().length);
        assertEquals(16, SpaceGroups.SG127.getGenerators().length);
        assertEquals(16, SpaceGroups.SG128.getGenerators().length);
        assertEquals(16, SpaceGroups.SG129.getGenerators().length);
        assertEquals(16, SpaceGroups.SG130.getGenerators().length);
        assertEquals(16, SpaceGroups.SG131.getGenerators().length);
        assertEquals(16, SpaceGroups.SG132.getGenerators().length);
        assertEquals(16, SpaceGroups.SG133.getGenerators().length);
        assertEquals(16, SpaceGroups.SG134.getGenerators().length);
        assertEquals(16, SpaceGroups.SG135.getGenerators().length);
        assertEquals(16, SpaceGroups.SG136.getGenerators().length);
        assertEquals(16, SpaceGroups.SG137.getGenerators().length);
        assertEquals(16, SpaceGroups.SG138.getGenerators().length);
        assertEquals(32, SpaceGroups.SG139.getGenerators().length);
        assertEquals(32, SpaceGroups.SG140.getGenerators().length);
        assertEquals(32, SpaceGroups.SG141.getGenerators().length);
        assertEquals(32, SpaceGroups.SG142.getGenerators().length);
        assertEquals(3, SpaceGroups.SG143.getGenerators().length);
        assertEquals(3, SpaceGroups.SG144.getGenerators().length);
        assertEquals(3, SpaceGroups.SG145.getGenerators().length);
        assertEquals(9, SpaceGroups.SG146.getGenerators().length);
        assertEquals(3, SpaceGroups.SG1146.getGenerators().length);
        assertEquals(6, SpaceGroups.SG147.getGenerators().length);
        assertEquals(18, SpaceGroups.SG148.getGenerators().length);
        assertEquals(6, SpaceGroups.SG1148.getGenerators().length);
        assertEquals(6, SpaceGroups.SG149.getGenerators().length);
        assertEquals(6, SpaceGroups.SG150.getGenerators().length);
        assertEquals(6, SpaceGroups.SG151.getGenerators().length);
        assertEquals(6, SpaceGroups.SG152.getGenerators().length);
        assertEquals(6, SpaceGroups.SG153.getGenerators().length);
        assertEquals(6, SpaceGroups.SG154.getGenerators().length);
        assertEquals(18, SpaceGroups.SG155.getGenerators().length);
        assertEquals(6, SpaceGroups.SG1155.getGenerators().length);
        assertEquals(6, SpaceGroups.SG156.getGenerators().length);
        assertEquals(6, SpaceGroups.SG157.getGenerators().length);
        assertEquals(6, SpaceGroups.SG158.getGenerators().length);
        assertEquals(6, SpaceGroups.SG159.getGenerators().length);
        assertEquals(18, SpaceGroups.SG160.getGenerators().length);
        assertEquals(6, SpaceGroups.SG1160.getGenerators().length);
        assertEquals(18, SpaceGroups.SG161.getGenerators().length);
        assertEquals(6, SpaceGroups.SG1161.getGenerators().length);
        assertEquals(12, SpaceGroups.SG162.getGenerators().length);
        assertEquals(12, SpaceGroups.SG163.getGenerators().length);
        assertEquals(12, SpaceGroups.SG164.getGenerators().length);
        assertEquals(12, SpaceGroups.SG165.getGenerators().length);
        assertEquals(36, SpaceGroups.SG166.getGenerators().length);
        assertEquals(12, SpaceGroups.SG1166.getGenerators().length);
        assertEquals(36, SpaceGroups.SG167.getGenerators().length);
        assertEquals(12, SpaceGroups.SG1167.getGenerators().length);
        assertEquals(6, SpaceGroups.SG168.getGenerators().length);
        assertEquals(6, SpaceGroups.SG169.getGenerators().length);
        assertEquals(6, SpaceGroups.SG170.getGenerators().length);
        assertEquals(6, SpaceGroups.SG171.getGenerators().length);
        assertEquals(6, SpaceGroups.SG172.getGenerators().length);
        assertEquals(6, SpaceGroups.SG173.getGenerators().length);
        assertEquals(6, SpaceGroups.SG174.getGenerators().length);
        assertEquals(12, SpaceGroups.SG175.getGenerators().length);
        assertEquals(12, SpaceGroups.SG176.getGenerators().length);
        assertEquals(12, SpaceGroups.SG177.getGenerators().length);
        assertEquals(12, SpaceGroups.SG178.getGenerators().length);
        assertEquals(12, SpaceGroups.SG179.getGenerators().length);
        assertEquals(12, SpaceGroups.SG180.getGenerators().length);
        assertEquals(12, SpaceGroups.SG181.getGenerators().length);
        assertEquals(12, SpaceGroups.SG182.getGenerators().length);
        assertEquals(12, SpaceGroups.SG183.getGenerators().length);
        assertEquals(12, SpaceGroups.SG184.getGenerators().length);
        assertEquals(12, SpaceGroups.SG185.getGenerators().length);
        assertEquals(12, SpaceGroups.SG186.getGenerators().length);
        assertEquals(12, SpaceGroups.SG187.getGenerators().length);
        assertEquals(12, SpaceGroups.SG188.getGenerators().length);
        assertEquals(12, SpaceGroups.SG189.getGenerators().length);
        assertEquals(12, SpaceGroups.SG190.getGenerators().length);
        assertEquals(24, SpaceGroups.SG191.getGenerators().length);
        assertEquals(24, SpaceGroups.SG192.getGenerators().length);
        assertEquals(24, SpaceGroups.SG193.getGenerators().length);
        assertEquals(24, SpaceGroups.SG194.getGenerators().length);
        assertEquals(12, SpaceGroups.SG195.getGenerators().length);
        assertEquals(48, SpaceGroups.SG196.getGenerators().length);
        assertEquals(24, SpaceGroups.SG197.getGenerators().length);
        assertEquals(12, SpaceGroups.SG198.getGenerators().length);
        assertEquals(24, SpaceGroups.SG199.getGenerators().length);
        assertEquals(24, SpaceGroups.SG200.getGenerators().length);
        assertEquals(24, SpaceGroups.SG201.getGenerators().length);
        assertEquals(96, SpaceGroups.SG202.getGenerators().length);
        assertEquals(96, SpaceGroups.SG203.getGenerators().length);
        assertEquals(48, SpaceGroups.SG204.getGenerators().length);
        assertEquals(24, SpaceGroups.SG205.getGenerators().length);
        assertEquals(48, SpaceGroups.SG206.getGenerators().length);
        assertEquals(24, SpaceGroups.SG207.getGenerators().length);
        assertEquals(24, SpaceGroups.SG208.getGenerators().length);
        assertEquals(96, SpaceGroups.SG209.getGenerators().length);
        assertEquals(96, SpaceGroups.SG210.getGenerators().length);
        assertEquals(48, SpaceGroups.SG211.getGenerators().length);
        assertEquals(24, SpaceGroups.SG212.getGenerators().length);
        assertEquals(24, SpaceGroups.SG213.getGenerators().length);
        assertEquals(48, SpaceGroups.SG214.getGenerators().length);
        assertEquals(24, SpaceGroups.SG215.getGenerators().length);
        assertEquals(96, SpaceGroups.SG216.getGenerators().length);
        assertEquals(48, SpaceGroups.SG217.getGenerators().length);
        assertEquals(24, SpaceGroups.SG218.getGenerators().length);
        assertEquals(96, SpaceGroups.SG219.getGenerators().length);
        assertEquals(48, SpaceGroups.SG220.getGenerators().length);
        assertEquals(48, SpaceGroups.SG221.getGenerators().length);
        assertEquals(48, SpaceGroups.SG222.getGenerators().length);
        assertEquals(48, SpaceGroups.SG223.getGenerators().length);
        assertEquals(48, SpaceGroups.SG224.getGenerators().length);
        assertEquals(192, SpaceGroups.SG225.getGenerators().length);
        assertEquals(192, SpaceGroups.SG226.getGenerators().length);
        assertEquals(192, SpaceGroups.SG227.getGenerators().length);
        assertEquals(192, SpaceGroups.SG228.getGenerators().length);
        assertEquals(96, SpaceGroups.SG229.getGenerators().length);
        assertEquals(96, SpaceGroups.SG230.getGenerators().length);
    }



    @Test
    public void testSymbol() {
        assertEquals("P1", SpaceGroups.SG1.symbol);
        assertEquals("P-1", SpaceGroups.SG2.symbol);
        assertEquals("P2", SpaceGroups.SG3.symbol);
        assertEquals("P21", SpaceGroups.SG4.symbol);
        assertEquals("C2", SpaceGroups.SG5.symbol);
        assertEquals("Pm", SpaceGroups.SG6.symbol);
        assertEquals("Pc", SpaceGroups.SG7.symbol);
        assertEquals("Cm", SpaceGroups.SG8.symbol);
        assertEquals("Cc", SpaceGroups.SG9.symbol);
        assertEquals("P2/m", SpaceGroups.SG10.symbol);
        assertEquals("P21/m", SpaceGroups.SG11.symbol);
        assertEquals("C2/m", SpaceGroups.SG12.symbol);
        assertEquals("P2/c", SpaceGroups.SG13.symbol);
        assertEquals("P21/c", SpaceGroups.SG14.symbol);
        assertEquals("C2/c", SpaceGroups.SG15.symbol);
        assertEquals("P222", SpaceGroups.SG16.symbol);
        assertEquals("P2221", SpaceGroups.SG17.symbol);
        assertEquals("P21212", SpaceGroups.SG18.symbol);
        assertEquals("P212121", SpaceGroups.SG19.symbol);
        assertEquals("C2221", SpaceGroups.SG20.symbol);
        assertEquals("C222", SpaceGroups.SG21.symbol);
        assertEquals("F222", SpaceGroups.SG22.symbol);
        assertEquals("I222", SpaceGroups.SG23.symbol);
        assertEquals("I212121", SpaceGroups.SG24.symbol);
        assertEquals("Pmm2", SpaceGroups.SG25.symbol);
        assertEquals("Pmc21", SpaceGroups.SG26.symbol);
        assertEquals("Pcc2", SpaceGroups.SG27.symbol);
        assertEquals("Pma2", SpaceGroups.SG28.symbol);
        assertEquals("Pca21", SpaceGroups.SG29.symbol);
        assertEquals("Pnc2", SpaceGroups.SG30.symbol);
        assertEquals("Pmn21", SpaceGroups.SG31.symbol);
        assertEquals("Pba2", SpaceGroups.SG32.symbol);
        assertEquals("Pna21", SpaceGroups.SG33.symbol);
        assertEquals("Pnn2", SpaceGroups.SG34.symbol);
        assertEquals("Cmm2", SpaceGroups.SG35.symbol);
        assertEquals("Cmc21", SpaceGroups.SG36.symbol);
        assertEquals("Ccc2", SpaceGroups.SG37.symbol);
        assertEquals("Amm2", SpaceGroups.SG38.symbol);
        assertEquals("Abm2", SpaceGroups.SG39.symbol);
        assertEquals("Ama2", SpaceGroups.SG40.symbol);
        assertEquals("Aba2", SpaceGroups.SG41.symbol);
        assertEquals("Fmm2", SpaceGroups.SG42.symbol);
        assertEquals("Fdd2", SpaceGroups.SG43.symbol);
        assertEquals("Imm2", SpaceGroups.SG44.symbol);
        assertEquals("Iba2", SpaceGroups.SG45.symbol);
        assertEquals("Ima2", SpaceGroups.SG46.symbol);
        assertEquals("Pmmm", SpaceGroups.SG47.symbol);
        assertEquals("Pnnn", SpaceGroups.SG48.symbol);
        assertEquals("Pccm", SpaceGroups.SG49.symbol);
        assertEquals("Pban", SpaceGroups.SG50.symbol);
        assertEquals("Pmma", SpaceGroups.SG51.symbol);
        assertEquals("Pnna", SpaceGroups.SG52.symbol);
        assertEquals("Pmna", SpaceGroups.SG53.symbol);
        assertEquals("Pcca", SpaceGroups.SG54.symbol);
        assertEquals("Pbam", SpaceGroups.SG55.symbol);
        assertEquals("Pccn", SpaceGroups.SG56.symbol);
        assertEquals("Pbcm", SpaceGroups.SG57.symbol);
        assertEquals("Pnnm", SpaceGroups.SG58.symbol);
        assertEquals("Pmmn", SpaceGroups.SG59.symbol);
        assertEquals("Pbcn", SpaceGroups.SG60.symbol);
        assertEquals("Pbca", SpaceGroups.SG61.symbol);
        assertEquals("Pnma", SpaceGroups.SG62.symbol);
        assertEquals("Cmcm", SpaceGroups.SG63.symbol);
        assertEquals("Cmca", SpaceGroups.SG64.symbol);
        assertEquals("Cmmm", SpaceGroups.SG65.symbol);
        assertEquals("Cccm", SpaceGroups.SG66.symbol);
        assertEquals("Cmma", SpaceGroups.SG67.symbol);
        assertEquals("Ccca", SpaceGroups.SG68.symbol);
        assertEquals("Fmmm", SpaceGroups.SG69.symbol);
        assertEquals("Fddd", SpaceGroups.SG70.symbol);
        assertEquals("Immm", SpaceGroups.SG71.symbol);
        assertEquals("Ibam", SpaceGroups.SG72.symbol);
        assertEquals("Ibca", SpaceGroups.SG73.symbol);
        assertEquals("Imma", SpaceGroups.SG74.symbol);
        assertEquals("P4", SpaceGroups.SG75.symbol);
        assertEquals("P41", SpaceGroups.SG76.symbol);
        assertEquals("P42", SpaceGroups.SG77.symbol);
        assertEquals("P43", SpaceGroups.SG78.symbol);
        assertEquals("I4", SpaceGroups.SG79.symbol);
        assertEquals("I41", SpaceGroups.SG80.symbol);
        assertEquals("P-4", SpaceGroups.SG81.symbol);
        assertEquals("I-4", SpaceGroups.SG82.symbol);
        assertEquals("P4/m", SpaceGroups.SG83.symbol);
        assertEquals("P42/m", SpaceGroups.SG84.symbol);
        assertEquals("P4/n", SpaceGroups.SG85.symbol);
        assertEquals("P42/n", SpaceGroups.SG86.symbol);
        assertEquals("I4/m", SpaceGroups.SG87.symbol);
        assertEquals("I41/a", SpaceGroups.SG88.symbol);
        assertEquals("P422", SpaceGroups.SG89.symbol);
        assertEquals("P4212", SpaceGroups.SG90.symbol);
        assertEquals("P4122", SpaceGroups.SG91.symbol);
        assertEquals("P41212", SpaceGroups.SG92.symbol);
        assertEquals("P4222", SpaceGroups.SG93.symbol);
        assertEquals("P42212", SpaceGroups.SG94.symbol);
        assertEquals("P4322", SpaceGroups.SG95.symbol);
        assertEquals("P43212", SpaceGroups.SG96.symbol);
        assertEquals("I422", SpaceGroups.SG97.symbol);
        assertEquals("I4122", SpaceGroups.SG98.symbol);
        assertEquals("P4mm", SpaceGroups.SG99.symbol);
        assertEquals("P4bm", SpaceGroups.SG100.symbol);
        assertEquals("P42cm", SpaceGroups.SG101.symbol);
        assertEquals("P42nm", SpaceGroups.SG102.symbol);
        assertEquals("P4cc", SpaceGroups.SG103.symbol);
        assertEquals("P4nc", SpaceGroups.SG104.symbol);
        assertEquals("P42mc", SpaceGroups.SG105.symbol);
        assertEquals("P42bc", SpaceGroups.SG106.symbol);
        assertEquals("I4mm", SpaceGroups.SG107.symbol);
        assertEquals("I4cm", SpaceGroups.SG108.symbol);
        assertEquals("I41md", SpaceGroups.SG109.symbol);
        assertEquals("I41cd", SpaceGroups.SG110.symbol);
        assertEquals("P-42m", SpaceGroups.SG111.symbol);
        assertEquals("P-42c", SpaceGroups.SG112.symbol);
        assertEquals("P-421m", SpaceGroups.SG113.symbol);
        assertEquals("P-421c", SpaceGroups.SG114.symbol);
        assertEquals("P-4m2", SpaceGroups.SG115.symbol);
        assertEquals("P-4c2", SpaceGroups.SG116.symbol);
        assertEquals("P-4b2", SpaceGroups.SG117.symbol);
        assertEquals("P-4n2", SpaceGroups.SG118.symbol);
        assertEquals("I-4m2", SpaceGroups.SG119.symbol);
        assertEquals("I-4c2", SpaceGroups.SG120.symbol);
        assertEquals("I-42m", SpaceGroups.SG121.symbol);
        assertEquals("I-42d", SpaceGroups.SG122.symbol);
        assertEquals("P4/mmm", SpaceGroups.SG123.symbol);
        assertEquals("P4/mcc", SpaceGroups.SG124.symbol);
        assertEquals("P4/nbm", SpaceGroups.SG125.symbol);
        assertEquals("P4/nnc", SpaceGroups.SG126.symbol);
        assertEquals("P4/mbm", SpaceGroups.SG127.symbol);
        assertEquals("P4/mnc", SpaceGroups.SG128.symbol);
        assertEquals("P4/nmm", SpaceGroups.SG129.symbol);
        assertEquals("P4/ncc", SpaceGroups.SG130.symbol);
        assertEquals("P42/mmc", SpaceGroups.SG131.symbol);
        assertEquals("P42/mcm", SpaceGroups.SG132.symbol);
        assertEquals("P42/nbc", SpaceGroups.SG133.symbol);
        assertEquals("P42/nnm", SpaceGroups.SG134.symbol);
        assertEquals("P42/mbc", SpaceGroups.SG135.symbol);
        assertEquals("P42/mnm", SpaceGroups.SG136.symbol);
        assertEquals("P42/nmc", SpaceGroups.SG137.symbol);
        assertEquals("P42/ncm", SpaceGroups.SG138.symbol);
        assertEquals("I4/mmm", SpaceGroups.SG139.symbol);
        assertEquals("I4/mcm", SpaceGroups.SG140.symbol);
        assertEquals("I41/amd", SpaceGroups.SG141.symbol);
        assertEquals("I41/acd", SpaceGroups.SG142.symbol);
        assertEquals("P3", SpaceGroups.SG143.symbol);
        assertEquals("P31", SpaceGroups.SG144.symbol);
        assertEquals("P32", SpaceGroups.SG145.symbol);
        assertEquals("H3", SpaceGroups.SG146.symbol);
        assertEquals("R3", SpaceGroups.SG1146.symbol);
        assertEquals("P-3", SpaceGroups.SG147.symbol);
        assertEquals("H-3", SpaceGroups.SG148.symbol);
        assertEquals("R-3", SpaceGroups.SG1148.symbol);
        assertEquals("P312", SpaceGroups.SG149.symbol);
        assertEquals("P321", SpaceGroups.SG150.symbol);
        assertEquals("P3112", SpaceGroups.SG151.symbol);
        assertEquals("P3121", SpaceGroups.SG152.symbol);
        assertEquals("P3212", SpaceGroups.SG153.symbol);
        assertEquals("P3221", SpaceGroups.SG154.symbol);
        assertEquals("H32", SpaceGroups.SG155.symbol);
        assertEquals("R32", SpaceGroups.SG1155.symbol);
        assertEquals("P3m1", SpaceGroups.SG156.symbol);
        assertEquals("P31m", SpaceGroups.SG157.symbol);
        assertEquals("P3c1", SpaceGroups.SG158.symbol);
        assertEquals("P31c", SpaceGroups.SG159.symbol);
        assertEquals("H3m", SpaceGroups.SG160.symbol);
        assertEquals("R3m", SpaceGroups.SG1160.symbol);
        assertEquals("H3c", SpaceGroups.SG161.symbol);
        assertEquals("R3c", SpaceGroups.SG1161.symbol);
        assertEquals("P-31m", SpaceGroups.SG162.symbol);
        assertEquals("P-31c", SpaceGroups.SG163.symbol);
        assertEquals("P-3m1", SpaceGroups.SG164.symbol);
        assertEquals("P-3c1", SpaceGroups.SG165.symbol);
        assertEquals("H-3m", SpaceGroups.SG166.symbol);
        assertEquals("R-3m", SpaceGroups.SG1166.symbol);
        assertEquals("H-3c", SpaceGroups.SG167.symbol);
        assertEquals("R-3c", SpaceGroups.SG1167.symbol);
        assertEquals("P6", SpaceGroups.SG168.symbol);
        assertEquals("P61", SpaceGroups.SG169.symbol);
        assertEquals("P65", SpaceGroups.SG170.symbol);
        assertEquals("P62", SpaceGroups.SG171.symbol);
        assertEquals("P64", SpaceGroups.SG172.symbol);
        assertEquals("P63", SpaceGroups.SG173.symbol);
        assertEquals("P-6", SpaceGroups.SG174.symbol);
        assertEquals("P6/m", SpaceGroups.SG175.symbol);
        assertEquals("P63/m", SpaceGroups.SG176.symbol);
        assertEquals("P622", SpaceGroups.SG177.symbol);
        assertEquals("P6122", SpaceGroups.SG178.symbol);
        assertEquals("P6522", SpaceGroups.SG179.symbol);
        assertEquals("P6222", SpaceGroups.SG180.symbol);
        assertEquals("P6422", SpaceGroups.SG181.symbol);
        assertEquals("P6322", SpaceGroups.SG182.symbol);
        assertEquals("P6mm", SpaceGroups.SG183.symbol);
        assertEquals("P6cc", SpaceGroups.SG184.symbol);
        assertEquals("P63cm", SpaceGroups.SG185.symbol);
        assertEquals("P63mc", SpaceGroups.SG186.symbol);
        assertEquals("P-6m2", SpaceGroups.SG187.symbol);
        assertEquals("P-6c2", SpaceGroups.SG188.symbol);
        assertEquals("P-62m", SpaceGroups.SG189.symbol);
        assertEquals("P-62c", SpaceGroups.SG190.symbol);
        assertEquals("P6/mmm", SpaceGroups.SG191.symbol);
        assertEquals("P6/mcc", SpaceGroups.SG192.symbol);
        assertEquals("P63/mcm", SpaceGroups.SG193.symbol);
        assertEquals("P63/mmc", SpaceGroups.SG194.symbol);
        assertEquals("P23", SpaceGroups.SG195.symbol);
        assertEquals("F23", SpaceGroups.SG196.symbol);
        assertEquals("I23", SpaceGroups.SG197.symbol);
        assertEquals("P213", SpaceGroups.SG198.symbol);
        assertEquals("I213", SpaceGroups.SG199.symbol);
        assertEquals("Pm-3", SpaceGroups.SG200.symbol);
        assertEquals("Pn-3", SpaceGroups.SG201.symbol);
        assertEquals("Fm-3", SpaceGroups.SG202.symbol);
        assertEquals("Fd-3", SpaceGroups.SG203.symbol);
        assertEquals("Im-3", SpaceGroups.SG204.symbol);
        assertEquals("Pa-3", SpaceGroups.SG205.symbol);
        assertEquals("Ia-3", SpaceGroups.SG206.symbol);
        assertEquals("P432", SpaceGroups.SG207.symbol);
        assertEquals("P4232", SpaceGroups.SG208.symbol);
        assertEquals("F432", SpaceGroups.SG209.symbol);
        assertEquals("F4132", SpaceGroups.SG210.symbol);
        assertEquals("I432", SpaceGroups.SG211.symbol);
        assertEquals("P4332", SpaceGroups.SG212.symbol);
        assertEquals("P4132", SpaceGroups.SG213.symbol);
        assertEquals("I4132", SpaceGroups.SG214.symbol);
        assertEquals("P-43m", SpaceGroups.SG215.symbol);
        assertEquals("F-43m", SpaceGroups.SG216.symbol);
        assertEquals("I-43m", SpaceGroups.SG217.symbol);
        assertEquals("P-43n", SpaceGroups.SG218.symbol);
        assertEquals("F-43c", SpaceGroups.SG219.symbol);
        assertEquals("I-43d", SpaceGroups.SG220.symbol);
        assertEquals("Pm-3m", SpaceGroups.SG221.symbol);
        assertEquals("Pn-3n", SpaceGroups.SG222.symbol);
        assertEquals("Pm-3n", SpaceGroups.SG223.symbol);
        assertEquals("Pn-3m", SpaceGroups.SG224.symbol);
        assertEquals("Fm-3m", SpaceGroups.SG225.symbol);
        assertEquals("Fm-3c", SpaceGroups.SG226.symbol);
        assertEquals("Fd-3m", SpaceGroups.SG227.symbol);
        assertEquals("Fd-3c", SpaceGroups.SG228.symbol);
        assertEquals("Im-3m", SpaceGroups.SG229.symbol);
        assertEquals("Ia-3d", SpaceGroups.SG230.symbol);
    }



    @Test
    public void testCrystalSystem() {
        assertEquals(TRICLINIC, SpaceGroups.SG1.crystalSystem);
        assertEquals(TRICLINIC, SpaceGroups.SG2.crystalSystem);
        assertEquals(MONOCLINIC, SpaceGroups.SG3.crystalSystem);
        assertEquals(MONOCLINIC, SpaceGroups.SG4.crystalSystem);
        assertEquals(MONOCLINIC, SpaceGroups.SG5.crystalSystem);
        assertEquals(MONOCLINIC, SpaceGroups.SG6.crystalSystem);
        assertEquals(MONOCLINIC, SpaceGroups.SG7.crystalSystem);
        assertEquals(MONOCLINIC, SpaceGroups.SG8.crystalSystem);
        assertEquals(MONOCLINIC, SpaceGroups.SG9.crystalSystem);
        assertEquals(MONOCLINIC, SpaceGroups.SG10.crystalSystem);
        assertEquals(MONOCLINIC, SpaceGroups.SG11.crystalSystem);
        assertEquals(MONOCLINIC, SpaceGroups.SG12.crystalSystem);
        assertEquals(MONOCLINIC, SpaceGroups.SG13.crystalSystem);
        assertEquals(MONOCLINIC, SpaceGroups.SG14.crystalSystem);
        assertEquals(MONOCLINIC, SpaceGroups.SG15.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG16.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG17.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG18.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG19.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG20.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG21.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG22.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG23.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG24.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG25.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG26.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG27.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG28.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG29.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG30.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG31.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG32.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG33.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG34.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG35.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG36.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG37.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG38.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG39.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG40.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG41.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG42.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG43.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG44.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG45.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG46.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG47.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG48.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG49.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG50.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG51.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG52.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG53.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG54.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG55.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG56.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG57.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG58.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG59.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG60.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG61.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG62.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG63.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG64.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG65.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG66.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG67.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG68.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG69.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG70.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG71.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG72.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG73.crystalSystem);
        assertEquals(ORTHORHOMBIC, SpaceGroups.SG74.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG75.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG76.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG77.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG78.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG79.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG80.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG81.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG82.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG83.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG84.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG85.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG86.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG87.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG88.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG89.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG90.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG91.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG92.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG93.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG94.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG95.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG96.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG97.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG98.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG99.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG100.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG101.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG102.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG103.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG104.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG105.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG106.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG107.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG108.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG109.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG110.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG111.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG112.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG113.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG114.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG115.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG116.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG117.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG118.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG119.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG120.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG121.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG122.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG123.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG124.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG125.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG126.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG127.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG128.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG129.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG130.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG131.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG132.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG133.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG134.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG135.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG136.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG137.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG138.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG139.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG140.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG141.crystalSystem);
        assertEquals(TETRAGONAL, SpaceGroups.SG142.crystalSystem);
        assertEquals(TRIGONAL, SpaceGroups.SG143.crystalSystem);
        assertEquals(TRIGONAL, SpaceGroups.SG144.crystalSystem);
        assertEquals(TRIGONAL, SpaceGroups.SG145.crystalSystem);
        assertEquals(TRIGONAL, SpaceGroups.SG146.crystalSystem);
        assertEquals(TRIGONAL, SpaceGroups.SG1146.crystalSystem);
        assertEquals(TRIGONAL, SpaceGroups.SG147.crystalSystem);
        assertEquals(TRIGONAL, SpaceGroups.SG148.crystalSystem);
        assertEquals(TRIGONAL, SpaceGroups.SG1148.crystalSystem);
        assertEquals(TRIGONAL, SpaceGroups.SG149.crystalSystem);
        assertEquals(TRIGONAL, SpaceGroups.SG150.crystalSystem);
        assertEquals(TRIGONAL, SpaceGroups.SG151.crystalSystem);
        assertEquals(TRIGONAL, SpaceGroups.SG152.crystalSystem);
        assertEquals(TRIGONAL, SpaceGroups.SG153.crystalSystem);
        assertEquals(TRIGONAL, SpaceGroups.SG154.crystalSystem);
        assertEquals(TRIGONAL, SpaceGroups.SG155.crystalSystem);
        assertEquals(TRIGONAL, SpaceGroups.SG1155.crystalSystem);
        assertEquals(TRIGONAL, SpaceGroups.SG156.crystalSystem);
        assertEquals(TRIGONAL, SpaceGroups.SG157.crystalSystem);
        assertEquals(TRIGONAL, SpaceGroups.SG158.crystalSystem);
        assertEquals(TRIGONAL, SpaceGroups.SG159.crystalSystem);
        assertEquals(TRIGONAL, SpaceGroups.SG160.crystalSystem);
        assertEquals(TRIGONAL, SpaceGroups.SG1160.crystalSystem);
        assertEquals(TRIGONAL, SpaceGroups.SG161.crystalSystem);
        assertEquals(TRIGONAL, SpaceGroups.SG1161.crystalSystem);
        assertEquals(TRIGONAL, SpaceGroups.SG162.crystalSystem);
        assertEquals(TRIGONAL, SpaceGroups.SG163.crystalSystem);
        assertEquals(TRIGONAL, SpaceGroups.SG164.crystalSystem);
        assertEquals(TRIGONAL, SpaceGroups.SG165.crystalSystem);
        assertEquals(TRIGONAL, SpaceGroups.SG166.crystalSystem);
        assertEquals(TRIGONAL, SpaceGroups.SG1166.crystalSystem);
        assertEquals(TRIGONAL, SpaceGroups.SG167.crystalSystem);
        assertEquals(TRIGONAL, SpaceGroups.SG1167.crystalSystem);
        assertEquals(HEXAGONAL, SpaceGroups.SG168.crystalSystem);
        assertEquals(HEXAGONAL, SpaceGroups.SG169.crystalSystem);
        assertEquals(HEXAGONAL, SpaceGroups.SG170.crystalSystem);
        assertEquals(HEXAGONAL, SpaceGroups.SG171.crystalSystem);
        assertEquals(HEXAGONAL, SpaceGroups.SG172.crystalSystem);
        assertEquals(HEXAGONAL, SpaceGroups.SG173.crystalSystem);
        assertEquals(HEXAGONAL, SpaceGroups.SG174.crystalSystem);
        assertEquals(HEXAGONAL, SpaceGroups.SG175.crystalSystem);
        assertEquals(HEXAGONAL, SpaceGroups.SG176.crystalSystem);
        assertEquals(HEXAGONAL, SpaceGroups.SG177.crystalSystem);
        assertEquals(HEXAGONAL, SpaceGroups.SG178.crystalSystem);
        assertEquals(HEXAGONAL, SpaceGroups.SG179.crystalSystem);
        assertEquals(HEXAGONAL, SpaceGroups.SG180.crystalSystem);
        assertEquals(HEXAGONAL, SpaceGroups.SG181.crystalSystem);
        assertEquals(HEXAGONAL, SpaceGroups.SG182.crystalSystem);
        assertEquals(HEXAGONAL, SpaceGroups.SG183.crystalSystem);
        assertEquals(HEXAGONAL, SpaceGroups.SG184.crystalSystem);
        assertEquals(HEXAGONAL, SpaceGroups.SG185.crystalSystem);
        assertEquals(HEXAGONAL, SpaceGroups.SG186.crystalSystem);
        assertEquals(HEXAGONAL, SpaceGroups.SG187.crystalSystem);
        assertEquals(HEXAGONAL, SpaceGroups.SG188.crystalSystem);
        assertEquals(HEXAGONAL, SpaceGroups.SG189.crystalSystem);
        assertEquals(HEXAGONAL, SpaceGroups.SG190.crystalSystem);
        assertEquals(HEXAGONAL, SpaceGroups.SG191.crystalSystem);
        assertEquals(HEXAGONAL, SpaceGroups.SG192.crystalSystem);
        assertEquals(HEXAGONAL, SpaceGroups.SG193.crystalSystem);
        assertEquals(HEXAGONAL, SpaceGroups.SG194.crystalSystem);
        assertEquals(CUBIC, SpaceGroups.SG195.crystalSystem);
        assertEquals(CUBIC, SpaceGroups.SG196.crystalSystem);
        assertEquals(CUBIC, SpaceGroups.SG197.crystalSystem);
        assertEquals(CUBIC, SpaceGroups.SG198.crystalSystem);
        assertEquals(CUBIC, SpaceGroups.SG199.crystalSystem);
        assertEquals(CUBIC, SpaceGroups.SG200.crystalSystem);
        assertEquals(CUBIC, SpaceGroups.SG201.crystalSystem);
        assertEquals(CUBIC, SpaceGroups.SG202.crystalSystem);
        assertEquals(CUBIC, SpaceGroups.SG203.crystalSystem);
        assertEquals(CUBIC, SpaceGroups.SG204.crystalSystem);
        assertEquals(CUBIC, SpaceGroups.SG205.crystalSystem);
        assertEquals(CUBIC, SpaceGroups.SG206.crystalSystem);
        assertEquals(CUBIC, SpaceGroups.SG207.crystalSystem);
        assertEquals(CUBIC, SpaceGroups.SG208.crystalSystem);
        assertEquals(CUBIC, SpaceGroups.SG209.crystalSystem);
        assertEquals(CUBIC, SpaceGroups.SG210.crystalSystem);
        assertEquals(CUBIC, SpaceGroups.SG211.crystalSystem);
        assertEquals(CUBIC, SpaceGroups.SG212.crystalSystem);
        assertEquals(CUBIC, SpaceGroups.SG213.crystalSystem);
        assertEquals(CUBIC, SpaceGroups.SG214.crystalSystem);
        assertEquals(CUBIC, SpaceGroups.SG215.crystalSystem);
        assertEquals(CUBIC, SpaceGroups.SG216.crystalSystem);
        assertEquals(CUBIC, SpaceGroups.SG217.crystalSystem);
        assertEquals(CUBIC, SpaceGroups.SG218.crystalSystem);
        assertEquals(CUBIC, SpaceGroups.SG219.crystalSystem);
        assertEquals(CUBIC, SpaceGroups.SG220.crystalSystem);
        assertEquals(CUBIC, SpaceGroups.SG221.crystalSystem);
        assertEquals(CUBIC, SpaceGroups.SG222.crystalSystem);
        assertEquals(CUBIC, SpaceGroups.SG223.crystalSystem);
        assertEquals(CUBIC, SpaceGroups.SG224.crystalSystem);
        assertEquals(CUBIC, SpaceGroups.SG225.crystalSystem);
        assertEquals(CUBIC, SpaceGroups.SG226.crystalSystem);
        assertEquals(CUBIC, SpaceGroups.SG227.crystalSystem);
        assertEquals(CUBIC, SpaceGroups.SG228.crystalSystem);
        assertEquals(CUBIC, SpaceGroups.SG229.crystalSystem);
        assertEquals(CUBIC, SpaceGroups.SG230.crystalSystem);
    }

}
