/*
 * EBSD-Image
 * Copyright (C) 2010 Philippe T. Pinard
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.ebsdimage.io.exp.ops.detection.pre;

import static org.ebsdimage.io.exp.ops.detection.pre.ButterflyXmlTags.ATTR_FLATTEN_LOWERLIMIT;
import static org.ebsdimage.io.exp.ops.detection.pre.ButterflyXmlTags.ATTR_FLATTEN_UPPERLIMIT;
import static org.ebsdimage.io.exp.ops.detection.pre.ButterflyXmlTags.ATTR_KERNELSIZE;
import static org.ebsdimage.io.exp.ops.detection.pre.ButterflyXmlTags.TAG_NAME;
import static org.junit.Assert.assertEquals;

import org.ebsdimage.core.exp.ops.detection.pre.Butterfly;
import org.jdom.Element;
import org.junit.Before;
import org.junit.Test;

public class ButterflyXmlLoaderTest {

    private Element element;



    @Before
    public void setUp() throws Exception {
        element = new Element(TAG_NAME);

        element.setAttribute(ATTR_KERNELSIZE, Integer.toString(9));
        element.setAttribute(ATTR_FLATTEN_LOWERLIMIT, Float.toString(-50.3f));
        element.setAttribute(ATTR_FLATTEN_UPPERLIMIT, Float.toString(50.3f));
    }



    @Test
    public void testLoad() {
        Butterfly op = new ButterflyXmlLoader().load(element);

        assertEquals(TAG_NAME, op.getName());
        assertEquals(9, op.kernelSize);
        assertEquals(-50.3, op.flattenLowerLimit, 1e-5);
        assertEquals(50.3, op.flattenUpperLimit, 1e-5);
    }

}
