/*
 * EBSD-Image
 * Copyright (C) 2010 Philippe T. Pinard
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package crystallography.core;

import static crystallography.core.Constants.*;
import static crystallography.core.CrystalSystem.CUBIC;
import static crystallography.core.CrystalSystem.HEXAGONAL;
import static crystallography.core.CrystalSystem.TETRAGONAL;
import static crystallography.core.CrystalSystem.TRIGONAL;
import static crystallography.core.LaueGroup.*;

/**
 * Second series of space group between 116 and 230. The space groups must be
 * split into two classes due to Java's limitation on the size of public static
 * final variables.
 * 
 * @author Dr. Ethan Merritt <merritt@u.washington.edu> of PyMMLib Development
 *         Group
 */
public interface SpaceGroups2 {
    /** Space group 116. */
    public static final SpaceGroup SG116 = new SpaceGroup(116, "P-4c2",
            TETRAGONAL, LG4mmm, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mY_X_mZ, TR_0_0_0),
                    new Generator(ROT_Y_mX_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_Z, TR_0_0_12),
                    new Generator(ROT_mX_Y_Z, TR_0_0_12),
                    new Generator(ROT_Y_X_mZ, TR_0_0_12),
                    new Generator(ROT_mY_mX_mZ, TR_0_0_12) });

    /** Space group 111. */
    public static final SpaceGroup SG117 = new SpaceGroup(117, "P-4b2",
            TETRAGONAL, LG4mmm, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mY_X_mZ, TR_0_0_0),
                    new Generator(ROT_Y_mX_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_Z, TR_12_12_0),
                    new Generator(ROT_mX_Y_Z, TR_12_12_0),
                    new Generator(ROT_Y_X_mZ, TR_12_12_0),
                    new Generator(ROT_mY_mX_mZ, TR_12_12_0) });

    /** Space group 118. */
    public static final SpaceGroup SG118 = new SpaceGroup(118, "P-4n2",
            TETRAGONAL, LG4mmm, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mY_X_mZ, TR_0_0_0),
                    new Generator(ROT_Y_mX_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_Z, TR_12_12_12),
                    new Generator(ROT_mX_Y_Z, TR_12_12_12),
                    new Generator(ROT_Y_X_mZ, TR_12_12_12),
                    new Generator(ROT_mY_mX_mZ, TR_12_12_12) });

    /** Space group 119. */
    public static final SpaceGroup SG119 = new SpaceGroup(119, "I-4m2",
            TETRAGONAL, LG4mmm, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mY_X_mZ, TR_0_0_0),
                    new Generator(ROT_Y_mX_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_Z, TR_0_0_0),
                    new Generator(ROT_mX_Y_Z, TR_0_0_0),
                    new Generator(ROT_Y_X_mZ, TR_0_0_0),
                    new Generator(ROT_mY_mX_mZ, TR_0_0_0),
                    new Generator(ROT_X_Y_Z, TR_12_12_12),
                    new Generator(ROT_mX_mY_Z, TR_12_12_12),
                    new Generator(ROT_mY_X_mZ, TR_12_12_12),
                    new Generator(ROT_Y_mX_mZ, TR_12_12_12),
                    new Generator(ROT_X_mY_Z, TR_12_12_12),
                    new Generator(ROT_mX_Y_Z, TR_12_12_12),
                    new Generator(ROT_Y_X_mZ, TR_12_12_12),
                    new Generator(ROT_mY_mX_mZ, TR_12_12_12) });

    /** Space group 120. */
    public static final SpaceGroup SG120 = new SpaceGroup(120, "I-4c2",
            TETRAGONAL, LG4mmm, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mY_X_mZ, TR_0_0_0),
                    new Generator(ROT_Y_mX_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_Z, TR_0_0_12),
                    new Generator(ROT_mX_Y_Z, TR_0_0_12),
                    new Generator(ROT_Y_X_mZ, TR_0_0_12),
                    new Generator(ROT_mY_mX_mZ, TR_0_0_12),
                    new Generator(ROT_X_Y_Z, TR_12_12_12),
                    new Generator(ROT_mX_mY_Z, TR_12_12_12),
                    new Generator(ROT_mY_X_mZ, TR_12_12_12),
                    new Generator(ROT_Y_mX_mZ, TR_12_12_12),
                    new Generator(ROT_X_mY_Z, TR_12_12_0),
                    new Generator(ROT_mX_Y_Z, TR_12_12_0),
                    new Generator(ROT_Y_X_mZ, TR_12_12_0),
                    new Generator(ROT_mY_mX_mZ, TR_12_12_0) });

    /** Space group 121. */
    public static final SpaceGroup SG121 = new SpaceGroup(121, "I-42m",
            TETRAGONAL, LG4mmm, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mY_X_mZ, TR_0_0_0),
                    new Generator(ROT_Y_mX_mZ, TR_0_0_0),
                    new Generator(ROT_mX_Y_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_mZ, TR_0_0_0),
                    new Generator(ROT_mY_mX_Z, TR_0_0_0),
                    new Generator(ROT_Y_X_Z, TR_0_0_0),
                    new Generator(ROT_X_Y_Z, TR_12_12_12),
                    new Generator(ROT_mX_mY_Z, TR_12_12_12),
                    new Generator(ROT_mY_X_mZ, TR_12_12_12),
                    new Generator(ROT_Y_mX_mZ, TR_12_12_12),
                    new Generator(ROT_mX_Y_mZ, TR_12_12_12),
                    new Generator(ROT_X_mY_mZ, TR_12_12_12),
                    new Generator(ROT_mY_mX_Z, TR_12_12_12),
                    new Generator(ROT_Y_X_Z, TR_12_12_12) });

    /** Space group 122. */
    public static final SpaceGroup SG122 = new SpaceGroup(122, "I-42d",
            TETRAGONAL, LG4mmm, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mY_X_mZ, TR_0_0_0),
                    new Generator(ROT_Y_mX_mZ, TR_0_0_0),
                    new Generator(ROT_mX_Y_mZ, TR_12_0_34),
                    new Generator(ROT_X_mY_mZ, TR_12_0_34),
                    new Generator(ROT_mY_mX_Z, TR_12_0_34),
                    new Generator(ROT_Y_X_Z, TR_12_0_34),
                    new Generator(ROT_X_Y_Z, TR_12_12_12),
                    new Generator(ROT_mX_mY_Z, TR_12_12_12),
                    new Generator(ROT_mY_X_mZ, TR_12_12_12),
                    new Generator(ROT_Y_mX_mZ, TR_12_12_12),
                    new Generator(ROT_mX_Y_mZ, TR_0_12_14),
                    new Generator(ROT_X_mY_mZ, TR_0_12_14),
                    new Generator(ROT_mY_mX_Z, TR_0_12_14),
                    new Generator(ROT_Y_X_Z, TR_0_12_14) });

    /** Space group 123. */
    public static final SpaceGroup SG123 = new SpaceGroup(123, "P4/mmm",
            TETRAGONAL, LG4mmm, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mY_X_Z, TR_0_0_0),
                    new Generator(ROT_Y_mX_Z, TR_0_0_0),
                    new Generator(ROT_mX_Y_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_mZ, TR_0_0_0),
                    new Generator(ROT_Y_X_mZ, TR_0_0_0),
                    new Generator(ROT_mY_mX_mZ, TR_0_0_0),
                    new Generator(ROT_mX_mY_mZ, TR_0_0_0),
                    new Generator(ROT_X_Y_mZ, TR_0_0_0),
                    new Generator(ROT_Y_mX_mZ, TR_0_0_0),
                    new Generator(ROT_mY_X_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_Z, TR_0_0_0),
                    new Generator(ROT_mX_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_mX_Z, TR_0_0_0),
                    new Generator(ROT_Y_X_Z, TR_0_0_0) });

    /** Space group 124. */
    public static final SpaceGroup SG124 = new SpaceGroup(124, "P4/mcc",
            TETRAGONAL, LG4mmm, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mY_X_Z, TR_0_0_0),
                    new Generator(ROT_Y_mX_Z, TR_0_0_0),
                    new Generator(ROT_mX_Y_mZ, TR_0_0_12),
                    new Generator(ROT_X_mY_mZ, TR_0_0_12),
                    new Generator(ROT_Y_X_mZ, TR_0_0_12),
                    new Generator(ROT_mY_mX_mZ, TR_0_0_12),
                    new Generator(ROT_mX_mY_mZ, TR_0_0_0),
                    new Generator(ROT_X_Y_mZ, TR_0_0_0),
                    new Generator(ROT_Y_mX_mZ, TR_0_0_0),
                    new Generator(ROT_mY_X_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_Z, TR_0_0_12),
                    new Generator(ROT_mX_Y_Z, TR_0_0_12),
                    new Generator(ROT_mY_mX_Z, TR_0_0_12),
                    new Generator(ROT_Y_X_Z, TR_0_0_12) });

    /** Space group 125. */
    public static final SpaceGroup SG125 = new SpaceGroup(125, "P4/nbm",
            TETRAGONAL, LG4mmm, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mY_X_Z, TR_0_0_0),
                    new Generator(ROT_Y_mX_Z, TR_0_0_0),
                    new Generator(ROT_mX_Y_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_mZ, TR_0_0_0),
                    new Generator(ROT_Y_X_mZ, TR_0_0_0),
                    new Generator(ROT_mY_mX_mZ, TR_0_0_0),
                    new Generator(ROT_mX_mY_mZ, TR_12_12_0),
                    new Generator(ROT_X_Y_mZ, TR_12_12_0),
                    new Generator(ROT_Y_mX_mZ, TR_12_12_0),
                    new Generator(ROT_mY_X_mZ, TR_12_12_0),
                    new Generator(ROT_X_mY_Z, TR_12_12_0),
                    new Generator(ROT_mX_Y_Z, TR_12_12_0),
                    new Generator(ROT_mY_mX_Z, TR_12_12_0),
                    new Generator(ROT_Y_X_Z, TR_12_12_0) });

    /** Space group 126. */
    public static final SpaceGroup SG126 = new SpaceGroup(126, "P4/nnc",
            TETRAGONAL, LG4mmm, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mY_X_Z, TR_0_0_0),
                    new Generator(ROT_Y_mX_Z, TR_0_0_0),
                    new Generator(ROT_mX_Y_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_mZ, TR_0_0_0),
                    new Generator(ROT_Y_X_mZ, TR_0_0_0),
                    new Generator(ROT_mY_mX_mZ, TR_0_0_0),
                    new Generator(ROT_mX_mY_mZ, TR_12_12_12),
                    new Generator(ROT_X_Y_mZ, TR_12_12_12),
                    new Generator(ROT_Y_mX_mZ, TR_12_12_12),
                    new Generator(ROT_mY_X_mZ, TR_12_12_12),
                    new Generator(ROT_X_mY_Z, TR_12_12_12),
                    new Generator(ROT_mX_Y_Z, TR_12_12_12),
                    new Generator(ROT_mY_mX_Z, TR_12_12_12),
                    new Generator(ROT_Y_X_Z, TR_12_12_12) });

    /** Space group 127. */
    public static final SpaceGroup SG127 = new SpaceGroup(127, "P4/mbm",
            TETRAGONAL, LG4mmm, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mY_X_Z, TR_0_0_0),
                    new Generator(ROT_Y_mX_Z, TR_0_0_0),
                    new Generator(ROT_mX_Y_mZ, TR_12_12_0),
                    new Generator(ROT_X_mY_mZ, TR_12_12_0),
                    new Generator(ROT_Y_X_mZ, TR_12_12_0),
                    new Generator(ROT_mY_mX_mZ, TR_12_12_0),
                    new Generator(ROT_mX_mY_mZ, TR_0_0_0),
                    new Generator(ROT_X_Y_mZ, TR_0_0_0),
                    new Generator(ROT_Y_mX_mZ, TR_0_0_0),
                    new Generator(ROT_mY_X_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_Z, TR_12_12_0),
                    new Generator(ROT_mX_Y_Z, TR_12_12_0),
                    new Generator(ROT_mY_mX_Z, TR_12_12_0),
                    new Generator(ROT_Y_X_Z, TR_12_12_0) });

    /** Space group 128. */
    public static final SpaceGroup SG128 = new SpaceGroup(128, "P4/mnc",
            TETRAGONAL, LG4mmm, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mY_X_Z, TR_0_0_0),
                    new Generator(ROT_Y_mX_Z, TR_0_0_0),
                    new Generator(ROT_mX_Y_mZ, TR_12_12_12),
                    new Generator(ROT_X_mY_mZ, TR_12_12_12),
                    new Generator(ROT_Y_X_mZ, TR_12_12_12),
                    new Generator(ROT_mY_mX_mZ, TR_12_12_12),
                    new Generator(ROT_mX_mY_mZ, TR_0_0_0),
                    new Generator(ROT_X_Y_mZ, TR_0_0_0),
                    new Generator(ROT_Y_mX_mZ, TR_0_0_0),
                    new Generator(ROT_mY_X_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_Z, TR_12_12_12),
                    new Generator(ROT_mX_Y_Z, TR_12_12_12),
                    new Generator(ROT_mY_mX_Z, TR_12_12_12),
                    new Generator(ROT_Y_X_Z, TR_12_12_12) });

    /** Space group 129. */
    public static final SpaceGroup SG129 = new SpaceGroup(129, "P4/nmm",
            TETRAGONAL, LG4mmm, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mY_X_Z, TR_12_12_0),
                    new Generator(ROT_Y_mX_Z, TR_12_12_0),
                    new Generator(ROT_mX_Y_mZ, TR_12_12_0),
                    new Generator(ROT_X_mY_mZ, TR_12_12_0),
                    new Generator(ROT_Y_X_mZ, TR_0_0_0),
                    new Generator(ROT_mY_mX_mZ, TR_0_0_0),
                    new Generator(ROT_mX_mY_mZ, TR_12_12_0),
                    new Generator(ROT_X_Y_mZ, TR_12_12_0),
                    new Generator(ROT_Y_mX_mZ, TR_0_0_0),
                    new Generator(ROT_mY_X_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_Z, TR_0_0_0),
                    new Generator(ROT_mX_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_mX_Z, TR_12_12_0),
                    new Generator(ROT_Y_X_Z, TR_12_12_0) });

    /** Space group 130. */
    public static final SpaceGroup SG130 = new SpaceGroup(130, "P4/ncc",
            TETRAGONAL, LG4mmm, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mY_X_Z, TR_12_12_0),
                    new Generator(ROT_Y_mX_Z, TR_12_12_0),
                    new Generator(ROT_mX_Y_mZ, TR_12_12_12),
                    new Generator(ROT_X_mY_mZ, TR_12_12_12),
                    new Generator(ROT_Y_X_mZ, TR_0_0_12),
                    new Generator(ROT_mY_mX_mZ, TR_0_0_12),
                    new Generator(ROT_mX_mY_mZ, TR_12_12_0),
                    new Generator(ROT_X_Y_mZ, TR_12_12_0),
                    new Generator(ROT_Y_mX_mZ, TR_0_0_0),
                    new Generator(ROT_mY_X_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_Z, TR_0_0_12),
                    new Generator(ROT_mX_Y_Z, TR_0_0_12),
                    new Generator(ROT_mY_mX_Z, TR_12_12_12),
                    new Generator(ROT_Y_X_Z, TR_12_12_12) });

    /** Space group 131. */
    public static final SpaceGroup SG131 = new SpaceGroup(131, "P42/mmc",
            TETRAGONAL, LG4mmm, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mY_X_Z, TR_0_0_12),
                    new Generator(ROT_Y_mX_Z, TR_0_0_12),
                    new Generator(ROT_mX_Y_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_mZ, TR_0_0_0),
                    new Generator(ROT_Y_X_mZ, TR_0_0_12),
                    new Generator(ROT_mY_mX_mZ, TR_0_0_12),
                    new Generator(ROT_mX_mY_mZ, TR_0_0_0),
                    new Generator(ROT_X_Y_mZ, TR_0_0_0),
                    new Generator(ROT_Y_mX_mZ, TR_0_0_12),
                    new Generator(ROT_mY_X_mZ, TR_0_0_12),
                    new Generator(ROT_X_mY_Z, TR_0_0_0),
                    new Generator(ROT_mX_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_mX_Z, TR_0_0_12),
                    new Generator(ROT_Y_X_Z, TR_0_0_12) });

    /** Space group 132. */
    public static final SpaceGroup SG132 = new SpaceGroup(132, "P42/mcm",
            TETRAGONAL, LG4mmm, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mY_X_Z, TR_0_0_12),
                    new Generator(ROT_Y_mX_Z, TR_0_0_12),
                    new Generator(ROT_mX_Y_mZ, TR_0_0_12),
                    new Generator(ROT_X_mY_mZ, TR_0_0_12),
                    new Generator(ROT_Y_X_mZ, TR_0_0_0),
                    new Generator(ROT_mY_mX_mZ, TR_0_0_0),
                    new Generator(ROT_mX_mY_mZ, TR_0_0_0),
                    new Generator(ROT_X_Y_mZ, TR_0_0_0),
                    new Generator(ROT_Y_mX_mZ, TR_0_0_12),
                    new Generator(ROT_mY_X_mZ, TR_0_0_12),
                    new Generator(ROT_X_mY_Z, TR_0_0_12),
                    new Generator(ROT_mX_Y_Z, TR_0_0_12),
                    new Generator(ROT_mY_mX_Z, TR_0_0_0),
                    new Generator(ROT_Y_X_Z, TR_0_0_0) });

    /** Space group 133. */
    public static final SpaceGroup SG133 = new SpaceGroup(133, "P42/nbc",
            TETRAGONAL, LG4mmm, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mY_X_Z, TR_12_12_12),
                    new Generator(ROT_Y_mX_Z, TR_12_12_12),
                    new Generator(ROT_mX_Y_mZ, TR_0_0_12),
                    new Generator(ROT_X_mY_mZ, TR_0_0_12),
                    new Generator(ROT_Y_X_mZ, TR_12_12_0),
                    new Generator(ROT_mY_mX_mZ, TR_12_12_0),
                    new Generator(ROT_mX_mY_mZ, TR_12_12_12),
                    new Generator(ROT_X_Y_mZ, TR_12_12_12),
                    new Generator(ROT_Y_mX_mZ, TR_0_0_0),
                    new Generator(ROT_mY_X_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_Z, TR_12_12_0),
                    new Generator(ROT_mX_Y_Z, TR_12_12_0),
                    new Generator(ROT_mY_mX_Z, TR_0_0_12),
                    new Generator(ROT_Y_X_Z, TR_0_0_12) });

    /** Space group 134. */
    public static final SpaceGroup SG134 = new SpaceGroup(134, "P42/nnm",
            TETRAGONAL, LG4mmm, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mY_X_Z, TR_12_12_12),
                    new Generator(ROT_Y_mX_Z, TR_12_12_12),
                    new Generator(ROT_mX_Y_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_mZ, TR_0_0_0),
                    new Generator(ROT_Y_X_mZ, TR_12_12_12),
                    new Generator(ROT_mY_mX_mZ, TR_12_12_12),
                    new Generator(ROT_mX_mY_mZ, TR_12_12_12),
                    new Generator(ROT_X_Y_mZ, TR_12_12_12),
                    new Generator(ROT_Y_mX_mZ, TR_0_0_0),
                    new Generator(ROT_mY_X_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_Z, TR_12_12_12),
                    new Generator(ROT_mX_Y_Z, TR_12_12_12),
                    new Generator(ROT_mY_mX_Z, TR_0_0_0),
                    new Generator(ROT_Y_X_Z, TR_0_0_0) });

    /** Space group 135. */
    public static final SpaceGroup SG135 = new SpaceGroup(135, "P42/mbc",
            TETRAGONAL, LG4mmm, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mY_X_Z, TR_0_0_12),
                    new Generator(ROT_Y_mX_Z, TR_0_0_12),
                    new Generator(ROT_mX_Y_mZ, TR_12_12_0),
                    new Generator(ROT_X_mY_mZ, TR_12_12_0),
                    new Generator(ROT_Y_X_mZ, TR_12_12_12),
                    new Generator(ROT_mY_mX_mZ, TR_12_12_12),
                    new Generator(ROT_mX_mY_mZ, TR_0_0_0),
                    new Generator(ROT_X_Y_mZ, TR_0_0_0),
                    new Generator(ROT_Y_mX_mZ, TR_0_0_12),
                    new Generator(ROT_mY_X_mZ, TR_0_0_12),
                    new Generator(ROT_X_mY_Z, TR_12_12_0),
                    new Generator(ROT_mX_Y_Z, TR_12_12_0),
                    new Generator(ROT_mY_mX_Z, TR_12_12_12),
                    new Generator(ROT_Y_X_Z, TR_12_12_12) });

    /** Space group 136. */
    public static final SpaceGroup SG136 = new SpaceGroup(136, "P42/mnm",
            TETRAGONAL, LG4mmm, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mY_X_Z, TR_12_12_12),
                    new Generator(ROT_Y_mX_Z, TR_12_12_12),
                    new Generator(ROT_mX_Y_mZ, TR_12_12_12),
                    new Generator(ROT_X_mY_mZ, TR_12_12_12),
                    new Generator(ROT_Y_X_mZ, TR_0_0_0),
                    new Generator(ROT_mY_mX_mZ, TR_0_0_0),
                    new Generator(ROT_mX_mY_mZ, TR_0_0_0),
                    new Generator(ROT_X_Y_mZ, TR_0_0_0),
                    new Generator(ROT_Y_mX_mZ, TR_12_12_12),
                    new Generator(ROT_mY_X_mZ, TR_12_12_12),
                    new Generator(ROT_X_mY_Z, TR_12_12_12),
                    new Generator(ROT_mX_Y_Z, TR_12_12_12),
                    new Generator(ROT_mY_mX_Z, TR_0_0_0),
                    new Generator(ROT_Y_X_Z, TR_0_0_0) });

    /** Space group 137. */
    public static final SpaceGroup SG137 = new SpaceGroup(137, "P42/nmc",
            TETRAGONAL, LG4mmm, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mY_X_Z, TR_12_12_12),
                    new Generator(ROT_Y_mX_Z, TR_12_12_12),
                    new Generator(ROT_mX_Y_mZ, TR_12_12_12),
                    new Generator(ROT_X_mY_mZ, TR_12_12_12),
                    new Generator(ROT_Y_X_mZ, TR_0_0_0),
                    new Generator(ROT_mY_mX_mZ, TR_0_0_0),
                    new Generator(ROT_mX_mY_mZ, TR_12_12_12),
                    new Generator(ROT_X_Y_mZ, TR_12_12_12),
                    new Generator(ROT_Y_mX_mZ, TR_0_0_0),
                    new Generator(ROT_mY_X_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_Z, TR_0_0_0),
                    new Generator(ROT_mX_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_mX_Z, TR_12_12_12),
                    new Generator(ROT_Y_X_Z, TR_12_12_12) });

    /** Space group 138. */
    public static final SpaceGroup SG138 = new SpaceGroup(138, "P42/ncm",
            TETRAGONAL, LG4mmm, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mY_X_Z, TR_12_12_12),
                    new Generator(ROT_Y_mX_Z, TR_12_12_12),
                    new Generator(ROT_mX_Y_mZ, TR_12_12_0),
                    new Generator(ROT_X_mY_mZ, TR_12_12_0),
                    new Generator(ROT_Y_X_mZ, TR_0_0_12),
                    new Generator(ROT_mY_mX_mZ, TR_0_0_12),
                    new Generator(ROT_mX_mY_mZ, TR_12_12_12),
                    new Generator(ROT_X_Y_mZ, TR_12_12_12),
                    new Generator(ROT_Y_mX_mZ, TR_0_0_0),
                    new Generator(ROT_mY_X_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_Z, TR_0_0_12),
                    new Generator(ROT_mX_Y_Z, TR_0_0_12),
                    new Generator(ROT_mY_mX_Z, TR_12_12_0),
                    new Generator(ROT_Y_X_Z, TR_12_12_0) });

    /** Space group 139. */
    public static final SpaceGroup SG139 = new SpaceGroup(139, "I4/mmm",
            TETRAGONAL, LG4mmm, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mY_X_Z, TR_0_0_0),
                    new Generator(ROT_Y_mX_Z, TR_0_0_0),
                    new Generator(ROT_mX_Y_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_mZ, TR_0_0_0),
                    new Generator(ROT_Y_X_mZ, TR_0_0_0),
                    new Generator(ROT_mY_mX_mZ, TR_0_0_0),
                    new Generator(ROT_mX_mY_mZ, TR_0_0_0),
                    new Generator(ROT_X_Y_mZ, TR_0_0_0),
                    new Generator(ROT_Y_mX_mZ, TR_0_0_0),
                    new Generator(ROT_mY_X_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_Z, TR_0_0_0),
                    new Generator(ROT_mX_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_mX_Z, TR_0_0_0),
                    new Generator(ROT_Y_X_Z, TR_0_0_0),
                    new Generator(ROT_X_Y_Z, TR_12_12_12),
                    new Generator(ROT_mX_mY_Z, TR_12_12_12),
                    new Generator(ROT_mY_X_Z, TR_12_12_12),
                    new Generator(ROT_Y_mX_Z, TR_12_12_12),
                    new Generator(ROT_mX_Y_mZ, TR_12_12_12),
                    new Generator(ROT_X_mY_mZ, TR_12_12_12),
                    new Generator(ROT_Y_X_mZ, TR_12_12_12),
                    new Generator(ROT_mY_mX_mZ, TR_12_12_12),
                    new Generator(ROT_mX_mY_mZ, TR_12_12_12),
                    new Generator(ROT_X_Y_mZ, TR_12_12_12),
                    new Generator(ROT_Y_mX_mZ, TR_12_12_12),
                    new Generator(ROT_mY_X_mZ, TR_12_12_12),
                    new Generator(ROT_X_mY_Z, TR_12_12_12),
                    new Generator(ROT_mX_Y_Z, TR_12_12_12),
                    new Generator(ROT_mY_mX_Z, TR_12_12_12),
                    new Generator(ROT_Y_X_Z, TR_12_12_12) });

    /** Space group 140. */
    public static final SpaceGroup SG140 = new SpaceGroup(140, "I4/mcm",
            TETRAGONAL, LG4mmm, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mY_X_Z, TR_0_0_0),
                    new Generator(ROT_Y_mX_Z, TR_0_0_0),
                    new Generator(ROT_mX_Y_mZ, TR_0_0_12),
                    new Generator(ROT_X_mY_mZ, TR_0_0_12),
                    new Generator(ROT_Y_X_mZ, TR_0_0_12),
                    new Generator(ROT_mY_mX_mZ, TR_0_0_12),
                    new Generator(ROT_mX_mY_mZ, TR_0_0_0),
                    new Generator(ROT_X_Y_mZ, TR_0_0_0),
                    new Generator(ROT_Y_mX_mZ, TR_0_0_0),
                    new Generator(ROT_mY_X_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_Z, TR_0_0_12),
                    new Generator(ROT_mX_Y_Z, TR_0_0_12),
                    new Generator(ROT_mY_mX_Z, TR_0_0_12),
                    new Generator(ROT_Y_X_Z, TR_0_0_12),
                    new Generator(ROT_X_Y_Z, TR_12_12_12),
                    new Generator(ROT_mX_mY_Z, TR_12_12_12),
                    new Generator(ROT_mY_X_Z, TR_12_12_12),
                    new Generator(ROT_Y_mX_Z, TR_12_12_12),
                    new Generator(ROT_mX_Y_mZ, TR_12_12_0),
                    new Generator(ROT_X_mY_mZ, TR_12_12_0),
                    new Generator(ROT_Y_X_mZ, TR_12_12_0),
                    new Generator(ROT_mY_mX_mZ, TR_12_12_0),
                    new Generator(ROT_mX_mY_mZ, TR_12_12_12),
                    new Generator(ROT_X_Y_mZ, TR_12_12_12),
                    new Generator(ROT_Y_mX_mZ, TR_12_12_12),
                    new Generator(ROT_mY_X_mZ, TR_12_12_12),
                    new Generator(ROT_X_mY_Z, TR_12_12_0),
                    new Generator(ROT_mX_Y_Z, TR_12_12_0),
                    new Generator(ROT_mY_mX_Z, TR_12_12_0),
                    new Generator(ROT_Y_X_Z, TR_12_12_0) });

    /** Space group 141. */
    public static final SpaceGroup SG141 = new SpaceGroup(141, "I41/amd",
            TETRAGONAL, LG4mmm, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_12_12_12),
                    new Generator(ROT_mY_X_Z, TR_0_12_14),
                    new Generator(ROT_Y_mX_Z, TR_12_0_34),
                    new Generator(ROT_mX_Y_mZ, TR_12_0_34),
                    new Generator(ROT_X_mY_mZ, TR_0_12_14),
                    new Generator(ROT_Y_X_mZ, TR_12_12_12),
                    new Generator(ROT_mY_mX_mZ, TR_0_0_0),
                    new Generator(ROT_mX_mY_mZ, TR_0_12_14),
                    new Generator(ROT_X_Y_mZ, TR_12_0_34),
                    new Generator(ROT_Y_mX_mZ, TR_0_0_0),
                    new Generator(ROT_mY_X_mZ, TR_12_12_12),
                    new Generator(ROT_X_mY_Z, TR_12_12_12),
                    new Generator(ROT_mX_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_mX_Z, TR_12_0_34),
                    new Generator(ROT_Y_X_Z, TR_0_12_14),
                    new Generator(ROT_X_Y_Z, TR_12_12_12),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mY_X_Z, TR_12_0_34),
                    new Generator(ROT_Y_mX_Z, TR_0_12_14),
                    new Generator(ROT_mX_Y_mZ, TR_0_12_14),
                    new Generator(ROT_X_mY_mZ, TR_12_0_34),
                    new Generator(ROT_Y_X_mZ, TR_0_0_0),
                    new Generator(ROT_mY_mX_mZ, TR_12_12_12),
                    new Generator(ROT_mX_mY_mZ, TR_12_0_34),
                    new Generator(ROT_X_Y_mZ, TR_0_12_14),
                    new Generator(ROT_Y_mX_mZ, TR_12_12_12),
                    new Generator(ROT_mY_X_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_Z, TR_0_0_0),
                    new Generator(ROT_mX_Y_Z, TR_12_12_12),
                    new Generator(ROT_mY_mX_Z, TR_0_12_14),
                    new Generator(ROT_Y_X_Z, TR_12_0_34) });

    /** Space group 142. */
    public static final SpaceGroup SG142 = new SpaceGroup(142, "I41/acd",
            TETRAGONAL, LG4mmm, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_12_12_12),
                    new Generator(ROT_mY_X_Z, TR_0_12_14),
                    new Generator(ROT_Y_mX_Z, TR_12_0_34),
                    new Generator(ROT_mX_Y_mZ, TR_12_0_14),
                    new Generator(ROT_X_mY_mZ, TR_0_12_34),
                    new Generator(ROT_Y_X_mZ, TR_12_12_0),
                    new Generator(ROT_mY_mX_mZ, TR_0_0_12),
                    new Generator(ROT_mX_mY_mZ, TR_0_12_14),
                    new Generator(ROT_X_Y_mZ, TR_12_0_34),
                    new Generator(ROT_Y_mX_mZ, TR_0_0_0),
                    new Generator(ROT_mY_X_mZ, TR_12_12_12),
                    new Generator(ROT_X_mY_Z, TR_12_12_0),
                    new Generator(ROT_mX_Y_Z, TR_0_0_12),
                    new Generator(ROT_mY_mX_Z, TR_12_0_14),
                    new Generator(ROT_Y_X_Z, TR_0_12_34),
                    new Generator(ROT_X_Y_Z, TR_12_12_12),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mY_X_Z, TR_12_0_34),
                    new Generator(ROT_Y_mX_Z, TR_0_12_14),
                    new Generator(ROT_mX_Y_mZ, TR_0_12_34),
                    new Generator(ROT_X_mY_mZ, TR_12_0_14),
                    new Generator(ROT_Y_X_mZ, TR_0_0_12),
                    new Generator(ROT_mY_mX_mZ, TR_12_12_0),
                    new Generator(ROT_mX_mY_mZ, TR_12_0_34),
                    new Generator(ROT_X_Y_mZ, TR_0_12_14),
                    new Generator(ROT_Y_mX_mZ, TR_12_12_12),
                    new Generator(ROT_mY_X_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_Z, TR_0_0_12),
                    new Generator(ROT_mX_Y_Z, TR_12_12_0),
                    new Generator(ROT_mY_mX_Z, TR_0_12_34),
                    new Generator(ROT_Y_X_Z, TR_12_0_14) });

    /** Space group 143. */
    public static final SpaceGroup SG143 = new SpaceGroup(143, "P3", TRIGONAL,
            LG3, new Generator[] { new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_XmY_Z, TR_0_0_0),
                    new Generator(ROT_mXY_mX_Z, TR_0_0_0) });

    /** Space group 144. */
    public static final SpaceGroup SG144 = new SpaceGroup(144, "P31", TRIGONAL,
            LG3, new Generator[] { new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_XmY_Z, TR_0_0_13),
                    new Generator(ROT_mXY_mX_Z, TR_0_0_23) });

    /** Space group 145. */
    public static final SpaceGroup SG145 = new SpaceGroup(145, "P32", TRIGONAL,
            LG3, new Generator[] { new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_XmY_Z, TR_0_0_23),
                    new Generator(ROT_mXY_mX_Z, TR_0_0_13) });

    /** Space group 146. */
    public static final SpaceGroup SG146 = new SpaceGroup(146, "H3", TRIGONAL,
            LG3, new Generator[] { new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_XmY_Z, TR_0_0_0),
                    new Generator(ROT_mXY_mX_Z, TR_0_0_0),
                    new Generator(ROT_X_Y_Z, TR_23_13_13),
                    new Generator(ROT_mY_XmY_Z, TR_23_13_13),
                    new Generator(ROT_mXY_mX_Z, TR_23_13_13),
                    new Generator(ROT_X_Y_Z, TR_13_23_23),
                    new Generator(ROT_mY_XmY_Z, TR_13_23_23),
                    new Generator(ROT_mXY_mX_Z, TR_13_23_23) });

    /** Space group 1146. */
    public static final SpaceGroup SG1146 = new SpaceGroup(1146, "R3",
            TRIGONAL, LG3, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_Z_X_Y, TR_0_0_0),
                    new Generator(ROT_Y_Z_X, TR_0_0_0) });

    /** Space group 147. */
    public static final SpaceGroup SG147 = new SpaceGroup(147, "P-3", TRIGONAL,
            LG3, new Generator[] { new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_XmY_Z, TR_0_0_0),
                    new Generator(ROT_mXY_mX_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_mZ, TR_0_0_0),
                    new Generator(ROT_Y_mXY_mZ, TR_0_0_0),
                    new Generator(ROT_XmY_X_mZ, TR_0_0_0) });

    /** Space group 148. */
    public static final SpaceGroup SG148 = new SpaceGroup(148, "H-3", TRIGONAL,
            LG3, new Generator[] { new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_XmY_Z, TR_0_0_0),
                    new Generator(ROT_mXY_mX_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_mZ, TR_0_0_0),
                    new Generator(ROT_Y_mXY_mZ, TR_0_0_0),
                    new Generator(ROT_XmY_X_mZ, TR_0_0_0),
                    new Generator(ROT_X_Y_Z, TR_23_13_13),
                    new Generator(ROT_mY_XmY_Z, TR_23_13_13),
                    new Generator(ROT_mXY_mX_Z, TR_23_13_13),
                    new Generator(ROT_mX_mY_mZ, TR_23_13_13),
                    new Generator(ROT_Y_mXY_mZ, TR_23_13_13),
                    new Generator(ROT_XmY_X_mZ, TR_23_13_13),
                    new Generator(ROT_X_Y_Z, TR_13_23_23),
                    new Generator(ROT_mY_XmY_Z, TR_13_23_23),
                    new Generator(ROT_mXY_mX_Z, TR_13_23_23),
                    new Generator(ROT_mX_mY_mZ, TR_13_23_23),
                    new Generator(ROT_Y_mXY_mZ, TR_13_23_23),
                    new Generator(ROT_XmY_X_mZ, TR_13_23_23) });

    /** Space group 1148. */
    public static final SpaceGroup SG1148 = new SpaceGroup(1148, "R-3",
            TRIGONAL, LG3, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_Z_X_Y, TR_0_0_0),
                    new Generator(ROT_Y_Z_X, TR_0_0_0),
                    new Generator(ROT_mX_mY_mZ, TR_0_0_0),
                    new Generator(ROT_mZ_mX_mY, TR_0_0_0),
                    new Generator(ROT_mY_mZ_mX, TR_0_0_0) });

    /** Space group 149. */
    public static final SpaceGroup SG149 = new SpaceGroup(149, "P312",
            TRIGONAL, LG3m, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_XmY_Z, TR_0_0_0),
                    new Generator(ROT_mXY_mX_Z, TR_0_0_0),
                    new Generator(ROT_mY_mX_mZ, TR_0_0_0),
                    new Generator(ROT_mXY_Y_mZ, TR_0_0_0),
                    new Generator(ROT_X_XmY_mZ, TR_0_0_0) });

    /** Space group 150. */
    public static final SpaceGroup SG150 = new SpaceGroup(150, "P321",
            TRIGONAL, LG3m, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_XmY_Z, TR_0_0_0),
                    new Generator(ROT_mXY_mX_Z, TR_0_0_0),
                    new Generator(ROT_Y_X_mZ, TR_0_0_0),
                    new Generator(ROT_XmY_mY_mZ, TR_0_0_0),
                    new Generator(ROT_mX_mXY_mZ, TR_0_0_0) });

    /** Space group 151. */
    public static final SpaceGroup SG151 = new SpaceGroup(151, "P3112",
            TRIGONAL, LG3m, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_XmY_Z, TR_0_0_13),
                    new Generator(ROT_mXY_mX_Z, TR_0_0_23),
                    new Generator(ROT_mY_mX_mZ, TR_0_0_23),
                    new Generator(ROT_mXY_Y_mZ, TR_0_0_13),
                    new Generator(ROT_X_XmY_mZ, TR_0_0_0) });

    /** Space group 152. */
    public static final SpaceGroup SG152 = new SpaceGroup(152, "P3121",
            TRIGONAL, LG3m, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_XmY_Z, TR_0_0_13),
                    new Generator(ROT_mXY_mX_Z, TR_0_0_23),
                    new Generator(ROT_Y_X_mZ, TR_0_0_0),
                    new Generator(ROT_XmY_mY_mZ, TR_0_0_23),
                    new Generator(ROT_mX_mXY_mZ, TR_0_0_13) });

    /** Space group 153. */
    public static final SpaceGroup SG153 = new SpaceGroup(153, "P3212",
            TRIGONAL, LG3m, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_XmY_Z, TR_0_0_23),
                    new Generator(ROT_mXY_mX_Z, TR_0_0_13),
                    new Generator(ROT_mY_mX_mZ, TR_0_0_13),
                    new Generator(ROT_mXY_Y_mZ, TR_0_0_23),
                    new Generator(ROT_X_XmY_mZ, TR_0_0_0) });

    /** Space group 154. */
    public static final SpaceGroup SG154 = new SpaceGroup(154, "P3221",
            TRIGONAL, LG3m, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_XmY_Z, TR_0_0_23),
                    new Generator(ROT_mXY_mX_Z, TR_0_0_13),
                    new Generator(ROT_Y_X_mZ, TR_0_0_0),
                    new Generator(ROT_XmY_mY_mZ, TR_0_0_13),
                    new Generator(ROT_mX_mXY_mZ, TR_0_0_23) });

    /** Space group 155. */
    public static final SpaceGroup SG155 = new SpaceGroup(155, "H32", TRIGONAL,
            LG3m, new Generator[] { new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_XmY_Z, TR_0_0_0),
                    new Generator(ROT_mXY_mX_Z, TR_0_0_0),
                    new Generator(ROT_Y_X_mZ, TR_0_0_0),
                    new Generator(ROT_XmY_mY_mZ, TR_0_0_0),
                    new Generator(ROT_mX_mXY_mZ, TR_0_0_0),
                    new Generator(ROT_X_Y_Z, TR_23_13_13),
                    new Generator(ROT_mY_XmY_Z, TR_23_13_13),
                    new Generator(ROT_mXY_mX_Z, TR_23_13_13),
                    new Generator(ROT_Y_X_mZ, TR_23_13_13),
                    new Generator(ROT_XmY_mY_mZ, TR_23_13_13),
                    new Generator(ROT_mX_mXY_mZ, TR_23_13_13),
                    new Generator(ROT_X_Y_Z, TR_13_23_23),
                    new Generator(ROT_mY_XmY_Z, TR_13_23_23),
                    new Generator(ROT_mXY_mX_Z, TR_13_23_23),
                    new Generator(ROT_Y_X_mZ, TR_13_23_23),
                    new Generator(ROT_XmY_mY_mZ, TR_13_23_23),
                    new Generator(ROT_mX_mXY_mZ, TR_13_23_23) });

    /** Space group 1155. */
    public static final SpaceGroup SG1155 = new SpaceGroup(1155, "R32",
            TRIGONAL, LG3m, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_Z_X_Y, TR_0_0_0),
                    new Generator(ROT_Y_Z_X, TR_0_0_0),
                    new Generator(ROT_mY_mX_mZ, TR_0_0_0),
                    new Generator(ROT_mX_mZ_mY, TR_0_0_0),
                    new Generator(ROT_mZ_mY_mX, TR_0_0_0) });

    /** Space group 156. */
    public static final SpaceGroup SG156 = new SpaceGroup(156, "P3m1",
            TRIGONAL, LG3m, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_XmY_Z, TR_0_0_0),
                    new Generator(ROT_mXY_mX_Z, TR_0_0_0),
                    new Generator(ROT_mY_mX_Z, TR_0_0_0),
                    new Generator(ROT_mXY_Y_Z, TR_0_0_0),
                    new Generator(ROT_X_XmY_Z, TR_0_0_0) });

    /** Space group 157. */
    public static final SpaceGroup SG157 = new SpaceGroup(157, "P31m",
            TRIGONAL, LG3m, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_XmY_Z, TR_0_0_0),
                    new Generator(ROT_mXY_mX_Z, TR_0_0_0),
                    new Generator(ROT_Y_X_Z, TR_0_0_0),
                    new Generator(ROT_XmY_mY_Z, TR_0_0_0),
                    new Generator(ROT_mX_mXY_Z, TR_0_0_0) });

    /** Space group 158. */
    public static final SpaceGroup SG158 = new SpaceGroup(158, "P3c1",
            TRIGONAL, LG3m, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_XmY_Z, TR_0_0_0),
                    new Generator(ROT_mXY_mX_Z, TR_0_0_0),
                    new Generator(ROT_mY_mX_Z, TR_0_0_12),
                    new Generator(ROT_mXY_Y_Z, TR_0_0_12),
                    new Generator(ROT_X_XmY_Z, TR_0_0_12) });

    /** Space group 159. */
    public static final SpaceGroup SG159 = new SpaceGroup(159, "P31c",
            TRIGONAL, LG3m, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_XmY_Z, TR_0_0_0),
                    new Generator(ROT_mXY_mX_Z, TR_0_0_0),
                    new Generator(ROT_Y_X_Z, TR_0_0_12),
                    new Generator(ROT_XmY_mY_Z, TR_0_0_12),
                    new Generator(ROT_mX_mXY_Z, TR_0_0_12) });

    /** Space group 160. */
    public static final SpaceGroup SG160 = new SpaceGroup(160, "H3m", TRIGONAL,
            LG3m, new Generator[] { new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_XmY_Z, TR_0_0_0),
                    new Generator(ROT_mXY_mX_Z, TR_0_0_0),
                    new Generator(ROT_mY_mX_Z, TR_0_0_0),
                    new Generator(ROT_mXY_Y_Z, TR_0_0_0),
                    new Generator(ROT_X_XmY_Z, TR_0_0_0),
                    new Generator(ROT_X_Y_Z, TR_23_13_13),
                    new Generator(ROT_mY_XmY_Z, TR_23_13_13),
                    new Generator(ROT_mXY_mX_Z, TR_23_13_13),
                    new Generator(ROT_mY_mX_Z, TR_23_13_13),
                    new Generator(ROT_mXY_Y_Z, TR_23_13_13),
                    new Generator(ROT_X_XmY_Z, TR_23_13_13),
                    new Generator(ROT_X_Y_Z, TR_13_23_23),
                    new Generator(ROT_mY_XmY_Z, TR_13_23_23),
                    new Generator(ROT_mXY_mX_Z, TR_13_23_23),
                    new Generator(ROT_mY_mX_Z, TR_13_23_23),
                    new Generator(ROT_mXY_Y_Z, TR_13_23_23),
                    new Generator(ROT_X_XmY_Z, TR_13_23_23) });

    /** Space group 1160. */
    public static final SpaceGroup SG1160 = new SpaceGroup(1160, "R3m",
            TRIGONAL, LG3m, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_Z_X_Y, TR_0_0_0),
                    new Generator(ROT_Y_Z_X, TR_0_0_0),
                    new Generator(ROT_Y_X_Z, TR_0_0_0),
                    new Generator(ROT_X_Z_Y, TR_0_0_0),
                    new Generator(ROT_Z_Y_X, TR_0_0_0) });

    /** Space group 161. */
    public static final SpaceGroup SG161 = new SpaceGroup(161, "H3c", TRIGONAL,
            LG3m, new Generator[] { new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_XmY_Z, TR_0_0_0),
                    new Generator(ROT_mXY_mX_Z, TR_0_0_0),
                    new Generator(ROT_mY_mX_Z, TR_0_0_12),
                    new Generator(ROT_mXY_Y_Z, TR_0_0_12),
                    new Generator(ROT_X_XmY_Z, TR_0_0_12),
                    new Generator(ROT_X_Y_Z, TR_23_13_13),
                    new Generator(ROT_mY_XmY_Z, TR_23_13_13),
                    new Generator(ROT_mXY_mX_Z, TR_23_13_13),
                    new Generator(ROT_mY_mX_Z, TR_23_13_56),
                    new Generator(ROT_mXY_Y_Z, TR_23_13_56),
                    new Generator(ROT_X_XmY_Z, TR_23_13_56),
                    new Generator(ROT_X_Y_Z, TR_13_23_23),
                    new Generator(ROT_mY_XmY_Z, TR_13_23_23),
                    new Generator(ROT_mXY_mX_Z, TR_13_23_23),
                    new Generator(ROT_mY_mX_Z, TR_13_23_16),
                    new Generator(ROT_mXY_Y_Z, TR_13_23_16),
                    new Generator(ROT_X_XmY_Z, TR_13_23_16) });

    /** Space group 1161. */
    public static final SpaceGroup SG1161 = new SpaceGroup(1161, "R3c",
            TRIGONAL, LG3m, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_Z_X_Y, TR_0_0_0),
                    new Generator(ROT_Y_Z_X, TR_0_0_0),
                    new Generator(ROT_Y_X_Z, TR_12_12_12),
                    new Generator(ROT_X_Z_Y, TR_12_12_12),
                    new Generator(ROT_Z_Y_X, TR_12_12_12) });

    /** Space group 162. */
    public static final SpaceGroup SG162 = new SpaceGroup(162, "P-31m",
            TRIGONAL, LG3m, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_XmY_Z, TR_0_0_0),
                    new Generator(ROT_mXY_mX_Z, TR_0_0_0),
                    new Generator(ROT_mY_mX_mZ, TR_0_0_0),
                    new Generator(ROT_mXY_Y_mZ, TR_0_0_0),
                    new Generator(ROT_X_XmY_mZ, TR_0_0_0),
                    new Generator(ROT_mX_mY_mZ, TR_0_0_0),
                    new Generator(ROT_Y_mXY_mZ, TR_0_0_0),
                    new Generator(ROT_XmY_X_mZ, TR_0_0_0),
                    new Generator(ROT_Y_X_Z, TR_0_0_0),
                    new Generator(ROT_XmY_mY_Z, TR_0_0_0),
                    new Generator(ROT_mX_mXY_Z, TR_0_0_0) });

    /** Space group 163. */
    public static final SpaceGroup SG163 = new SpaceGroup(163, "P-31c",
            TRIGONAL, LG3m, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_XmY_Z, TR_0_0_0),
                    new Generator(ROT_mXY_mX_Z, TR_0_0_0),
                    new Generator(ROT_mY_mX_mZ, TR_0_0_12),
                    new Generator(ROT_mXY_Y_mZ, TR_0_0_12),
                    new Generator(ROT_X_XmY_mZ, TR_0_0_12),
                    new Generator(ROT_mX_mY_mZ, TR_0_0_0),
                    new Generator(ROT_Y_mXY_mZ, TR_0_0_0),
                    new Generator(ROT_XmY_X_mZ, TR_0_0_0),
                    new Generator(ROT_Y_X_Z, TR_0_0_12),
                    new Generator(ROT_XmY_mY_Z, TR_0_0_12),
                    new Generator(ROT_mX_mXY_Z, TR_0_0_12) });

    /** Space group 164. */
    public static final SpaceGroup SG164 = new SpaceGroup(164, "P-3m1",
            TRIGONAL, LG3m, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_XmY_Z, TR_0_0_0),
                    new Generator(ROT_mXY_mX_Z, TR_0_0_0),
                    new Generator(ROT_Y_X_mZ, TR_0_0_0),
                    new Generator(ROT_XmY_mY_mZ, TR_0_0_0),
                    new Generator(ROT_mX_mXY_mZ, TR_0_0_0),
                    new Generator(ROT_mX_mY_mZ, TR_0_0_0),
                    new Generator(ROT_Y_mXY_mZ, TR_0_0_0),
                    new Generator(ROT_XmY_X_mZ, TR_0_0_0),
                    new Generator(ROT_mY_mX_Z, TR_0_0_0),
                    new Generator(ROT_mXY_Y_Z, TR_0_0_0),
                    new Generator(ROT_X_XmY_Z, TR_0_0_0) });

    /** Space group 165. */
    public static final SpaceGroup SG165 = new SpaceGroup(165, "P-3c1",
            TRIGONAL, LG3m, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_XmY_Z, TR_0_0_0),
                    new Generator(ROT_mXY_mX_Z, TR_0_0_0),
                    new Generator(ROT_Y_X_mZ, TR_0_0_12),
                    new Generator(ROT_XmY_mY_mZ, TR_0_0_12),
                    new Generator(ROT_mX_mXY_mZ, TR_0_0_12),
                    new Generator(ROT_mX_mY_mZ, TR_0_0_0),
                    new Generator(ROT_Y_mXY_mZ, TR_0_0_0),
                    new Generator(ROT_XmY_X_mZ, TR_0_0_0),
                    new Generator(ROT_mY_mX_Z, TR_0_0_12),
                    new Generator(ROT_mXY_Y_Z, TR_0_0_12),
                    new Generator(ROT_X_XmY_Z, TR_0_0_12) });

    /** Space group 166. */
    public static final SpaceGroup SG166 = new SpaceGroup(166, "H-3m",
            TRIGONAL, LG3m, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_XmY_Z, TR_0_0_0),
                    new Generator(ROT_mXY_mX_Z, TR_0_0_0),
                    new Generator(ROT_Y_X_mZ, TR_0_0_0),
                    new Generator(ROT_XmY_mY_mZ, TR_0_0_0),
                    new Generator(ROT_mX_mXY_mZ, TR_0_0_0),
                    new Generator(ROT_mX_mY_mZ, TR_0_0_0),
                    new Generator(ROT_Y_mXY_mZ, TR_0_0_0),
                    new Generator(ROT_XmY_X_mZ, TR_0_0_0),
                    new Generator(ROT_mY_mX_Z, TR_0_0_0),
                    new Generator(ROT_mXY_Y_Z, TR_0_0_0),
                    new Generator(ROT_X_XmY_Z, TR_0_0_0),
                    new Generator(ROT_X_Y_Z, TR_23_13_13),
                    new Generator(ROT_mY_XmY_Z, TR_23_13_13),
                    new Generator(ROT_mXY_mX_Z, TR_23_13_13),
                    new Generator(ROT_Y_X_mZ, TR_23_13_13),
                    new Generator(ROT_XmY_mY_mZ, TR_23_13_13),
                    new Generator(ROT_mX_mXY_mZ, TR_23_13_13),
                    new Generator(ROT_mX_mY_mZ, TR_23_13_13),
                    new Generator(ROT_Y_mXY_mZ, TR_23_13_13),
                    new Generator(ROT_XmY_X_mZ, TR_23_13_13),
                    new Generator(ROT_mY_mX_Z, TR_23_13_13),
                    new Generator(ROT_mXY_Y_Z, TR_23_13_13),
                    new Generator(ROT_X_XmY_Z, TR_23_13_13),
                    new Generator(ROT_X_Y_Z, TR_13_23_23),
                    new Generator(ROT_mY_XmY_Z, TR_13_23_23),
                    new Generator(ROT_mXY_mX_Z, TR_13_23_23),
                    new Generator(ROT_Y_X_mZ, TR_13_23_23),
                    new Generator(ROT_XmY_mY_mZ, TR_13_23_23),
                    new Generator(ROT_mX_mXY_mZ, TR_13_23_23),
                    new Generator(ROT_mX_mY_mZ, TR_13_23_23),
                    new Generator(ROT_Y_mXY_mZ, TR_13_23_23),
                    new Generator(ROT_XmY_X_mZ, TR_13_23_23),
                    new Generator(ROT_mY_mX_Z, TR_13_23_23),
                    new Generator(ROT_mXY_Y_Z, TR_13_23_23),
                    new Generator(ROT_X_XmY_Z, TR_13_23_23) });

    /** Space group 1166. */
    public static final SpaceGroup SG1166 = new SpaceGroup(1166, "R-3m",
            TRIGONAL, LG3m, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_Z_X_Y, TR_0_0_0),
                    new Generator(ROT_Y_Z_X, TR_0_0_0),
                    new Generator(ROT_mY_mX_mZ, TR_0_0_0),
                    new Generator(ROT_mX_mZ_mY, TR_0_0_0),
                    new Generator(ROT_mZ_mY_mX, TR_0_0_0),
                    new Generator(ROT_mX_mY_mZ, TR_0_0_0),
                    new Generator(ROT_mZ_mX_mY, TR_0_0_0),
                    new Generator(ROT_mY_mZ_mX, TR_0_0_0),
                    new Generator(ROT_Y_X_Z, TR_0_0_0),
                    new Generator(ROT_X_Z_Y, TR_0_0_0),
                    new Generator(ROT_Z_Y_X, TR_0_0_0) });

    /** Space group 167. */
    public static final SpaceGroup SG167 = new SpaceGroup(167, "H-3c",
            TRIGONAL, LG3m, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_XmY_Z, TR_0_0_0),
                    new Generator(ROT_mXY_mX_Z, TR_0_0_0),
                    new Generator(ROT_Y_X_mZ, TR_0_0_12),
                    new Generator(ROT_XmY_mY_mZ, TR_0_0_12),
                    new Generator(ROT_mX_mXY_mZ, TR_0_0_12),
                    new Generator(ROT_mX_mY_mZ, TR_0_0_0),
                    new Generator(ROT_Y_mXY_mZ, TR_0_0_0),
                    new Generator(ROT_XmY_X_mZ, TR_0_0_0),
                    new Generator(ROT_mY_mX_Z, TR_0_0_12),
                    new Generator(ROT_mXY_Y_Z, TR_0_0_12),
                    new Generator(ROT_X_XmY_Z, TR_0_0_12),
                    new Generator(ROT_X_Y_Z, TR_23_13_13),
                    new Generator(ROT_mY_XmY_Z, TR_23_13_13),
                    new Generator(ROT_mXY_mX_Z, TR_23_13_13),
                    new Generator(ROT_Y_X_mZ, TR_23_13_56),
                    new Generator(ROT_XmY_mY_mZ, TR_23_13_56),
                    new Generator(ROT_mX_mXY_mZ, TR_23_13_56),
                    new Generator(ROT_mX_mY_mZ, TR_23_13_13),
                    new Generator(ROT_Y_mXY_mZ, TR_23_13_13),
                    new Generator(ROT_XmY_X_mZ, TR_23_13_13),
                    new Generator(ROT_mY_mX_Z, TR_23_13_56),
                    new Generator(ROT_mXY_Y_Z, TR_23_13_56),
                    new Generator(ROT_X_XmY_Z, TR_23_13_56),
                    new Generator(ROT_X_Y_Z, TR_13_23_23),
                    new Generator(ROT_mY_XmY_Z, TR_13_23_23),
                    new Generator(ROT_mXY_mX_Z, TR_13_23_23),
                    new Generator(ROT_Y_X_mZ, TR_13_23_16),
                    new Generator(ROT_XmY_mY_mZ, TR_13_23_16),
                    new Generator(ROT_mX_mXY_mZ, TR_13_23_16),
                    new Generator(ROT_mX_mY_mZ, TR_13_23_23),
                    new Generator(ROT_Y_mXY_mZ, TR_13_23_23),
                    new Generator(ROT_XmY_X_mZ, TR_13_23_23),
                    new Generator(ROT_mY_mX_Z, TR_13_23_16),
                    new Generator(ROT_mXY_Y_Z, TR_13_23_16),
                    new Generator(ROT_X_XmY_Z, TR_13_23_16) });

    /** Space group 1167. */
    public static final SpaceGroup SG1167 = new SpaceGroup(1167, "R-3c",
            TRIGONAL, LG3m, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_Z_X_Y, TR_0_0_0),
                    new Generator(ROT_Y_Z_X, TR_0_0_0),
                    new Generator(ROT_mY_mX_mZ, TR_12_12_12),
                    new Generator(ROT_mX_mZ_mY, TR_12_12_12),
                    new Generator(ROT_mZ_mY_mX, TR_12_12_12),
                    new Generator(ROT_mX_mY_mZ, TR_0_0_0),
                    new Generator(ROT_mZ_mX_mY, TR_0_0_0),
                    new Generator(ROT_mY_mZ_mX, TR_0_0_0),
                    new Generator(ROT_Y_X_Z, TR_12_12_12),
                    new Generator(ROT_X_Z_Y, TR_12_12_12),
                    new Generator(ROT_Z_Y_X, TR_12_12_12) });

    /** Space group 168. */
    public static final SpaceGroup SG168 = new SpaceGroup(168, "P6", HEXAGONAL,
            LG6m, new Generator[] { new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_XmY_Z, TR_0_0_0),
                    new Generator(ROT_mXY_mX_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_Y_mXY_Z, TR_0_0_0),
                    new Generator(ROT_XmY_X_Z, TR_0_0_0) });

    /** Space group 169. */
    public static final SpaceGroup SG169 = new SpaceGroup(169, "P61",
            HEXAGONAL, LG6m, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_XmY_Z, TR_0_0_13),
                    new Generator(ROT_mXY_mX_Z, TR_0_0_23),
                    new Generator(ROT_mX_mY_Z, TR_0_0_12),
                    new Generator(ROT_Y_mXY_Z, TR_0_0_56),
                    new Generator(ROT_XmY_X_Z, TR_0_0_16) });

    /** Space group 170. */
    public static final SpaceGroup SG170 = new SpaceGroup(170, "P65",
            HEXAGONAL, LG6m, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_XmY_Z, TR_0_0_23),
                    new Generator(ROT_mXY_mX_Z, TR_0_0_13),
                    new Generator(ROT_mX_mY_Z, TR_0_0_12),
                    new Generator(ROT_Y_mXY_Z, TR_0_0_16),
                    new Generator(ROT_XmY_X_Z, TR_0_0_56) });

    /** Space group 171. */
    public static final SpaceGroup SG171 = new SpaceGroup(171, "P62",
            HEXAGONAL, LG6m, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_XmY_Z, TR_0_0_23),
                    new Generator(ROT_mXY_mX_Z, TR_0_0_13),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_Y_mXY_Z, TR_0_0_23),
                    new Generator(ROT_XmY_X_Z, TR_0_0_13) });

    /** Space group 172. */
    public static final SpaceGroup SG172 = new SpaceGroup(172, "P64",
            HEXAGONAL, LG6m, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_XmY_Z, TR_0_0_13),
                    new Generator(ROT_mXY_mX_Z, TR_0_0_23),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_Y_mXY_Z, TR_0_0_13),
                    new Generator(ROT_XmY_X_Z, TR_0_0_23) });

    /** Space group 173. */
    public static final SpaceGroup SG173 = new SpaceGroup(173, "P63",
            HEXAGONAL, LG6m, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_XmY_Z, TR_0_0_0),
                    new Generator(ROT_mXY_mX_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_12),
                    new Generator(ROT_Y_mXY_Z, TR_0_0_12),
                    new Generator(ROT_XmY_X_Z, TR_0_0_12) });

    /** Space group 174. */
    public static final SpaceGroup SG174 = new SpaceGroup(174, "P-6",
            HEXAGONAL, LG6m, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_XmY_Z, TR_0_0_0),
                    new Generator(ROT_mXY_mX_Z, TR_0_0_0),
                    new Generator(ROT_X_Y_mZ, TR_0_0_0),
                    new Generator(ROT_mY_XmY_mZ, TR_0_0_0),
                    new Generator(ROT_mXY_mX_mZ, TR_0_0_0) });

    /** Space group 175. */
    public static final SpaceGroup SG175 = new SpaceGroup(175, "P6/m",
            HEXAGONAL, LG6m, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_XmY_Z, TR_0_0_0),
                    new Generator(ROT_mXY_mX_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_Y_mXY_Z, TR_0_0_0),
                    new Generator(ROT_XmY_X_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_mZ, TR_0_0_0),
                    new Generator(ROT_Y_mXY_mZ, TR_0_0_0),
                    new Generator(ROT_XmY_X_mZ, TR_0_0_0),
                    new Generator(ROT_X_Y_mZ, TR_0_0_0),
                    new Generator(ROT_mY_XmY_mZ, TR_0_0_0),
                    new Generator(ROT_mXY_mX_mZ, TR_0_0_0) });

    /** Space group 176. */
    public static final SpaceGroup SG176 = new SpaceGroup(176, "P63/m",
            HEXAGONAL, LG6m, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_XmY_Z, TR_0_0_0),
                    new Generator(ROT_mXY_mX_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_12),
                    new Generator(ROT_Y_mXY_Z, TR_0_0_12),
                    new Generator(ROT_XmY_X_Z, TR_0_0_12),
                    new Generator(ROT_mX_mY_mZ, TR_0_0_0),
                    new Generator(ROT_Y_mXY_mZ, TR_0_0_0),
                    new Generator(ROT_XmY_X_mZ, TR_0_0_0),
                    new Generator(ROT_X_Y_mZ, TR_0_0_12),
                    new Generator(ROT_mY_XmY_mZ, TR_0_0_12),
                    new Generator(ROT_mXY_mX_mZ, TR_0_0_12) });

    /** Space group 177. */
    public static final SpaceGroup SG177 = new SpaceGroup(177, "P622",
            HEXAGONAL, LG6mmm, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_XmY_Z, TR_0_0_0),
                    new Generator(ROT_mXY_mX_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_Y_mXY_Z, TR_0_0_0),
                    new Generator(ROT_XmY_X_Z, TR_0_0_0),
                    new Generator(ROT_Y_X_mZ, TR_0_0_0),
                    new Generator(ROT_XmY_mY_mZ, TR_0_0_0),
                    new Generator(ROT_mX_mXY_mZ, TR_0_0_0),
                    new Generator(ROT_mY_mX_mZ, TR_0_0_0),
                    new Generator(ROT_mXY_Y_mZ, TR_0_0_0),
                    new Generator(ROT_X_XmY_mZ, TR_0_0_0) });

    /** Space group 178. */
    public static final SpaceGroup SG178 = new SpaceGroup(178, "P6122",
            HEXAGONAL, LG6mmm, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_XmY_Z, TR_0_0_13),
                    new Generator(ROT_mXY_mX_Z, TR_0_0_23),
                    new Generator(ROT_mX_mY_Z, TR_0_0_12),
                    new Generator(ROT_Y_mXY_Z, TR_0_0_56),
                    new Generator(ROT_XmY_X_Z, TR_0_0_16),
                    new Generator(ROT_Y_X_mZ, TR_0_0_13),
                    new Generator(ROT_XmY_mY_mZ, TR_0_0_0),
                    new Generator(ROT_mX_mXY_mZ, TR_0_0_23),
                    new Generator(ROT_mY_mX_mZ, TR_0_0_56),
                    new Generator(ROT_mXY_Y_mZ, TR_0_0_12),
                    new Generator(ROT_X_XmY_mZ, TR_0_0_16) });

    /** Space group 179. */
    public static final SpaceGroup SG179 = new SpaceGroup(179, "P6522",
            HEXAGONAL, LG6mmm, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_XmY_Z, TR_0_0_23),
                    new Generator(ROT_mXY_mX_Z, TR_0_0_13),
                    new Generator(ROT_mX_mY_Z, TR_0_0_12),
                    new Generator(ROT_Y_mXY_Z, TR_0_0_16),
                    new Generator(ROT_XmY_X_Z, TR_0_0_56),
                    new Generator(ROT_Y_X_mZ, TR_0_0_23),
                    new Generator(ROT_XmY_mY_mZ, TR_0_0_0),
                    new Generator(ROT_mX_mXY_mZ, TR_0_0_13),
                    new Generator(ROT_mY_mX_mZ, TR_0_0_16),
                    new Generator(ROT_mXY_Y_mZ, TR_0_0_12),
                    new Generator(ROT_X_XmY_mZ, TR_0_0_56) });

    /** Space group 180. */
    public static final SpaceGroup SG180 = new SpaceGroup(180, "P6222",
            HEXAGONAL, LG6mmm, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_XmY_Z, TR_0_0_23),
                    new Generator(ROT_mXY_mX_Z, TR_0_0_13),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_Y_mXY_Z, TR_0_0_23),
                    new Generator(ROT_XmY_X_Z, TR_0_0_13),
                    new Generator(ROT_Y_X_mZ, TR_0_0_23),
                    new Generator(ROT_XmY_mY_mZ, TR_0_0_0),
                    new Generator(ROT_mX_mXY_mZ, TR_0_0_13),
                    new Generator(ROT_mY_mX_mZ, TR_0_0_23),
                    new Generator(ROT_mXY_Y_mZ, TR_0_0_0),
                    new Generator(ROT_X_XmY_mZ, TR_0_0_13) });

    /** Space group 181. */
    public static final SpaceGroup SG181 = new SpaceGroup(181, "P6422",
            HEXAGONAL, LG6mmm, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_XmY_Z, TR_0_0_13),
                    new Generator(ROT_mXY_mX_Z, TR_0_0_23),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_Y_mXY_Z, TR_0_0_13),
                    new Generator(ROT_XmY_X_Z, TR_0_0_23),
                    new Generator(ROT_Y_X_mZ, TR_0_0_13),
                    new Generator(ROT_XmY_mY_mZ, TR_0_0_0),
                    new Generator(ROT_mX_mXY_mZ, TR_0_0_23),
                    new Generator(ROT_mY_mX_mZ, TR_0_0_13),
                    new Generator(ROT_mXY_Y_mZ, TR_0_0_0),
                    new Generator(ROT_X_XmY_mZ, TR_0_0_23) });

    /** Space group 182. */
    public static final SpaceGroup SG182 = new SpaceGroup(182, "P6322",
            HEXAGONAL, LG6mmm, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_XmY_Z, TR_0_0_0),
                    new Generator(ROT_mXY_mX_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_12),
                    new Generator(ROT_Y_mXY_Z, TR_0_0_12),
                    new Generator(ROT_XmY_X_Z, TR_0_0_12),
                    new Generator(ROT_Y_X_mZ, TR_0_0_0),
                    new Generator(ROT_XmY_mY_mZ, TR_0_0_0),
                    new Generator(ROT_mX_mXY_mZ, TR_0_0_0),
                    new Generator(ROT_mY_mX_mZ, TR_0_0_12),
                    new Generator(ROT_mXY_Y_mZ, TR_0_0_12),
                    new Generator(ROT_X_XmY_mZ, TR_0_0_12) });

    /** Space group 183. */
    public static final SpaceGroup SG183 = new SpaceGroup(183, "P6mm",
            HEXAGONAL, LG6mmm, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_XmY_Z, TR_0_0_0),
                    new Generator(ROT_mXY_mX_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_Y_mXY_Z, TR_0_0_0),
                    new Generator(ROT_XmY_X_Z, TR_0_0_0),
                    new Generator(ROT_mY_mX_Z, TR_0_0_0),
                    new Generator(ROT_mXY_Y_Z, TR_0_0_0),
                    new Generator(ROT_X_XmY_Z, TR_0_0_0),
                    new Generator(ROT_Y_X_Z, TR_0_0_0),
                    new Generator(ROT_XmY_mY_Z, TR_0_0_0),
                    new Generator(ROT_mX_mXY_Z, TR_0_0_0) });

    /** Space group 184. */
    public static final SpaceGroup SG184 = new SpaceGroup(184, "P6cc",
            HEXAGONAL, LG6mmm, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_XmY_Z, TR_0_0_0),
                    new Generator(ROT_mXY_mX_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_Y_mXY_Z, TR_0_0_0),
                    new Generator(ROT_XmY_X_Z, TR_0_0_0),
                    new Generator(ROT_mY_mX_Z, TR_0_0_12),
                    new Generator(ROT_mXY_Y_Z, TR_0_0_12),
                    new Generator(ROT_X_XmY_Z, TR_0_0_12),
                    new Generator(ROT_Y_X_Z, TR_0_0_12),
                    new Generator(ROT_XmY_mY_Z, TR_0_0_12),
                    new Generator(ROT_mX_mXY_Z, TR_0_0_12) });

    /** Space group 185. */
    public static final SpaceGroup SG185 = new SpaceGroup(185, "P63cm",
            HEXAGONAL, LG6mmm, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_XmY_Z, TR_0_0_0),
                    new Generator(ROT_mXY_mX_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_12),
                    new Generator(ROT_Y_mXY_Z, TR_0_0_12),
                    new Generator(ROT_XmY_X_Z, TR_0_0_12),
                    new Generator(ROT_mY_mX_Z, TR_0_0_12),
                    new Generator(ROT_mXY_Y_Z, TR_0_0_12),
                    new Generator(ROT_X_XmY_Z, TR_0_0_12),
                    new Generator(ROT_Y_X_Z, TR_0_0_0),
                    new Generator(ROT_XmY_mY_Z, TR_0_0_0),
                    new Generator(ROT_mX_mXY_Z, TR_0_0_0) });

    /** Space group 186. */
    public static final SpaceGroup SG186 = new SpaceGroup(186, "P63mc",
            HEXAGONAL, LG6mmm, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_XmY_Z, TR_0_0_0),
                    new Generator(ROT_mXY_mX_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_12),
                    new Generator(ROT_Y_mXY_Z, TR_0_0_12),
                    new Generator(ROT_XmY_X_Z, TR_0_0_12),
                    new Generator(ROT_mY_mX_Z, TR_0_0_0),
                    new Generator(ROT_mXY_Y_Z, TR_0_0_0),
                    new Generator(ROT_X_XmY_Z, TR_0_0_0),
                    new Generator(ROT_Y_X_Z, TR_0_0_12),
                    new Generator(ROT_XmY_mY_Z, TR_0_0_12),
                    new Generator(ROT_mX_mXY_Z, TR_0_0_12) });

    /** Space group 187. */
    public static final SpaceGroup SG187 = new SpaceGroup(187, "P-6m2",
            HEXAGONAL, LG6mmm, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_XmY_Z, TR_0_0_0),
                    new Generator(ROT_mXY_mX_Z, TR_0_0_0),
                    new Generator(ROT_X_Y_mZ, TR_0_0_0),
                    new Generator(ROT_mY_XmY_mZ, TR_0_0_0),
                    new Generator(ROT_mXY_mX_mZ, TR_0_0_0),
                    new Generator(ROT_mY_mX_Z, TR_0_0_0),
                    new Generator(ROT_mXY_Y_Z, TR_0_0_0),
                    new Generator(ROT_X_XmY_Z, TR_0_0_0),
                    new Generator(ROT_mY_mX_mZ, TR_0_0_0),
                    new Generator(ROT_mXY_Y_mZ, TR_0_0_0),
                    new Generator(ROT_X_XmY_mZ, TR_0_0_0) });

    /** Space group 188. */
    public static final SpaceGroup SG188 = new SpaceGroup(188, "P-6c2",
            HEXAGONAL, LG6mmm, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_XmY_Z, TR_0_0_0),
                    new Generator(ROT_mXY_mX_Z, TR_0_0_0),
                    new Generator(ROT_X_Y_mZ, TR_0_0_12),
                    new Generator(ROT_mY_XmY_mZ, TR_0_0_12),
                    new Generator(ROT_mXY_mX_mZ, TR_0_0_12),
                    new Generator(ROT_mY_mX_Z, TR_0_0_12),
                    new Generator(ROT_mXY_Y_Z, TR_0_0_12),
                    new Generator(ROT_X_XmY_Z, TR_0_0_12),
                    new Generator(ROT_mY_mX_mZ, TR_0_0_0),
                    new Generator(ROT_mXY_Y_mZ, TR_0_0_0),
                    new Generator(ROT_X_XmY_mZ, TR_0_0_0) });

    /** Space group 189. */
    public static final SpaceGroup SG189 = new SpaceGroup(189, "P-62m",
            HEXAGONAL, LG6mmm, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_XmY_Z, TR_0_0_0),
                    new Generator(ROT_mXY_mX_Z, TR_0_0_0),
                    new Generator(ROT_X_Y_mZ, TR_0_0_0),
                    new Generator(ROT_mY_XmY_mZ, TR_0_0_0),
                    new Generator(ROT_mXY_mX_mZ, TR_0_0_0),
                    new Generator(ROT_Y_X_mZ, TR_0_0_0),
                    new Generator(ROT_XmY_mY_mZ, TR_0_0_0),
                    new Generator(ROT_mX_mXY_mZ, TR_0_0_0),
                    new Generator(ROT_Y_X_Z, TR_0_0_0),
                    new Generator(ROT_XmY_mY_Z, TR_0_0_0),
                    new Generator(ROT_mX_mXY_Z, TR_0_0_0) });

    /** Space group 190. */
    public static final SpaceGroup SG190 = new SpaceGroup(190, "P-62c",
            HEXAGONAL, LG6mmm, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_XmY_Z, TR_0_0_0),
                    new Generator(ROT_mXY_mX_Z, TR_0_0_0),
                    new Generator(ROT_X_Y_mZ, TR_0_0_12),
                    new Generator(ROT_mY_XmY_mZ, TR_0_0_12),
                    new Generator(ROT_mXY_mX_mZ, TR_0_0_12),
                    new Generator(ROT_Y_X_mZ, TR_0_0_0),
                    new Generator(ROT_XmY_mY_mZ, TR_0_0_0),
                    new Generator(ROT_mX_mXY_mZ, TR_0_0_0),
                    new Generator(ROT_Y_X_Z, TR_0_0_12),
                    new Generator(ROT_XmY_mY_Z, TR_0_0_12),
                    new Generator(ROT_mX_mXY_Z, TR_0_0_12) });

    /** Space group 191. */
    public static final SpaceGroup SG191 = new SpaceGroup(191, "P6/mmm",
            HEXAGONAL, LG6mmm, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_XmY_Z, TR_0_0_0),
                    new Generator(ROT_mXY_mX_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_Y_mXY_Z, TR_0_0_0),
                    new Generator(ROT_XmY_X_Z, TR_0_0_0),
                    new Generator(ROT_Y_X_mZ, TR_0_0_0),
                    new Generator(ROT_XmY_mY_mZ, TR_0_0_0),
                    new Generator(ROT_mX_mXY_mZ, TR_0_0_0),
                    new Generator(ROT_mY_mX_mZ, TR_0_0_0),
                    new Generator(ROT_mXY_Y_mZ, TR_0_0_0),
                    new Generator(ROT_X_XmY_mZ, TR_0_0_0),
                    new Generator(ROT_mX_mY_mZ, TR_0_0_0),
                    new Generator(ROT_Y_mXY_mZ, TR_0_0_0),
                    new Generator(ROT_XmY_X_mZ, TR_0_0_0),
                    new Generator(ROT_X_Y_mZ, TR_0_0_0),
                    new Generator(ROT_mXY_mX_mZ, TR_0_0_0),
                    new Generator(ROT_mY_XmY_mZ, TR_0_0_0),
                    new Generator(ROT_mY_mX_Z, TR_0_0_0),
                    new Generator(ROT_mXY_Y_Z, TR_0_0_0),
                    new Generator(ROT_X_XmY_Z, TR_0_0_0),
                    new Generator(ROT_Y_X_Z, TR_0_0_0),
                    new Generator(ROT_XmY_mY_Z, TR_0_0_0),
                    new Generator(ROT_mX_mXY_Z, TR_0_0_0) });

    /** Space group 192. */
    public static final SpaceGroup SG192 = new SpaceGroup(192, "P6/mcc",
            HEXAGONAL, LG6mmm, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_XmY_Z, TR_0_0_0),
                    new Generator(ROT_mXY_mX_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_Y_mXY_Z, TR_0_0_0),
                    new Generator(ROT_XmY_X_Z, TR_0_0_0),
                    new Generator(ROT_Y_X_mZ, TR_0_0_12),
                    new Generator(ROT_XmY_mY_mZ, TR_0_0_12),
                    new Generator(ROT_mX_mXY_mZ, TR_0_0_12),
                    new Generator(ROT_mY_mX_mZ, TR_0_0_12),
                    new Generator(ROT_mXY_Y_mZ, TR_0_0_12),
                    new Generator(ROT_X_XmY_mZ, TR_0_0_12),
                    new Generator(ROT_mX_mY_mZ, TR_0_0_0),
                    new Generator(ROT_Y_mXY_mZ, TR_0_0_0),
                    new Generator(ROT_XmY_X_mZ, TR_0_0_0),
                    new Generator(ROT_X_Y_mZ, TR_0_0_0),
                    new Generator(ROT_mXY_mX_mZ, TR_0_0_0),
                    new Generator(ROT_mY_XmY_mZ, TR_0_0_0),
                    new Generator(ROT_mY_mX_Z, TR_0_0_12),
                    new Generator(ROT_mXY_Y_Z, TR_0_0_12),
                    new Generator(ROT_X_XmY_Z, TR_0_0_12),
                    new Generator(ROT_Y_X_Z, TR_0_0_12),
                    new Generator(ROT_XmY_mY_Z, TR_0_0_12),
                    new Generator(ROT_mX_mXY_Z, TR_0_0_12) });

    /** Space group 193. */
    public static final SpaceGroup SG193 = new SpaceGroup(193, "P63/mcm",
            HEXAGONAL, LG6mmm, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_XmY_Z, TR_0_0_0),
                    new Generator(ROT_mXY_mX_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_12),
                    new Generator(ROT_Y_mXY_Z, TR_0_0_12),
                    new Generator(ROT_XmY_X_Z, TR_0_0_12),
                    new Generator(ROT_Y_X_mZ, TR_0_0_12),
                    new Generator(ROT_XmY_mY_mZ, TR_0_0_12),
                    new Generator(ROT_mX_mXY_mZ, TR_0_0_12),
                    new Generator(ROT_mY_mX_mZ, TR_0_0_0),
                    new Generator(ROT_mXY_Y_mZ, TR_0_0_0),
                    new Generator(ROT_X_XmY_mZ, TR_0_0_0),
                    new Generator(ROT_mX_mY_mZ, TR_0_0_0),
                    new Generator(ROT_Y_mXY_mZ, TR_0_0_0),
                    new Generator(ROT_XmY_X_mZ, TR_0_0_0),
                    new Generator(ROT_X_Y_mZ, TR_0_0_12),
                    new Generator(ROT_mXY_mX_mZ, TR_0_0_12),
                    new Generator(ROT_mY_XmY_mZ, TR_0_0_12),
                    new Generator(ROT_mY_mX_Z, TR_0_0_12),
                    new Generator(ROT_mXY_Y_Z, TR_0_0_12),
                    new Generator(ROT_X_XmY_Z, TR_0_0_12),
                    new Generator(ROT_Y_X_Z, TR_0_0_0),
                    new Generator(ROT_XmY_mY_Z, TR_0_0_0),
                    new Generator(ROT_mX_mXY_Z, TR_0_0_0) });

    /** Space group 194. */
    public static final SpaceGroup SG194 = new SpaceGroup(194, "P63/mmc",
            HEXAGONAL, LG6mmm, new Generator[] {
                    new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mY_XmY_Z, TR_0_0_0),
                    new Generator(ROT_mXY_mX_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_12),
                    new Generator(ROT_Y_mXY_Z, TR_0_0_12),
                    new Generator(ROT_XmY_X_Z, TR_0_0_12),
                    new Generator(ROT_Y_X_mZ, TR_0_0_0),
                    new Generator(ROT_XmY_mY_mZ, TR_0_0_0),
                    new Generator(ROT_mX_mXY_mZ, TR_0_0_0),
                    new Generator(ROT_mY_mX_mZ, TR_0_0_12),
                    new Generator(ROT_mXY_Y_mZ, TR_0_0_12),
                    new Generator(ROT_X_XmY_mZ, TR_0_0_12),
                    new Generator(ROT_mX_mY_mZ, TR_0_0_0),
                    new Generator(ROT_Y_mXY_mZ, TR_0_0_0),
                    new Generator(ROT_XmY_X_mZ, TR_0_0_0),
                    new Generator(ROT_X_Y_mZ, TR_0_0_12),
                    new Generator(ROT_mXY_mX_mZ, TR_0_0_12),
                    new Generator(ROT_mY_XmY_mZ, TR_0_0_12),
                    new Generator(ROT_mY_mX_Z, TR_0_0_0),
                    new Generator(ROT_mXY_Y_Z, TR_0_0_0),
                    new Generator(ROT_X_XmY_Z, TR_0_0_0),
                    new Generator(ROT_Y_X_Z, TR_0_0_12),
                    new Generator(ROT_XmY_mY_Z, TR_0_0_12),
                    new Generator(ROT_mX_mXY_Z, TR_0_0_12) });

    /** Space group 195. */
    public static final SpaceGroup SG195 = new SpaceGroup(195, "P23", CUBIC,
            LGm3, new Generator[] { new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mX_Y_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_mZ, TR_0_0_0),
                    new Generator(ROT_Z_X_Y, TR_0_0_0),
                    new Generator(ROT_Z_mX_mY, TR_0_0_0),
                    new Generator(ROT_mZ_mX_Y, TR_0_0_0),
                    new Generator(ROT_mZ_X_mY, TR_0_0_0),
                    new Generator(ROT_Y_Z_X, TR_0_0_0),
                    new Generator(ROT_mY_Z_mX, TR_0_0_0),
                    new Generator(ROT_Y_mZ_mX, TR_0_0_0),
                    new Generator(ROT_mY_mZ_X, TR_0_0_0) });

    /** Space group 196. */
    public static final SpaceGroup SG196 = new SpaceGroup(196, "F23", CUBIC,
            LGm3, new Generator[] { new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mX_Y_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_mZ, TR_0_0_0),
                    new Generator(ROT_Z_X_Y, TR_0_0_0),
                    new Generator(ROT_Z_mX_mY, TR_0_0_0),
                    new Generator(ROT_mZ_mX_Y, TR_0_0_0),
                    new Generator(ROT_mZ_X_mY, TR_0_0_0),
                    new Generator(ROT_Y_Z_X, TR_0_0_0),
                    new Generator(ROT_mY_Z_mX, TR_0_0_0),
                    new Generator(ROT_Y_mZ_mX, TR_0_0_0),
                    new Generator(ROT_mY_mZ_X, TR_0_0_0),
                    new Generator(ROT_X_Y_Z, TR_0_12_12),
                    new Generator(ROT_mX_mY_Z, TR_0_12_12),
                    new Generator(ROT_mX_Y_mZ, TR_0_12_12),
                    new Generator(ROT_X_mY_mZ, TR_0_12_12),
                    new Generator(ROT_Z_X_Y, TR_0_12_12),
                    new Generator(ROT_Z_mX_mY, TR_0_12_12),
                    new Generator(ROT_mZ_mX_Y, TR_0_12_12),
                    new Generator(ROT_mZ_X_mY, TR_0_12_12),
                    new Generator(ROT_Y_Z_X, TR_0_12_12),
                    new Generator(ROT_mY_Z_mX, TR_0_12_12),
                    new Generator(ROT_Y_mZ_mX, TR_0_12_12),
                    new Generator(ROT_mY_mZ_X, TR_0_12_12),
                    new Generator(ROT_X_Y_Z, TR_12_0_12),
                    new Generator(ROT_mX_mY_Z, TR_12_0_12),
                    new Generator(ROT_mX_Y_mZ, TR_12_0_12),
                    new Generator(ROT_X_mY_mZ, TR_12_0_12),
                    new Generator(ROT_Z_X_Y, TR_12_0_12),
                    new Generator(ROT_Z_mX_mY, TR_12_0_12),
                    new Generator(ROT_mZ_mX_Y, TR_12_0_12),
                    new Generator(ROT_mZ_X_mY, TR_12_0_12),
                    new Generator(ROT_Y_Z_X, TR_12_0_12),
                    new Generator(ROT_mY_Z_mX, TR_12_0_12),
                    new Generator(ROT_Y_mZ_mX, TR_12_0_12),
                    new Generator(ROT_mY_mZ_X, TR_12_0_12),
                    new Generator(ROT_X_Y_Z, TR_12_12_0),
                    new Generator(ROT_mX_mY_Z, TR_12_12_0),
                    new Generator(ROT_mX_Y_mZ, TR_12_12_0),
                    new Generator(ROT_X_mY_mZ, TR_12_12_0),
                    new Generator(ROT_Z_X_Y, TR_12_12_0),
                    new Generator(ROT_Z_mX_mY, TR_12_12_0),
                    new Generator(ROT_mZ_mX_Y, TR_12_12_0),
                    new Generator(ROT_mZ_X_mY, TR_12_12_0),
                    new Generator(ROT_Y_Z_X, TR_12_12_0),
                    new Generator(ROT_mY_Z_mX, TR_12_12_0),
                    new Generator(ROT_Y_mZ_mX, TR_12_12_0),
                    new Generator(ROT_mY_mZ_X, TR_12_12_0) });

    /** Space group 197. */
    public static final SpaceGroup SG197 = new SpaceGroup(197, "I23", CUBIC,
            LGm3, new Generator[] { new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mX_Y_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_mZ, TR_0_0_0),
                    new Generator(ROT_Z_X_Y, TR_0_0_0),
                    new Generator(ROT_Z_mX_mY, TR_0_0_0),
                    new Generator(ROT_mZ_mX_Y, TR_0_0_0),
                    new Generator(ROT_mZ_X_mY, TR_0_0_0),
                    new Generator(ROT_Y_Z_X, TR_0_0_0),
                    new Generator(ROT_mY_Z_mX, TR_0_0_0),
                    new Generator(ROT_Y_mZ_mX, TR_0_0_0),
                    new Generator(ROT_mY_mZ_X, TR_0_0_0),
                    new Generator(ROT_X_Y_Z, TR_12_12_12),
                    new Generator(ROT_mX_mY_Z, TR_12_12_12),
                    new Generator(ROT_mX_Y_mZ, TR_12_12_12),
                    new Generator(ROT_X_mY_mZ, TR_12_12_12),
                    new Generator(ROT_Z_X_Y, TR_12_12_12),
                    new Generator(ROT_Z_mX_mY, TR_12_12_12),
                    new Generator(ROT_mZ_mX_Y, TR_12_12_12),
                    new Generator(ROT_mZ_X_mY, TR_12_12_12),
                    new Generator(ROT_Y_Z_X, TR_12_12_12),
                    new Generator(ROT_mY_Z_mX, TR_12_12_12),
                    new Generator(ROT_Y_mZ_mX, TR_12_12_12),
                    new Generator(ROT_mY_mZ_X, TR_12_12_12) });

    /** Space group 198. */
    public static final SpaceGroup SG198 = new SpaceGroup(198, "P213", CUBIC,
            LGm3, new Generator[] { new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_12_0_12),
                    new Generator(ROT_mX_Y_mZ, TR_0_12_12),
                    new Generator(ROT_X_mY_mZ, TR_12_12_0),
                    new Generator(ROT_Z_X_Y, TR_0_0_0),
                    new Generator(ROT_Z_mX_mY, TR_12_12_0),
                    new Generator(ROT_mZ_mX_Y, TR_12_0_12),
                    new Generator(ROT_mZ_X_mY, TR_0_12_12),
                    new Generator(ROT_Y_Z_X, TR_0_0_0),
                    new Generator(ROT_mY_Z_mX, TR_0_12_12),
                    new Generator(ROT_Y_mZ_mX, TR_12_12_0),
                    new Generator(ROT_mY_mZ_X, TR_12_0_12) });

    /** Space group 199. */
    public static final SpaceGroup SG199 = new SpaceGroup(199, "I213", CUBIC,
            LGm3, new Generator[] { new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_12_0_12),
                    new Generator(ROT_mX_Y_mZ, TR_0_12_12),
                    new Generator(ROT_X_mY_mZ, TR_12_12_0),
                    new Generator(ROT_Z_X_Y, TR_0_0_0),
                    new Generator(ROT_Z_mX_mY, TR_12_12_0),
                    new Generator(ROT_mZ_mX_Y, TR_12_0_12),
                    new Generator(ROT_mZ_X_mY, TR_0_12_12),
                    new Generator(ROT_Y_Z_X, TR_0_0_0),
                    new Generator(ROT_mY_Z_mX, TR_0_12_12),
                    new Generator(ROT_Y_mZ_mX, TR_12_12_0),
                    new Generator(ROT_mY_mZ_X, TR_12_0_12),
                    new Generator(ROT_X_Y_Z, TR_12_12_12),
                    new Generator(ROT_mX_mY_Z, TR_0_12_0),
                    new Generator(ROT_mX_Y_mZ, TR_12_0_0),
                    new Generator(ROT_X_mY_mZ, TR_0_0_12),
                    new Generator(ROT_Z_X_Y, TR_12_12_12),
                    new Generator(ROT_Z_mX_mY, TR_0_0_12),
                    new Generator(ROT_mZ_mX_Y, TR_0_12_0),
                    new Generator(ROT_mZ_X_mY, TR_12_0_0),
                    new Generator(ROT_Y_Z_X, TR_12_12_12),
                    new Generator(ROT_mY_Z_mX, TR_12_0_0),
                    new Generator(ROT_Y_mZ_mX, TR_0_0_12),
                    new Generator(ROT_mY_mZ_X, TR_0_12_0) });

    /** Space group 200. */
    public static final SpaceGroup SG200 = new SpaceGroup(200, "Pm-3", CUBIC,
            LGm3, new Generator[] { new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mX_Y_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_mZ, TR_0_0_0),
                    new Generator(ROT_Z_X_Y, TR_0_0_0),
                    new Generator(ROT_Z_mX_mY, TR_0_0_0),
                    new Generator(ROT_mZ_mX_Y, TR_0_0_0),
                    new Generator(ROT_mZ_X_mY, TR_0_0_0),
                    new Generator(ROT_Y_Z_X, TR_0_0_0),
                    new Generator(ROT_mY_Z_mX, TR_0_0_0),
                    new Generator(ROT_Y_mZ_mX, TR_0_0_0),
                    new Generator(ROT_mY_mZ_X, TR_0_0_0),
                    new Generator(ROT_mX_mY_mZ, TR_0_0_0),
                    new Generator(ROT_X_Y_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_Z, TR_0_0_0),
                    new Generator(ROT_mX_Y_Z, TR_0_0_0),
                    new Generator(ROT_mZ_mX_mY, TR_0_0_0),
                    new Generator(ROT_mZ_X_Y, TR_0_0_0),
                    new Generator(ROT_Z_X_mY, TR_0_0_0),
                    new Generator(ROT_Z_mX_Y, TR_0_0_0),
                    new Generator(ROT_mY_mZ_mX, TR_0_0_0),
                    new Generator(ROT_Y_mZ_X, TR_0_0_0),
                    new Generator(ROT_mY_Z_X, TR_0_0_0),
                    new Generator(ROT_Y_Z_mX, TR_0_0_0) });

    /** Space group 201. */
    public static final SpaceGroup SG201 = new SpaceGroup(201, "Pn-3", CUBIC,
            LGm3, new Generator[] { new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mX_Y_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_mZ, TR_0_0_0),
                    new Generator(ROT_Z_X_Y, TR_0_0_0),
                    new Generator(ROT_Z_mX_mY, TR_0_0_0),
                    new Generator(ROT_mZ_mX_Y, TR_0_0_0),
                    new Generator(ROT_mZ_X_mY, TR_0_0_0),
                    new Generator(ROT_Y_Z_X, TR_0_0_0),
                    new Generator(ROT_mY_Z_mX, TR_0_0_0),
                    new Generator(ROT_Y_mZ_mX, TR_0_0_0),
                    new Generator(ROT_mY_mZ_X, TR_0_0_0),
                    new Generator(ROT_mX_mY_mZ, TR_12_12_12),
                    new Generator(ROT_X_Y_mZ, TR_12_12_12),
                    new Generator(ROT_X_mY_Z, TR_12_12_12),
                    new Generator(ROT_mX_Y_Z, TR_12_12_12),
                    new Generator(ROT_mZ_mX_mY, TR_12_12_12),
                    new Generator(ROT_mZ_X_Y, TR_12_12_12),
                    new Generator(ROT_Z_X_mY, TR_12_12_12),
                    new Generator(ROT_Z_mX_Y, TR_12_12_12),
                    new Generator(ROT_mY_mZ_mX, TR_12_12_12),
                    new Generator(ROT_Y_mZ_X, TR_12_12_12),
                    new Generator(ROT_mY_Z_X, TR_12_12_12),
                    new Generator(ROT_Y_Z_mX, TR_12_12_12) });

    /** Space group 202. */
    public static final SpaceGroup SG202 = new SpaceGroup(202, "Fm-3", CUBIC,
            LGm3, new Generator[] { new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mX_Y_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_mZ, TR_0_0_0),
                    new Generator(ROT_Z_X_Y, TR_0_0_0),
                    new Generator(ROT_Z_mX_mY, TR_0_0_0),
                    new Generator(ROT_mZ_mX_Y, TR_0_0_0),
                    new Generator(ROT_mZ_X_mY, TR_0_0_0),
                    new Generator(ROT_Y_Z_X, TR_0_0_0),
                    new Generator(ROT_mY_Z_mX, TR_0_0_0),
                    new Generator(ROT_Y_mZ_mX, TR_0_0_0),
                    new Generator(ROT_mY_mZ_X, TR_0_0_0),
                    new Generator(ROT_mX_mY_mZ, TR_0_0_0),
                    new Generator(ROT_X_Y_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_Z, TR_0_0_0),
                    new Generator(ROT_mX_Y_Z, TR_0_0_0),
                    new Generator(ROT_mZ_mX_mY, TR_0_0_0),
                    new Generator(ROT_mZ_X_Y, TR_0_0_0),
                    new Generator(ROT_Z_X_mY, TR_0_0_0),
                    new Generator(ROT_Z_mX_Y, TR_0_0_0),
                    new Generator(ROT_mY_mZ_mX, TR_0_0_0),
                    new Generator(ROT_Y_mZ_X, TR_0_0_0),
                    new Generator(ROT_mY_Z_X, TR_0_0_0),
                    new Generator(ROT_Y_Z_mX, TR_0_0_0),
                    new Generator(ROT_X_Y_Z, TR_0_12_12),
                    new Generator(ROT_mX_mY_Z, TR_0_12_12),
                    new Generator(ROT_mX_Y_mZ, TR_0_12_12),
                    new Generator(ROT_X_mY_mZ, TR_0_12_12),
                    new Generator(ROT_Z_X_Y, TR_0_12_12),
                    new Generator(ROT_Z_mX_mY, TR_0_12_12),
                    new Generator(ROT_mZ_mX_Y, TR_0_12_12),
                    new Generator(ROT_mZ_X_mY, TR_0_12_12),
                    new Generator(ROT_Y_Z_X, TR_0_12_12),
                    new Generator(ROT_mY_Z_mX, TR_0_12_12),
                    new Generator(ROT_Y_mZ_mX, TR_0_12_12),
                    new Generator(ROT_mY_mZ_X, TR_0_12_12),
                    new Generator(ROT_mX_mY_mZ, TR_0_12_12),
                    new Generator(ROT_X_Y_mZ, TR_0_12_12),
                    new Generator(ROT_X_mY_Z, TR_0_12_12),
                    new Generator(ROT_mX_Y_Z, TR_0_12_12),
                    new Generator(ROT_mZ_mX_mY, TR_0_12_12),
                    new Generator(ROT_mZ_X_Y, TR_0_12_12),
                    new Generator(ROT_Z_X_mY, TR_0_12_12),
                    new Generator(ROT_Z_mX_Y, TR_0_12_12),
                    new Generator(ROT_mY_mZ_mX, TR_0_12_12),
                    new Generator(ROT_Y_mZ_X, TR_0_12_12),
                    new Generator(ROT_mY_Z_X, TR_0_12_12),
                    new Generator(ROT_Y_Z_mX, TR_0_12_12),
                    new Generator(ROT_X_Y_Z, TR_12_0_12),
                    new Generator(ROT_mX_mY_Z, TR_12_0_12),
                    new Generator(ROT_mX_Y_mZ, TR_12_0_12),
                    new Generator(ROT_X_mY_mZ, TR_12_0_12),
                    new Generator(ROT_Z_X_Y, TR_12_0_12),
                    new Generator(ROT_Z_mX_mY, TR_12_0_12),
                    new Generator(ROT_mZ_mX_Y, TR_12_0_12),
                    new Generator(ROT_mZ_X_mY, TR_12_0_12),
                    new Generator(ROT_Y_Z_X, TR_12_0_12),
                    new Generator(ROT_mY_Z_mX, TR_12_0_12),
                    new Generator(ROT_Y_mZ_mX, TR_12_0_12),
                    new Generator(ROT_mY_mZ_X, TR_12_0_12),
                    new Generator(ROT_mX_mY_mZ, TR_12_0_12),
                    new Generator(ROT_X_Y_mZ, TR_12_0_12),
                    new Generator(ROT_X_mY_Z, TR_12_0_12),
                    new Generator(ROT_mX_Y_Z, TR_12_0_12),
                    new Generator(ROT_mZ_mX_mY, TR_12_0_12),
                    new Generator(ROT_mZ_X_Y, TR_12_0_12),
                    new Generator(ROT_Z_X_mY, TR_12_0_12),
                    new Generator(ROT_Z_mX_Y, TR_12_0_12),
                    new Generator(ROT_mY_mZ_mX, TR_12_0_12),
                    new Generator(ROT_Y_mZ_X, TR_12_0_12),
                    new Generator(ROT_mY_Z_X, TR_12_0_12),
                    new Generator(ROT_Y_Z_mX, TR_12_0_12),
                    new Generator(ROT_X_Y_Z, TR_12_12_0),
                    new Generator(ROT_mX_mY_Z, TR_12_12_0),
                    new Generator(ROT_mX_Y_mZ, TR_12_12_0),
                    new Generator(ROT_X_mY_mZ, TR_12_12_0),
                    new Generator(ROT_Z_X_Y, TR_12_12_0),
                    new Generator(ROT_Z_mX_mY, TR_12_12_0),
                    new Generator(ROT_mZ_mX_Y, TR_12_12_0),
                    new Generator(ROT_mZ_X_mY, TR_12_12_0),
                    new Generator(ROT_Y_Z_X, TR_12_12_0),
                    new Generator(ROT_mY_Z_mX, TR_12_12_0),
                    new Generator(ROT_Y_mZ_mX, TR_12_12_0),
                    new Generator(ROT_mY_mZ_X, TR_12_12_0),
                    new Generator(ROT_mX_mY_mZ, TR_12_12_0),
                    new Generator(ROT_X_Y_mZ, TR_12_12_0),
                    new Generator(ROT_X_mY_Z, TR_12_12_0),
                    new Generator(ROT_mX_Y_Z, TR_12_12_0),
                    new Generator(ROT_mZ_mX_mY, TR_12_12_0),
                    new Generator(ROT_mZ_X_Y, TR_12_12_0),
                    new Generator(ROT_Z_X_mY, TR_12_12_0),
                    new Generator(ROT_Z_mX_Y, TR_12_12_0),
                    new Generator(ROT_mY_mZ_mX, TR_12_12_0),
                    new Generator(ROT_Y_mZ_X, TR_12_12_0),
                    new Generator(ROT_mY_Z_X, TR_12_12_0),
                    new Generator(ROT_Y_Z_mX, TR_12_12_0) });

    /** Space group 203. */
    public static final SpaceGroup SG203 = new SpaceGroup(203, "Fd-3", CUBIC,
            LGm3, new Generator[] { new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mX_Y_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_mZ, TR_0_0_0),
                    new Generator(ROT_Z_X_Y, TR_0_0_0),
                    new Generator(ROT_Z_mX_mY, TR_0_0_0),
                    new Generator(ROT_mZ_mX_Y, TR_0_0_0),
                    new Generator(ROT_mZ_X_mY, TR_0_0_0),
                    new Generator(ROT_Y_Z_X, TR_0_0_0),
                    new Generator(ROT_mY_Z_mX, TR_0_0_0),
                    new Generator(ROT_Y_mZ_mX, TR_0_0_0),
                    new Generator(ROT_mY_mZ_X, TR_0_0_0),
                    new Generator(ROT_mX_mY_mZ, TR_14_14_14),
                    new Generator(ROT_X_Y_mZ, TR_14_14_14),
                    new Generator(ROT_X_mY_Z, TR_14_14_14),
                    new Generator(ROT_mX_Y_Z, TR_14_14_14),
                    new Generator(ROT_mZ_mX_mY, TR_14_14_14),
                    new Generator(ROT_mZ_X_Y, TR_14_14_14),
                    new Generator(ROT_Z_X_mY, TR_14_14_14),
                    new Generator(ROT_Z_mX_Y, TR_14_14_14),
                    new Generator(ROT_mY_mZ_mX, TR_14_14_14),
                    new Generator(ROT_Y_mZ_X, TR_14_14_14),
                    new Generator(ROT_mY_Z_X, TR_14_14_14),
                    new Generator(ROT_Y_Z_mX, TR_14_14_14),
                    new Generator(ROT_X_Y_Z, TR_0_12_12),
                    new Generator(ROT_mX_mY_Z, TR_0_12_12),
                    new Generator(ROT_mX_Y_mZ, TR_0_12_12),
                    new Generator(ROT_X_mY_mZ, TR_0_12_12),
                    new Generator(ROT_Z_X_Y, TR_0_12_12),
                    new Generator(ROT_Z_mX_mY, TR_0_12_12),
                    new Generator(ROT_mZ_mX_Y, TR_0_12_12),
                    new Generator(ROT_mZ_X_mY, TR_0_12_12),
                    new Generator(ROT_Y_Z_X, TR_0_12_12),
                    new Generator(ROT_mY_Z_mX, TR_0_12_12),
                    new Generator(ROT_Y_mZ_mX, TR_0_12_12),
                    new Generator(ROT_mY_mZ_X, TR_0_12_12),
                    new Generator(ROT_mX_mY_mZ, TR_14_34_34),
                    new Generator(ROT_X_Y_mZ, TR_14_34_34),
                    new Generator(ROT_X_mY_Z, TR_14_34_34),
                    new Generator(ROT_mX_Y_Z, TR_14_34_34),
                    new Generator(ROT_mZ_mX_mY, TR_14_34_34),
                    new Generator(ROT_mZ_X_Y, TR_14_34_34),
                    new Generator(ROT_Z_X_mY, TR_14_34_34),
                    new Generator(ROT_Z_mX_Y, TR_14_34_34),
                    new Generator(ROT_mY_mZ_mX, TR_14_34_34),
                    new Generator(ROT_Y_mZ_X, TR_14_34_34),
                    new Generator(ROT_mY_Z_X, TR_14_34_34),
                    new Generator(ROT_Y_Z_mX, TR_14_34_34),
                    new Generator(ROT_X_Y_Z, TR_12_0_12),
                    new Generator(ROT_mX_mY_Z, TR_12_0_12),
                    new Generator(ROT_mX_Y_mZ, TR_12_0_12),
                    new Generator(ROT_X_mY_mZ, TR_12_0_12),
                    new Generator(ROT_Z_X_Y, TR_12_0_12),
                    new Generator(ROT_Z_mX_mY, TR_12_0_12),
                    new Generator(ROT_mZ_mX_Y, TR_12_0_12),
                    new Generator(ROT_mZ_X_mY, TR_12_0_12),
                    new Generator(ROT_Y_Z_X, TR_12_0_12),
                    new Generator(ROT_mY_Z_mX, TR_12_0_12),
                    new Generator(ROT_Y_mZ_mX, TR_12_0_12),
                    new Generator(ROT_mY_mZ_X, TR_12_0_12),
                    new Generator(ROT_mX_mY_mZ, TR_34_14_34),
                    new Generator(ROT_X_Y_mZ, TR_34_14_34),
                    new Generator(ROT_X_mY_Z, TR_34_14_34),
                    new Generator(ROT_mX_Y_Z, TR_34_14_34),
                    new Generator(ROT_mZ_mX_mY, TR_34_14_34),
                    new Generator(ROT_mZ_X_Y, TR_34_14_34),
                    new Generator(ROT_Z_X_mY, TR_34_14_34),
                    new Generator(ROT_Z_mX_Y, TR_34_14_34),
                    new Generator(ROT_mY_mZ_mX, TR_34_14_34),
                    new Generator(ROT_Y_mZ_X, TR_34_14_34),
                    new Generator(ROT_mY_Z_X, TR_34_14_34),
                    new Generator(ROT_Y_Z_mX, TR_34_14_34),
                    new Generator(ROT_X_Y_Z, TR_12_12_0),
                    new Generator(ROT_mX_mY_Z, TR_12_12_0),
                    new Generator(ROT_mX_Y_mZ, TR_12_12_0),
                    new Generator(ROT_X_mY_mZ, TR_12_12_0),
                    new Generator(ROT_Z_X_Y, TR_12_12_0),
                    new Generator(ROT_Z_mX_mY, TR_12_12_0),
                    new Generator(ROT_mZ_mX_Y, TR_12_12_0),
                    new Generator(ROT_mZ_X_mY, TR_12_12_0),
                    new Generator(ROT_Y_Z_X, TR_12_12_0),
                    new Generator(ROT_mY_Z_mX, TR_12_12_0),
                    new Generator(ROT_Y_mZ_mX, TR_12_12_0),
                    new Generator(ROT_mY_mZ_X, TR_12_12_0),
                    new Generator(ROT_mX_mY_mZ, TR_34_34_14),
                    new Generator(ROT_X_Y_mZ, TR_34_34_14),
                    new Generator(ROT_X_mY_Z, TR_34_34_14),
                    new Generator(ROT_mX_Y_Z, TR_34_34_14),
                    new Generator(ROT_mZ_mX_mY, TR_34_34_14),
                    new Generator(ROT_mZ_X_Y, TR_34_34_14),
                    new Generator(ROT_Z_X_mY, TR_34_34_14),
                    new Generator(ROT_Z_mX_Y, TR_34_34_14),
                    new Generator(ROT_mY_mZ_mX, TR_34_34_14),
                    new Generator(ROT_Y_mZ_X, TR_34_34_14),
                    new Generator(ROT_mY_Z_X, TR_34_34_14),
                    new Generator(ROT_Y_Z_mX, TR_34_34_14) });

    /** Space group 204. */
    public static final SpaceGroup SG204 = new SpaceGroup(204, "Im-3", CUBIC,
            LGm3, new Generator[] { new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mX_Y_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_mZ, TR_0_0_0),
                    new Generator(ROT_Z_X_Y, TR_0_0_0),
                    new Generator(ROT_Z_mX_mY, TR_0_0_0),
                    new Generator(ROT_mZ_mX_Y, TR_0_0_0),
                    new Generator(ROT_mZ_X_mY, TR_0_0_0),
                    new Generator(ROT_Y_Z_X, TR_0_0_0),
                    new Generator(ROT_mY_Z_mX, TR_0_0_0),
                    new Generator(ROT_Y_mZ_mX, TR_0_0_0),
                    new Generator(ROT_mY_mZ_X, TR_0_0_0),
                    new Generator(ROT_mX_mY_mZ, TR_0_0_0),
                    new Generator(ROT_X_Y_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_Z, TR_0_0_0),
                    new Generator(ROT_mX_Y_Z, TR_0_0_0),
                    new Generator(ROT_mZ_mX_mY, TR_0_0_0),
                    new Generator(ROT_mZ_X_Y, TR_0_0_0),
                    new Generator(ROT_Z_X_mY, TR_0_0_0),
                    new Generator(ROT_Z_mX_Y, TR_0_0_0),
                    new Generator(ROT_mY_mZ_mX, TR_0_0_0),
                    new Generator(ROT_Y_mZ_X, TR_0_0_0),
                    new Generator(ROT_mY_Z_X, TR_0_0_0),
                    new Generator(ROT_Y_Z_mX, TR_0_0_0),
                    new Generator(ROT_X_Y_Z, TR_12_12_12),
                    new Generator(ROT_mX_mY_Z, TR_12_12_12),
                    new Generator(ROT_mX_Y_mZ, TR_12_12_12),
                    new Generator(ROT_X_mY_mZ, TR_12_12_12),
                    new Generator(ROT_Z_X_Y, TR_12_12_12),
                    new Generator(ROT_Z_mX_mY, TR_12_12_12),
                    new Generator(ROT_mZ_mX_Y, TR_12_12_12),
                    new Generator(ROT_mZ_X_mY, TR_12_12_12),
                    new Generator(ROT_Y_Z_X, TR_12_12_12),
                    new Generator(ROT_mY_Z_mX, TR_12_12_12),
                    new Generator(ROT_Y_mZ_mX, TR_12_12_12),
                    new Generator(ROT_mY_mZ_X, TR_12_12_12),
                    new Generator(ROT_mX_mY_mZ, TR_12_12_12),
                    new Generator(ROT_X_Y_mZ, TR_12_12_12),
                    new Generator(ROT_X_mY_Z, TR_12_12_12),
                    new Generator(ROT_mX_Y_Z, TR_12_12_12),
                    new Generator(ROT_mZ_mX_mY, TR_12_12_12),
                    new Generator(ROT_mZ_X_Y, TR_12_12_12),
                    new Generator(ROT_Z_X_mY, TR_12_12_12),
                    new Generator(ROT_Z_mX_Y, TR_12_12_12),
                    new Generator(ROT_mY_mZ_mX, TR_12_12_12),
                    new Generator(ROT_Y_mZ_X, TR_12_12_12),
                    new Generator(ROT_mY_Z_X, TR_12_12_12),
                    new Generator(ROT_Y_Z_mX, TR_12_12_12) });

    /** Space group 205. */
    public static final SpaceGroup SG205 = new SpaceGroup(205, "Pa-3", CUBIC,
            LGm3, new Generator[] { new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_12_0_12),
                    new Generator(ROT_mX_Y_mZ, TR_0_12_12),
                    new Generator(ROT_X_mY_mZ, TR_12_12_0),
                    new Generator(ROT_Z_X_Y, TR_0_0_0),
                    new Generator(ROT_Z_mX_mY, TR_12_12_0),
                    new Generator(ROT_mZ_mX_Y, TR_12_0_12),
                    new Generator(ROT_mZ_X_mY, TR_0_12_12),
                    new Generator(ROT_Y_Z_X, TR_0_0_0),
                    new Generator(ROT_mY_Z_mX, TR_0_12_12),
                    new Generator(ROT_Y_mZ_mX, TR_12_12_0),
                    new Generator(ROT_mY_mZ_X, TR_12_0_12),
                    new Generator(ROT_mX_mY_mZ, TR_0_0_0),
                    new Generator(ROT_X_Y_mZ, TR_12_0_12),
                    new Generator(ROT_X_mY_Z, TR_0_12_12),
                    new Generator(ROT_mX_Y_Z, TR_12_12_0),
                    new Generator(ROT_mZ_mX_mY, TR_0_0_0),
                    new Generator(ROT_mZ_X_Y, TR_12_12_0),
                    new Generator(ROT_Z_X_mY, TR_12_0_12),
                    new Generator(ROT_Z_mX_Y, TR_0_12_12),
                    new Generator(ROT_mY_mZ_mX, TR_0_0_0),
                    new Generator(ROT_Y_mZ_X, TR_0_12_12),
                    new Generator(ROT_mY_Z_X, TR_12_12_0),
                    new Generator(ROT_Y_Z_mX, TR_12_0_12) });

    /** Space group 206. */
    public static final SpaceGroup SG206 = new SpaceGroup(206, "Ia-3", CUBIC,
            LGm3, new Generator[] { new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_12_0_12),
                    new Generator(ROT_mX_Y_mZ, TR_0_12_12),
                    new Generator(ROT_X_mY_mZ, TR_12_12_0),
                    new Generator(ROT_Z_X_Y, TR_0_0_0),
                    new Generator(ROT_Z_mX_mY, TR_12_12_0),
                    new Generator(ROT_mZ_mX_Y, TR_12_0_12),
                    new Generator(ROT_mZ_X_mY, TR_0_12_12),
                    new Generator(ROT_Y_Z_X, TR_0_0_0),
                    new Generator(ROT_mY_Z_mX, TR_0_12_12),
                    new Generator(ROT_Y_mZ_mX, TR_12_12_0),
                    new Generator(ROT_mY_mZ_X, TR_12_0_12),
                    new Generator(ROT_mX_mY_mZ, TR_0_0_0),
                    new Generator(ROT_X_Y_mZ, TR_12_0_12),
                    new Generator(ROT_X_mY_Z, TR_0_12_12),
                    new Generator(ROT_mX_Y_Z, TR_12_12_0),
                    new Generator(ROT_mZ_mX_mY, TR_0_0_0),
                    new Generator(ROT_mZ_X_Y, TR_12_12_0),
                    new Generator(ROT_Z_X_mY, TR_12_0_12),
                    new Generator(ROT_Z_mX_Y, TR_0_12_12),
                    new Generator(ROT_mY_mZ_mX, TR_0_0_0),
                    new Generator(ROT_Y_mZ_X, TR_0_12_12),
                    new Generator(ROT_mY_Z_X, TR_12_12_0),
                    new Generator(ROT_Y_Z_mX, TR_12_0_12),
                    new Generator(ROT_X_Y_Z, TR_12_12_12),
                    new Generator(ROT_mX_mY_Z, TR_0_12_0),
                    new Generator(ROT_mX_Y_mZ, TR_12_0_0),
                    new Generator(ROT_X_mY_mZ, TR_0_0_12),
                    new Generator(ROT_Z_X_Y, TR_12_12_12),
                    new Generator(ROT_Z_mX_mY, TR_0_0_12),
                    new Generator(ROT_mZ_mX_Y, TR_0_12_0),
                    new Generator(ROT_mZ_X_mY, TR_12_0_0),
                    new Generator(ROT_Y_Z_X, TR_12_12_12),
                    new Generator(ROT_mY_Z_mX, TR_12_0_0),
                    new Generator(ROT_Y_mZ_mX, TR_0_0_12),
                    new Generator(ROT_mY_mZ_X, TR_0_12_0),
                    new Generator(ROT_mX_mY_mZ, TR_12_12_12),
                    new Generator(ROT_X_Y_mZ, TR_0_12_0),
                    new Generator(ROT_X_mY_Z, TR_12_0_0),
                    new Generator(ROT_mX_Y_Z, TR_0_0_12),
                    new Generator(ROT_mZ_mX_mY, TR_12_12_12),
                    new Generator(ROT_mZ_X_Y, TR_0_0_12),
                    new Generator(ROT_Z_X_mY, TR_0_12_0),
                    new Generator(ROT_Z_mX_Y, TR_12_0_0),
                    new Generator(ROT_mY_mZ_mX, TR_12_12_12),
                    new Generator(ROT_Y_mZ_X, TR_12_0_0),
                    new Generator(ROT_mY_Z_X, TR_0_0_12),
                    new Generator(ROT_Y_Z_mX, TR_0_12_0) });

    /** Space group 207. */
    public static final SpaceGroup SG207 = new SpaceGroup(207, "P432", CUBIC,
            LGm3m, new Generator[] { new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mX_Y_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_mZ, TR_0_0_0),
                    new Generator(ROT_Z_X_Y, TR_0_0_0),
                    new Generator(ROT_Z_mX_mY, TR_0_0_0),
                    new Generator(ROT_mZ_mX_Y, TR_0_0_0),
                    new Generator(ROT_mZ_X_mY, TR_0_0_0),
                    new Generator(ROT_Y_Z_X, TR_0_0_0),
                    new Generator(ROT_mY_Z_mX, TR_0_0_0),
                    new Generator(ROT_Y_mZ_mX, TR_0_0_0),
                    new Generator(ROT_mY_mZ_X, TR_0_0_0),
                    new Generator(ROT_Y_X_mZ, TR_0_0_0),
                    new Generator(ROT_mY_mX_mZ, TR_0_0_0),
                    new Generator(ROT_Y_mX_Z, TR_0_0_0),
                    new Generator(ROT_mY_X_Z, TR_0_0_0),
                    new Generator(ROT_X_Z_mY, TR_0_0_0),
                    new Generator(ROT_mX_Z_Y, TR_0_0_0),
                    new Generator(ROT_mX_mZ_mY, TR_0_0_0),
                    new Generator(ROT_X_mZ_Y, TR_0_0_0),
                    new Generator(ROT_Z_Y_mX, TR_0_0_0),
                    new Generator(ROT_Z_mY_X, TR_0_0_0),
                    new Generator(ROT_mZ_Y_X, TR_0_0_0),
                    new Generator(ROT_mZ_mY_mX, TR_0_0_0) });

    /** Space group 208. */
    public static final SpaceGroup SG208 = new SpaceGroup(208, "P4232", CUBIC,
            LGm3m, new Generator[] { new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mX_Y_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_mZ, TR_0_0_0),
                    new Generator(ROT_Z_X_Y, TR_0_0_0),
                    new Generator(ROT_Z_mX_mY, TR_0_0_0),
                    new Generator(ROT_mZ_mX_Y, TR_0_0_0),
                    new Generator(ROT_mZ_X_mY, TR_0_0_0),
                    new Generator(ROT_Y_Z_X, TR_0_0_0),
                    new Generator(ROT_mY_Z_mX, TR_0_0_0),
                    new Generator(ROT_Y_mZ_mX, TR_0_0_0),
                    new Generator(ROT_mY_mZ_X, TR_0_0_0),
                    new Generator(ROT_Y_X_mZ, TR_12_12_12),
                    new Generator(ROT_mY_mX_mZ, TR_12_12_12),
                    new Generator(ROT_Y_mX_Z, TR_12_12_12),
                    new Generator(ROT_mY_X_Z, TR_12_12_12),
                    new Generator(ROT_X_Z_mY, TR_12_12_12),
                    new Generator(ROT_mX_Z_Y, TR_12_12_12),
                    new Generator(ROT_mX_mZ_mY, TR_12_12_12),
                    new Generator(ROT_X_mZ_Y, TR_12_12_12),
                    new Generator(ROT_Z_Y_mX, TR_12_12_12),
                    new Generator(ROT_Z_mY_X, TR_12_12_12),
                    new Generator(ROT_mZ_Y_X, TR_12_12_12),
                    new Generator(ROT_mZ_mY_mX, TR_12_12_12) });

    /** Space group 209. */
    public static final SpaceGroup SG209 = new SpaceGroup(209, "F432", CUBIC,
            LGm3m, new Generator[] { new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mX_Y_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_mZ, TR_0_0_0),
                    new Generator(ROT_Z_X_Y, TR_0_0_0),
                    new Generator(ROT_Z_mX_mY, TR_0_0_0),
                    new Generator(ROT_mZ_mX_Y, TR_0_0_0),
                    new Generator(ROT_mZ_X_mY, TR_0_0_0),
                    new Generator(ROT_Y_Z_X, TR_0_0_0),
                    new Generator(ROT_mY_Z_mX, TR_0_0_0),
                    new Generator(ROT_Y_mZ_mX, TR_0_0_0),
                    new Generator(ROT_mY_mZ_X, TR_0_0_0),
                    new Generator(ROT_Y_X_mZ, TR_0_0_0),
                    new Generator(ROT_mY_mX_mZ, TR_0_0_0),
                    new Generator(ROT_Y_mX_Z, TR_0_0_0),
                    new Generator(ROT_mY_X_Z, TR_0_0_0),
                    new Generator(ROT_X_Z_mY, TR_0_0_0),
                    new Generator(ROT_mX_Z_Y, TR_0_0_0),
                    new Generator(ROT_mX_mZ_mY, TR_0_0_0),
                    new Generator(ROT_X_mZ_Y, TR_0_0_0),
                    new Generator(ROT_Z_Y_mX, TR_0_0_0),
                    new Generator(ROT_Z_mY_X, TR_0_0_0),
                    new Generator(ROT_mZ_Y_X, TR_0_0_0),
                    new Generator(ROT_mZ_mY_mX, TR_0_0_0),
                    new Generator(ROT_X_Y_Z, TR_0_12_12),
                    new Generator(ROT_mX_mY_Z, TR_0_12_12),
                    new Generator(ROT_mX_Y_mZ, TR_0_12_12),
                    new Generator(ROT_X_mY_mZ, TR_0_12_12),
                    new Generator(ROT_Z_X_Y, TR_0_12_12),
                    new Generator(ROT_Z_mX_mY, TR_0_12_12),
                    new Generator(ROT_mZ_mX_Y, TR_0_12_12),
                    new Generator(ROT_mZ_X_mY, TR_0_12_12),
                    new Generator(ROT_Y_Z_X, TR_0_12_12),
                    new Generator(ROT_mY_Z_mX, TR_0_12_12),
                    new Generator(ROT_Y_mZ_mX, TR_0_12_12),
                    new Generator(ROT_mY_mZ_X, TR_0_12_12),
                    new Generator(ROT_Y_X_mZ, TR_0_12_12),
                    new Generator(ROT_mY_mX_mZ, TR_0_12_12),
                    new Generator(ROT_Y_mX_Z, TR_0_12_12),
                    new Generator(ROT_mY_X_Z, TR_0_12_12),
                    new Generator(ROT_X_Z_mY, TR_0_12_12),
                    new Generator(ROT_mX_Z_Y, TR_0_12_12),
                    new Generator(ROT_mX_mZ_mY, TR_0_12_12),
                    new Generator(ROT_X_mZ_Y, TR_0_12_12),
                    new Generator(ROT_Z_Y_mX, TR_0_12_12),
                    new Generator(ROT_Z_mY_X, TR_0_12_12),
                    new Generator(ROT_mZ_Y_X, TR_0_12_12),
                    new Generator(ROT_mZ_mY_mX, TR_0_12_12),
                    new Generator(ROT_X_Y_Z, TR_12_0_12),
                    new Generator(ROT_mX_mY_Z, TR_12_0_12),
                    new Generator(ROT_mX_Y_mZ, TR_12_0_12),
                    new Generator(ROT_X_mY_mZ, TR_12_0_12),
                    new Generator(ROT_Z_X_Y, TR_12_0_12),
                    new Generator(ROT_Z_mX_mY, TR_12_0_12),
                    new Generator(ROT_mZ_mX_Y, TR_12_0_12),
                    new Generator(ROT_mZ_X_mY, TR_12_0_12),
                    new Generator(ROT_Y_Z_X, TR_12_0_12),
                    new Generator(ROT_mY_Z_mX, TR_12_0_12),
                    new Generator(ROT_Y_mZ_mX, TR_12_0_12),
                    new Generator(ROT_mY_mZ_X, TR_12_0_12),
                    new Generator(ROT_Y_X_mZ, TR_12_0_12),
                    new Generator(ROT_mY_mX_mZ, TR_12_0_12),
                    new Generator(ROT_Y_mX_Z, TR_12_0_12),
                    new Generator(ROT_mY_X_Z, TR_12_0_12),
                    new Generator(ROT_X_Z_mY, TR_12_0_12),
                    new Generator(ROT_mX_Z_Y, TR_12_0_12),
                    new Generator(ROT_mX_mZ_mY, TR_12_0_12),
                    new Generator(ROT_X_mZ_Y, TR_12_0_12),
                    new Generator(ROT_Z_Y_mX, TR_12_0_12),
                    new Generator(ROT_Z_mY_X, TR_12_0_12),
                    new Generator(ROT_mZ_Y_X, TR_12_0_12),
                    new Generator(ROT_mZ_mY_mX, TR_12_0_12),
                    new Generator(ROT_X_Y_Z, TR_12_12_0),
                    new Generator(ROT_mX_mY_Z, TR_12_12_0),
                    new Generator(ROT_mX_Y_mZ, TR_12_12_0),
                    new Generator(ROT_X_mY_mZ, TR_12_12_0),
                    new Generator(ROT_Z_X_Y, TR_12_12_0),
                    new Generator(ROT_Z_mX_mY, TR_12_12_0),
                    new Generator(ROT_mZ_mX_Y, TR_12_12_0),
                    new Generator(ROT_mZ_X_mY, TR_12_12_0),
                    new Generator(ROT_Y_Z_X, TR_12_12_0),
                    new Generator(ROT_mY_Z_mX, TR_12_12_0),
                    new Generator(ROT_Y_mZ_mX, TR_12_12_0),
                    new Generator(ROT_mY_mZ_X, TR_12_12_0),
                    new Generator(ROT_Y_X_mZ, TR_12_12_0),
                    new Generator(ROT_mY_mX_mZ, TR_12_12_0),
                    new Generator(ROT_Y_mX_Z, TR_12_12_0),
                    new Generator(ROT_mY_X_Z, TR_12_12_0),
                    new Generator(ROT_X_Z_mY, TR_12_12_0),
                    new Generator(ROT_mX_Z_Y, TR_12_12_0),
                    new Generator(ROT_mX_mZ_mY, TR_12_12_0),
                    new Generator(ROT_X_mZ_Y, TR_12_12_0),
                    new Generator(ROT_Z_Y_mX, TR_12_12_0),
                    new Generator(ROT_Z_mY_X, TR_12_12_0),
                    new Generator(ROT_mZ_Y_X, TR_12_12_0),
                    new Generator(ROT_mZ_mY_mX, TR_12_12_0) });

    /** Space group 210. */
    public static final SpaceGroup SG210 = new SpaceGroup(210, "F4132", CUBIC,
            LGm3m, new Generator[] { new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_12_12),
                    new Generator(ROT_mX_Y_mZ, TR_12_12_0),
                    new Generator(ROT_X_mY_mZ, TR_12_0_12),
                    new Generator(ROT_Z_X_Y, TR_0_0_0),
                    new Generator(ROT_Z_mX_mY, TR_12_0_12),
                    new Generator(ROT_mZ_mX_Y, TR_0_12_12),
                    new Generator(ROT_mZ_X_mY, TR_12_12_0),
                    new Generator(ROT_Y_Z_X, TR_0_0_0),
                    new Generator(ROT_mY_Z_mX, TR_12_12_0),
                    new Generator(ROT_Y_mZ_mX, TR_12_0_12),
                    new Generator(ROT_mY_mZ_X, TR_0_12_12),
                    new Generator(ROT_Y_X_mZ, TR_34_14_34),
                    new Generator(ROT_mY_mX_mZ, TR_14_14_14),
                    new Generator(ROT_Y_mX_Z, TR_14_34_34),
                    new Generator(ROT_mY_X_Z, TR_34_34_14),
                    new Generator(ROT_X_Z_mY, TR_34_14_34),
                    new Generator(ROT_mX_Z_Y, TR_34_34_14),
                    new Generator(ROT_mX_mZ_mY, TR_14_14_14),
                    new Generator(ROT_X_mZ_Y, TR_14_34_34),
                    new Generator(ROT_Z_Y_mX, TR_34_14_34),
                    new Generator(ROT_Z_mY_X, TR_14_34_34),
                    new Generator(ROT_mZ_Y_X, TR_34_34_14),
                    new Generator(ROT_mZ_mY_mX, TR_14_14_14),
                    new Generator(ROT_X_Y_Z, TR_0_12_12),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mX_Y_mZ, TR_12_0_12),
                    new Generator(ROT_X_mY_mZ, TR_12_12_0),
                    new Generator(ROT_Z_X_Y, TR_0_12_12),
                    new Generator(ROT_Z_mX_mY, TR_12_12_0),
                    new Generator(ROT_mZ_mX_Y, TR_0_0_0),
                    new Generator(ROT_mZ_X_mY, TR_12_0_12),
                    new Generator(ROT_Y_Z_X, TR_0_12_12),
                    new Generator(ROT_mY_Z_mX, TR_12_0_12),
                    new Generator(ROT_Y_mZ_mX, TR_12_12_0),
                    new Generator(ROT_mY_mZ_X, TR_0_0_0),
                    new Generator(ROT_Y_X_mZ, TR_34_34_14),
                    new Generator(ROT_mY_mX_mZ, TR_14_34_34),
                    new Generator(ROT_Y_mX_Z, TR_14_14_14),
                    new Generator(ROT_mY_X_Z, TR_34_14_34),
                    new Generator(ROT_X_Z_mY, TR_34_34_14),
                    new Generator(ROT_mX_Z_Y, TR_34_14_34),
                    new Generator(ROT_mX_mZ_mY, TR_14_34_34),
                    new Generator(ROT_X_mZ_Y, TR_14_14_14),
                    new Generator(ROT_Z_Y_mX, TR_34_34_14),
                    new Generator(ROT_Z_mY_X, TR_14_14_14),
                    new Generator(ROT_mZ_Y_X, TR_34_14_34),
                    new Generator(ROT_mZ_mY_mX, TR_14_34_34),
                    new Generator(ROT_X_Y_Z, TR_12_0_12),
                    new Generator(ROT_mX_mY_Z, TR_12_12_0),
                    new Generator(ROT_mX_Y_mZ, TR_0_12_12),
                    new Generator(ROT_X_mY_mZ, TR_0_0_0),
                    new Generator(ROT_Z_X_Y, TR_12_0_12),
                    new Generator(ROT_Z_mX_mY, TR_0_0_0),
                    new Generator(ROT_mZ_mX_Y, TR_12_12_0),
                    new Generator(ROT_mZ_X_mY, TR_0_12_12),
                    new Generator(ROT_Y_Z_X, TR_12_0_12),
                    new Generator(ROT_mY_Z_mX, TR_0_12_12),
                    new Generator(ROT_Y_mZ_mX, TR_0_0_0),
                    new Generator(ROT_mY_mZ_X, TR_12_12_0),
                    new Generator(ROT_Y_X_mZ, TR_14_14_14),
                    new Generator(ROT_mY_mX_mZ, TR_34_14_34),
                    new Generator(ROT_Y_mX_Z, TR_34_34_14),
                    new Generator(ROT_mY_X_Z, TR_14_34_34),
                    new Generator(ROT_X_Z_mY, TR_14_14_14),
                    new Generator(ROT_mX_Z_Y, TR_14_34_34),
                    new Generator(ROT_mX_mZ_mY, TR_34_14_34),
                    new Generator(ROT_X_mZ_Y, TR_34_34_14),
                    new Generator(ROT_Z_Y_mX, TR_14_14_14),
                    new Generator(ROT_Z_mY_X, TR_34_34_14),
                    new Generator(ROT_mZ_Y_X, TR_14_34_34),
                    new Generator(ROT_mZ_mY_mX, TR_34_14_34),
                    new Generator(ROT_X_Y_Z, TR_12_12_0),
                    new Generator(ROT_mX_mY_Z, TR_12_0_12),
                    new Generator(ROT_mX_Y_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_mZ, TR_0_12_12),
                    new Generator(ROT_Z_X_Y, TR_12_12_0),
                    new Generator(ROT_Z_mX_mY, TR_0_12_12),
                    new Generator(ROT_mZ_mX_Y, TR_12_0_12),
                    new Generator(ROT_mZ_X_mY, TR_0_0_0),
                    new Generator(ROT_Y_Z_X, TR_12_12_0),
                    new Generator(ROT_mY_Z_mX, TR_0_0_0),
                    new Generator(ROT_Y_mZ_mX, TR_0_12_12),
                    new Generator(ROT_mY_mZ_X, TR_12_0_12),
                    new Generator(ROT_Y_X_mZ, TR_14_34_34),
                    new Generator(ROT_mY_mX_mZ, TR_34_34_14),
                    new Generator(ROT_Y_mX_Z, TR_34_14_34),
                    new Generator(ROT_mY_X_Z, TR_14_14_14),
                    new Generator(ROT_X_Z_mY, TR_14_34_34),
                    new Generator(ROT_mX_Z_Y, TR_14_14_14),
                    new Generator(ROT_mX_mZ_mY, TR_34_34_14),
                    new Generator(ROT_X_mZ_Y, TR_34_14_34),
                    new Generator(ROT_Z_Y_mX, TR_14_34_34),
                    new Generator(ROT_Z_mY_X, TR_34_14_34),
                    new Generator(ROT_mZ_Y_X, TR_14_14_14),
                    new Generator(ROT_mZ_mY_mX, TR_34_34_14) });

    /** Space group 211. */
    public static final SpaceGroup SG211 = new SpaceGroup(211, "I432", CUBIC,
            LGm3m, new Generator[] { new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mX_Y_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_mZ, TR_0_0_0),
                    new Generator(ROT_Z_X_Y, TR_0_0_0),
                    new Generator(ROT_Z_mX_mY, TR_0_0_0),
                    new Generator(ROT_mZ_mX_Y, TR_0_0_0),
                    new Generator(ROT_mZ_X_mY, TR_0_0_0),
                    new Generator(ROT_Y_Z_X, TR_0_0_0),
                    new Generator(ROT_mY_Z_mX, TR_0_0_0),
                    new Generator(ROT_Y_mZ_mX, TR_0_0_0),
                    new Generator(ROT_mY_mZ_X, TR_0_0_0),
                    new Generator(ROT_Y_X_mZ, TR_0_0_0),
                    new Generator(ROT_mY_mX_mZ, TR_0_0_0),
                    new Generator(ROT_Y_mX_Z, TR_0_0_0),
                    new Generator(ROT_mY_X_Z, TR_0_0_0),
                    new Generator(ROT_X_Z_mY, TR_0_0_0),
                    new Generator(ROT_mX_Z_Y, TR_0_0_0),
                    new Generator(ROT_mX_mZ_mY, TR_0_0_0),
                    new Generator(ROT_X_mZ_Y, TR_0_0_0),
                    new Generator(ROT_Z_Y_mX, TR_0_0_0),
                    new Generator(ROT_Z_mY_X, TR_0_0_0),
                    new Generator(ROT_mZ_Y_X, TR_0_0_0),
                    new Generator(ROT_mZ_mY_mX, TR_0_0_0),
                    new Generator(ROT_X_Y_Z, TR_12_12_12),
                    new Generator(ROT_mX_mY_Z, TR_12_12_12),
                    new Generator(ROT_mX_Y_mZ, TR_12_12_12),
                    new Generator(ROT_X_mY_mZ, TR_12_12_12),
                    new Generator(ROT_Z_X_Y, TR_12_12_12),
                    new Generator(ROT_Z_mX_mY, TR_12_12_12),
                    new Generator(ROT_mZ_mX_Y, TR_12_12_12),
                    new Generator(ROT_mZ_X_mY, TR_12_12_12),
                    new Generator(ROT_Y_Z_X, TR_12_12_12),
                    new Generator(ROT_mY_Z_mX, TR_12_12_12),
                    new Generator(ROT_Y_mZ_mX, TR_12_12_12),
                    new Generator(ROT_mY_mZ_X, TR_12_12_12),
                    new Generator(ROT_Y_X_mZ, TR_12_12_12),
                    new Generator(ROT_mY_mX_mZ, TR_12_12_12),
                    new Generator(ROT_Y_mX_Z, TR_12_12_12),
                    new Generator(ROT_mY_X_Z, TR_12_12_12),
                    new Generator(ROT_X_Z_mY, TR_12_12_12),
                    new Generator(ROT_mX_Z_Y, TR_12_12_12),
                    new Generator(ROT_mX_mZ_mY, TR_12_12_12),
                    new Generator(ROT_X_mZ_Y, TR_12_12_12),
                    new Generator(ROT_Z_Y_mX, TR_12_12_12),
                    new Generator(ROT_Z_mY_X, TR_12_12_12),
                    new Generator(ROT_mZ_Y_X, TR_12_12_12),
                    new Generator(ROT_mZ_mY_mX, TR_12_12_12) });

    /** Space group 212. */
    public static final SpaceGroup SG212 = new SpaceGroup(212, "P4332", CUBIC,
            LGm3m, new Generator[] { new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_12_0_12),
                    new Generator(ROT_mX_Y_mZ, TR_0_12_12),
                    new Generator(ROT_X_mY_mZ, TR_12_12_0),
                    new Generator(ROT_Z_X_Y, TR_0_0_0),
                    new Generator(ROT_Z_mX_mY, TR_12_12_0),
                    new Generator(ROT_mZ_mX_Y, TR_12_0_12),
                    new Generator(ROT_mZ_X_mY, TR_0_12_12),
                    new Generator(ROT_Y_Z_X, TR_0_0_0),
                    new Generator(ROT_mY_Z_mX, TR_0_12_12),
                    new Generator(ROT_Y_mZ_mX, TR_12_12_0),
                    new Generator(ROT_mY_mZ_X, TR_12_0_12),
                    new Generator(ROT_Y_X_mZ, TR_14_34_34),
                    new Generator(ROT_mY_mX_mZ, TR_14_14_14),
                    new Generator(ROT_Y_mX_Z, TR_34_34_14),
                    new Generator(ROT_mY_X_Z, TR_34_14_34),
                    new Generator(ROT_X_Z_mY, TR_14_34_34),
                    new Generator(ROT_mX_Z_Y, TR_34_14_34),
                    new Generator(ROT_mX_mZ_mY, TR_14_14_14),
                    new Generator(ROT_X_mZ_Y, TR_34_34_14),
                    new Generator(ROT_Z_Y_mX, TR_14_34_34),
                    new Generator(ROT_Z_mY_X, TR_34_34_14),
                    new Generator(ROT_mZ_Y_X, TR_34_14_34),
                    new Generator(ROT_mZ_mY_mX, TR_14_14_14) });

    /** Space group 213. */
    public static final SpaceGroup SG213 = new SpaceGroup(213, "P4132", CUBIC,
            LGm3m, new Generator[] { new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_12_0_12),
                    new Generator(ROT_mX_Y_mZ, TR_0_12_12),
                    new Generator(ROT_X_mY_mZ, TR_12_12_0),
                    new Generator(ROT_Z_X_Y, TR_0_0_0),
                    new Generator(ROT_Z_mX_mY, TR_12_12_0),
                    new Generator(ROT_mZ_mX_Y, TR_12_0_12),
                    new Generator(ROT_mZ_X_mY, TR_0_12_12),
                    new Generator(ROT_Y_Z_X, TR_0_0_0),
                    new Generator(ROT_mY_Z_mX, TR_0_12_12),
                    new Generator(ROT_Y_mZ_mX, TR_12_12_0),
                    new Generator(ROT_mY_mZ_X, TR_12_0_12),
                    new Generator(ROT_Y_X_mZ, TR_34_14_14),
                    new Generator(ROT_mY_mX_mZ, TR_34_34_34),
                    new Generator(ROT_Y_mX_Z, TR_14_14_34),
                    new Generator(ROT_mY_X_Z, TR_14_34_14),
                    new Generator(ROT_X_Z_mY, TR_34_14_14),
                    new Generator(ROT_mX_Z_Y, TR_14_34_14),
                    new Generator(ROT_mX_mZ_mY, TR_34_34_34),
                    new Generator(ROT_X_mZ_Y, TR_14_14_34),
                    new Generator(ROT_Z_Y_mX, TR_34_14_14),
                    new Generator(ROT_Z_mY_X, TR_14_14_34),
                    new Generator(ROT_mZ_Y_X, TR_14_34_14),
                    new Generator(ROT_mZ_mY_mX, TR_34_34_34) });

    /** Space group 214. */
    public static final SpaceGroup SG214 = new SpaceGroup(214, "I4132", CUBIC,
            LGm3m, new Generator[] { new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_12_0_12),
                    new Generator(ROT_mX_Y_mZ, TR_0_12_12),
                    new Generator(ROT_X_mY_mZ, TR_12_12_0),
                    new Generator(ROT_Z_X_Y, TR_0_0_0),
                    new Generator(ROT_Z_mX_mY, TR_12_12_0),
                    new Generator(ROT_mZ_mX_Y, TR_12_0_12),
                    new Generator(ROT_mZ_X_mY, TR_0_12_12),
                    new Generator(ROT_Y_Z_X, TR_0_0_0),
                    new Generator(ROT_mY_Z_mX, TR_0_12_12),
                    new Generator(ROT_Y_mZ_mX, TR_12_12_0),
                    new Generator(ROT_mY_mZ_X, TR_12_0_12),
                    new Generator(ROT_Y_X_mZ, TR_34_14_14),
                    new Generator(ROT_mY_mX_mZ, TR_34_34_34),
                    new Generator(ROT_Y_mX_Z, TR_14_14_34),
                    new Generator(ROT_mY_X_Z, TR_14_34_14),
                    new Generator(ROT_X_Z_mY, TR_34_14_14),
                    new Generator(ROT_mX_Z_Y, TR_14_34_14),
                    new Generator(ROT_mX_mZ_mY, TR_34_34_34),
                    new Generator(ROT_X_mZ_Y, TR_14_14_34),
                    new Generator(ROT_Z_Y_mX, TR_34_14_14),
                    new Generator(ROT_Z_mY_X, TR_14_14_34),
                    new Generator(ROT_mZ_Y_X, TR_14_34_14),
                    new Generator(ROT_mZ_mY_mX, TR_34_34_34),
                    new Generator(ROT_X_Y_Z, TR_12_12_12),
                    new Generator(ROT_mX_mY_Z, TR_0_12_0),
                    new Generator(ROT_mX_Y_mZ, TR_12_0_0),
                    new Generator(ROT_X_mY_mZ, TR_0_0_12),
                    new Generator(ROT_Z_X_Y, TR_12_12_12),
                    new Generator(ROT_Z_mX_mY, TR_0_0_12),
                    new Generator(ROT_mZ_mX_Y, TR_0_12_0),
                    new Generator(ROT_mZ_X_mY, TR_12_0_0),
                    new Generator(ROT_Y_Z_X, TR_12_12_12),
                    new Generator(ROT_mY_Z_mX, TR_12_0_0),
                    new Generator(ROT_Y_mZ_mX, TR_0_0_12),
                    new Generator(ROT_mY_mZ_X, TR_0_12_0),
                    new Generator(ROT_Y_X_mZ, TR_14_34_34),
                    new Generator(ROT_mY_mX_mZ, TR_14_14_14),
                    new Generator(ROT_Y_mX_Z, TR_34_34_14),
                    new Generator(ROT_mY_X_Z, TR_34_14_34),
                    new Generator(ROT_X_Z_mY, TR_14_34_34),
                    new Generator(ROT_mX_Z_Y, TR_34_14_34),
                    new Generator(ROT_mX_mZ_mY, TR_14_14_14),
                    new Generator(ROT_X_mZ_Y, TR_34_34_14),
                    new Generator(ROT_Z_Y_mX, TR_14_34_34),
                    new Generator(ROT_Z_mY_X, TR_34_34_14),
                    new Generator(ROT_mZ_Y_X, TR_34_14_34),
                    new Generator(ROT_mZ_mY_mX, TR_14_14_14) });

    /** Space group 215. */
    public static final SpaceGroup SG215 = new SpaceGroup(215, "P-43m", CUBIC,
            LGm3m, new Generator[] { new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mX_Y_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_mZ, TR_0_0_0),
                    new Generator(ROT_Z_X_Y, TR_0_0_0),
                    new Generator(ROT_Z_mX_mY, TR_0_0_0),
                    new Generator(ROT_mZ_mX_Y, TR_0_0_0),
                    new Generator(ROT_mZ_X_mY, TR_0_0_0),
                    new Generator(ROT_Y_Z_X, TR_0_0_0),
                    new Generator(ROT_mY_Z_mX, TR_0_0_0),
                    new Generator(ROT_Y_mZ_mX, TR_0_0_0),
                    new Generator(ROT_mY_mZ_X, TR_0_0_0),
                    new Generator(ROT_Y_X_Z, TR_0_0_0),
                    new Generator(ROT_mY_mX_Z, TR_0_0_0),
                    new Generator(ROT_Y_mX_mZ, TR_0_0_0),
                    new Generator(ROT_mY_X_mZ, TR_0_0_0),
                    new Generator(ROT_X_Z_Y, TR_0_0_0),
                    new Generator(ROT_mX_Z_mY, TR_0_0_0),
                    new Generator(ROT_mX_mZ_Y, TR_0_0_0),
                    new Generator(ROT_X_mZ_mY, TR_0_0_0),
                    new Generator(ROT_Z_Y_X, TR_0_0_0),
                    new Generator(ROT_Z_mY_mX, TR_0_0_0),
                    new Generator(ROT_mZ_Y_mX, TR_0_0_0),
                    new Generator(ROT_mZ_mY_X, TR_0_0_0) });

    /** Space group 216. */
    public static final SpaceGroup SG216 = new SpaceGroup(216, "F-43m", CUBIC,
            LGm3m, new Generator[] { new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mX_Y_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_mZ, TR_0_0_0),
                    new Generator(ROT_Z_X_Y, TR_0_0_0),
                    new Generator(ROT_Z_mX_mY, TR_0_0_0),
                    new Generator(ROT_mZ_mX_Y, TR_0_0_0),
                    new Generator(ROT_mZ_X_mY, TR_0_0_0),
                    new Generator(ROT_Y_Z_X, TR_0_0_0),
                    new Generator(ROT_mY_Z_mX, TR_0_0_0),
                    new Generator(ROT_Y_mZ_mX, TR_0_0_0),
                    new Generator(ROT_mY_mZ_X, TR_0_0_0),
                    new Generator(ROT_Y_X_Z, TR_0_0_0),
                    new Generator(ROT_mY_mX_Z, TR_0_0_0),
                    new Generator(ROT_Y_mX_mZ, TR_0_0_0),
                    new Generator(ROT_mY_X_mZ, TR_0_0_0),
                    new Generator(ROT_X_Z_Y, TR_0_0_0),
                    new Generator(ROT_mX_Z_mY, TR_0_0_0),
                    new Generator(ROT_mX_mZ_Y, TR_0_0_0),
                    new Generator(ROT_X_mZ_mY, TR_0_0_0),
                    new Generator(ROT_Z_Y_X, TR_0_0_0),
                    new Generator(ROT_Z_mY_mX, TR_0_0_0),
                    new Generator(ROT_mZ_Y_mX, TR_0_0_0),
                    new Generator(ROT_mZ_mY_X, TR_0_0_0),
                    new Generator(ROT_X_Y_Z, TR_0_12_12),
                    new Generator(ROT_mX_mY_Z, TR_0_12_12),
                    new Generator(ROT_mX_Y_mZ, TR_0_12_12),
                    new Generator(ROT_X_mY_mZ, TR_0_12_12),
                    new Generator(ROT_Z_X_Y, TR_0_12_12),
                    new Generator(ROT_Z_mX_mY, TR_0_12_12),
                    new Generator(ROT_mZ_mX_Y, TR_0_12_12),
                    new Generator(ROT_mZ_X_mY, TR_0_12_12),
                    new Generator(ROT_Y_Z_X, TR_0_12_12),
                    new Generator(ROT_mY_Z_mX, TR_0_12_12),
                    new Generator(ROT_Y_mZ_mX, TR_0_12_12),
                    new Generator(ROT_mY_mZ_X, TR_0_12_12),
                    new Generator(ROT_Y_X_Z, TR_0_12_12),
                    new Generator(ROT_mY_mX_Z, TR_0_12_12),
                    new Generator(ROT_Y_mX_mZ, TR_0_12_12),
                    new Generator(ROT_mY_X_mZ, TR_0_12_12),
                    new Generator(ROT_X_Z_Y, TR_0_12_12),
                    new Generator(ROT_mX_Z_mY, TR_0_12_12),
                    new Generator(ROT_mX_mZ_Y, TR_0_12_12),
                    new Generator(ROT_X_mZ_mY, TR_0_12_12),
                    new Generator(ROT_Z_Y_X, TR_0_12_12),
                    new Generator(ROT_Z_mY_mX, TR_0_12_12),
                    new Generator(ROT_mZ_Y_mX, TR_0_12_12),
                    new Generator(ROT_mZ_mY_X, TR_0_12_12),
                    new Generator(ROT_X_Y_Z, TR_12_0_12),
                    new Generator(ROT_mX_mY_Z, TR_12_0_12),
                    new Generator(ROT_mX_Y_mZ, TR_12_0_12),
                    new Generator(ROT_X_mY_mZ, TR_12_0_12),
                    new Generator(ROT_Z_X_Y, TR_12_0_12),
                    new Generator(ROT_Z_mX_mY, TR_12_0_12),
                    new Generator(ROT_mZ_mX_Y, TR_12_0_12),
                    new Generator(ROT_mZ_X_mY, TR_12_0_12),
                    new Generator(ROT_Y_Z_X, TR_12_0_12),
                    new Generator(ROT_mY_Z_mX, TR_12_0_12),
                    new Generator(ROT_Y_mZ_mX, TR_12_0_12),
                    new Generator(ROT_mY_mZ_X, TR_12_0_12),
                    new Generator(ROT_Y_X_Z, TR_12_0_12),
                    new Generator(ROT_mY_mX_Z, TR_12_0_12),
                    new Generator(ROT_Y_mX_mZ, TR_12_0_12),
                    new Generator(ROT_mY_X_mZ, TR_12_0_12),
                    new Generator(ROT_X_Z_Y, TR_12_0_12),
                    new Generator(ROT_mX_Z_mY, TR_12_0_12),
                    new Generator(ROT_mX_mZ_Y, TR_12_0_12),
                    new Generator(ROT_X_mZ_mY, TR_12_0_12),
                    new Generator(ROT_Z_Y_X, TR_12_0_12),
                    new Generator(ROT_Z_mY_mX, TR_12_0_12),
                    new Generator(ROT_mZ_Y_mX, TR_12_0_12),
                    new Generator(ROT_mZ_mY_X, TR_12_0_12),
                    new Generator(ROT_X_Y_Z, TR_12_12_0),
                    new Generator(ROT_mX_mY_Z, TR_12_12_0),
                    new Generator(ROT_mX_Y_mZ, TR_12_12_0),
                    new Generator(ROT_X_mY_mZ, TR_12_12_0),
                    new Generator(ROT_Z_X_Y, TR_12_12_0),
                    new Generator(ROT_Z_mX_mY, TR_12_12_0),
                    new Generator(ROT_mZ_mX_Y, TR_12_12_0),
                    new Generator(ROT_mZ_X_mY, TR_12_12_0),
                    new Generator(ROT_Y_Z_X, TR_12_12_0),
                    new Generator(ROT_mY_Z_mX, TR_12_12_0),
                    new Generator(ROT_Y_mZ_mX, TR_12_12_0),
                    new Generator(ROT_mY_mZ_X, TR_12_12_0),
                    new Generator(ROT_Y_X_Z, TR_12_12_0),
                    new Generator(ROT_mY_mX_Z, TR_12_12_0),
                    new Generator(ROT_Y_mX_mZ, TR_12_12_0),
                    new Generator(ROT_mY_X_mZ, TR_12_12_0),
                    new Generator(ROT_X_Z_Y, TR_12_12_0),
                    new Generator(ROT_mX_Z_mY, TR_12_12_0),
                    new Generator(ROT_mX_mZ_Y, TR_12_12_0),
                    new Generator(ROT_X_mZ_mY, TR_12_12_0),
                    new Generator(ROT_Z_Y_X, TR_12_12_0),
                    new Generator(ROT_Z_mY_mX, TR_12_12_0),
                    new Generator(ROT_mZ_Y_mX, TR_12_12_0),
                    new Generator(ROT_mZ_mY_X, TR_12_12_0) });

    /** Space group 217. */
    public static final SpaceGroup SG217 = new SpaceGroup(217, "I-43m", CUBIC,
            LGm3m, new Generator[] { new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mX_Y_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_mZ, TR_0_0_0),
                    new Generator(ROT_Z_X_Y, TR_0_0_0),
                    new Generator(ROT_Z_mX_mY, TR_0_0_0),
                    new Generator(ROT_mZ_mX_Y, TR_0_0_0),
                    new Generator(ROT_mZ_X_mY, TR_0_0_0),
                    new Generator(ROT_Y_Z_X, TR_0_0_0),
                    new Generator(ROT_mY_Z_mX, TR_0_0_0),
                    new Generator(ROT_Y_mZ_mX, TR_0_0_0),
                    new Generator(ROT_mY_mZ_X, TR_0_0_0),
                    new Generator(ROT_Y_X_Z, TR_0_0_0),
                    new Generator(ROT_mY_mX_Z, TR_0_0_0),
                    new Generator(ROT_Y_mX_mZ, TR_0_0_0),
                    new Generator(ROT_mY_X_mZ, TR_0_0_0),
                    new Generator(ROT_X_Z_Y, TR_0_0_0),
                    new Generator(ROT_mX_Z_mY, TR_0_0_0),
                    new Generator(ROT_mX_mZ_Y, TR_0_0_0),
                    new Generator(ROT_X_mZ_mY, TR_0_0_0),
                    new Generator(ROT_Z_Y_X, TR_0_0_0),
                    new Generator(ROT_Z_mY_mX, TR_0_0_0),
                    new Generator(ROT_mZ_Y_mX, TR_0_0_0),
                    new Generator(ROT_mZ_mY_X, TR_0_0_0),
                    new Generator(ROT_X_Y_Z, TR_12_12_12),
                    new Generator(ROT_mX_mY_Z, TR_12_12_12),
                    new Generator(ROT_mX_Y_mZ, TR_12_12_12),
                    new Generator(ROT_X_mY_mZ, TR_12_12_12),
                    new Generator(ROT_Z_X_Y, TR_12_12_12),
                    new Generator(ROT_Z_mX_mY, TR_12_12_12),
                    new Generator(ROT_mZ_mX_Y, TR_12_12_12),
                    new Generator(ROT_mZ_X_mY, TR_12_12_12),
                    new Generator(ROT_Y_Z_X, TR_12_12_12),
                    new Generator(ROT_mY_Z_mX, TR_12_12_12),
                    new Generator(ROT_Y_mZ_mX, TR_12_12_12),
                    new Generator(ROT_mY_mZ_X, TR_12_12_12),
                    new Generator(ROT_Y_X_Z, TR_12_12_12),
                    new Generator(ROT_mY_mX_Z, TR_12_12_12),
                    new Generator(ROT_Y_mX_mZ, TR_12_12_12),
                    new Generator(ROT_mY_X_mZ, TR_12_12_12),
                    new Generator(ROT_X_Z_Y, TR_12_12_12),
                    new Generator(ROT_mX_Z_mY, TR_12_12_12),
                    new Generator(ROT_mX_mZ_Y, TR_12_12_12),
                    new Generator(ROT_X_mZ_mY, TR_12_12_12),
                    new Generator(ROT_Z_Y_X, TR_12_12_12),
                    new Generator(ROT_Z_mY_mX, TR_12_12_12),
                    new Generator(ROT_mZ_Y_mX, TR_12_12_12),
                    new Generator(ROT_mZ_mY_X, TR_12_12_12) });

    /** Space group 218. */
    public static final SpaceGroup SG218 = new SpaceGroup(218, "P-43n", CUBIC,
            LGm3m, new Generator[] { new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mX_Y_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_mZ, TR_0_0_0),
                    new Generator(ROT_Z_X_Y, TR_0_0_0),
                    new Generator(ROT_Z_mX_mY, TR_0_0_0),
                    new Generator(ROT_mZ_mX_Y, TR_0_0_0),
                    new Generator(ROT_mZ_X_mY, TR_0_0_0),
                    new Generator(ROT_Y_Z_X, TR_0_0_0),
                    new Generator(ROT_mY_Z_mX, TR_0_0_0),
                    new Generator(ROT_Y_mZ_mX, TR_0_0_0),
                    new Generator(ROT_mY_mZ_X, TR_0_0_0),
                    new Generator(ROT_Y_X_Z, TR_12_12_12),
                    new Generator(ROT_mY_mX_Z, TR_12_12_12),
                    new Generator(ROT_Y_mX_mZ, TR_12_12_12),
                    new Generator(ROT_mY_X_mZ, TR_12_12_12),
                    new Generator(ROT_X_Z_Y, TR_12_12_12),
                    new Generator(ROT_mX_Z_mY, TR_12_12_12),
                    new Generator(ROT_mX_mZ_Y, TR_12_12_12),
                    new Generator(ROT_X_mZ_mY, TR_12_12_12),
                    new Generator(ROT_Z_Y_X, TR_12_12_12),
                    new Generator(ROT_Z_mY_mX, TR_12_12_12),
                    new Generator(ROT_mZ_Y_mX, TR_12_12_12),
                    new Generator(ROT_mZ_mY_X, TR_12_12_12) });

    /** Space group 219. */
    public static final SpaceGroup SG219 = new SpaceGroup(219, "F-43c", CUBIC,
            LGm3m, new Generator[] { new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mX_Y_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_mZ, TR_0_0_0),
                    new Generator(ROT_Z_X_Y, TR_0_0_0),
                    new Generator(ROT_Z_mX_mY, TR_0_0_0),
                    new Generator(ROT_mZ_mX_Y, TR_0_0_0),
                    new Generator(ROT_mZ_X_mY, TR_0_0_0),
                    new Generator(ROT_Y_Z_X, TR_0_0_0),
                    new Generator(ROT_mY_Z_mX, TR_0_0_0),
                    new Generator(ROT_Y_mZ_mX, TR_0_0_0),
                    new Generator(ROT_mY_mZ_X, TR_0_0_0),
                    new Generator(ROT_Y_X_Z, TR_12_12_12),
                    new Generator(ROT_mY_mX_Z, TR_12_12_12),
                    new Generator(ROT_Y_mX_mZ, TR_12_12_12),
                    new Generator(ROT_mY_X_mZ, TR_12_12_12),
                    new Generator(ROT_X_Z_Y, TR_12_12_12),
                    new Generator(ROT_mX_Z_mY, TR_12_12_12),
                    new Generator(ROT_mX_mZ_Y, TR_12_12_12),
                    new Generator(ROT_X_mZ_mY, TR_12_12_12),
                    new Generator(ROT_Z_Y_X, TR_12_12_12),
                    new Generator(ROT_Z_mY_mX, TR_12_12_12),
                    new Generator(ROT_mZ_Y_mX, TR_12_12_12),
                    new Generator(ROT_mZ_mY_X, TR_12_12_12),
                    new Generator(ROT_X_Y_Z, TR_0_12_12),
                    new Generator(ROT_mX_mY_Z, TR_0_12_12),
                    new Generator(ROT_mX_Y_mZ, TR_0_12_12),
                    new Generator(ROT_X_mY_mZ, TR_0_12_12),
                    new Generator(ROT_Z_X_Y, TR_0_12_12),
                    new Generator(ROT_Z_mX_mY, TR_0_12_12),
                    new Generator(ROT_mZ_mX_Y, TR_0_12_12),
                    new Generator(ROT_mZ_X_mY, TR_0_12_12),
                    new Generator(ROT_Y_Z_X, TR_0_12_12),
                    new Generator(ROT_mY_Z_mX, TR_0_12_12),
                    new Generator(ROT_Y_mZ_mX, TR_0_12_12),
                    new Generator(ROT_mY_mZ_X, TR_0_12_12),
                    new Generator(ROT_Y_X_Z, TR_12_0_0),
                    new Generator(ROT_mY_mX_Z, TR_12_0_0),
                    new Generator(ROT_Y_mX_mZ, TR_12_0_0),
                    new Generator(ROT_mY_X_mZ, TR_12_0_0),
                    new Generator(ROT_X_Z_Y, TR_12_0_0),
                    new Generator(ROT_mX_Z_mY, TR_12_0_0),
                    new Generator(ROT_mX_mZ_Y, TR_12_0_0),
                    new Generator(ROT_X_mZ_mY, TR_12_0_0),
                    new Generator(ROT_Z_Y_X, TR_12_0_0),
                    new Generator(ROT_Z_mY_mX, TR_12_0_0),
                    new Generator(ROT_mZ_Y_mX, TR_12_0_0),
                    new Generator(ROT_mZ_mY_X, TR_12_0_0),
                    new Generator(ROT_X_Y_Z, TR_12_0_12),
                    new Generator(ROT_mX_mY_Z, TR_12_0_12),
                    new Generator(ROT_mX_Y_mZ, TR_12_0_12),
                    new Generator(ROT_X_mY_mZ, TR_12_0_12),
                    new Generator(ROT_Z_X_Y, TR_12_0_12),
                    new Generator(ROT_Z_mX_mY, TR_12_0_12),
                    new Generator(ROT_mZ_mX_Y, TR_12_0_12),
                    new Generator(ROT_mZ_X_mY, TR_12_0_12),
                    new Generator(ROT_Y_Z_X, TR_12_0_12),
                    new Generator(ROT_mY_Z_mX, TR_12_0_12),
                    new Generator(ROT_Y_mZ_mX, TR_12_0_12),
                    new Generator(ROT_mY_mZ_X, TR_12_0_12),
                    new Generator(ROT_Y_X_Z, TR_0_12_0),
                    new Generator(ROT_mY_mX_Z, TR_0_12_0),
                    new Generator(ROT_Y_mX_mZ, TR_0_12_0),
                    new Generator(ROT_mY_X_mZ, TR_0_12_0),
                    new Generator(ROT_X_Z_Y, TR_0_12_0),
                    new Generator(ROT_mX_Z_mY, TR_0_12_0),
                    new Generator(ROT_mX_mZ_Y, TR_0_12_0),
                    new Generator(ROT_X_mZ_mY, TR_0_12_0),
                    new Generator(ROT_Z_Y_X, TR_0_12_0),
                    new Generator(ROT_Z_mY_mX, TR_0_12_0),
                    new Generator(ROT_mZ_Y_mX, TR_0_12_0),
                    new Generator(ROT_mZ_mY_X, TR_0_12_0),
                    new Generator(ROT_X_Y_Z, TR_12_12_0),
                    new Generator(ROT_mX_mY_Z, TR_12_12_0),
                    new Generator(ROT_mX_Y_mZ, TR_12_12_0),
                    new Generator(ROT_X_mY_mZ, TR_12_12_0),
                    new Generator(ROT_Z_X_Y, TR_12_12_0),
                    new Generator(ROT_Z_mX_mY, TR_12_12_0),
                    new Generator(ROT_mZ_mX_Y, TR_12_12_0),
                    new Generator(ROT_mZ_X_mY, TR_12_12_0),
                    new Generator(ROT_Y_Z_X, TR_12_12_0),
                    new Generator(ROT_mY_Z_mX, TR_12_12_0),
                    new Generator(ROT_Y_mZ_mX, TR_12_12_0),
                    new Generator(ROT_mY_mZ_X, TR_12_12_0),
                    new Generator(ROT_Y_X_Z, TR_0_0_12),
                    new Generator(ROT_mY_mX_Z, TR_0_0_12),
                    new Generator(ROT_Y_mX_mZ, TR_0_0_12),
                    new Generator(ROT_mY_X_mZ, TR_0_0_12),
                    new Generator(ROT_X_Z_Y, TR_0_0_12),
                    new Generator(ROT_mX_Z_mY, TR_0_0_12),
                    new Generator(ROT_mX_mZ_Y, TR_0_0_12),
                    new Generator(ROT_X_mZ_mY, TR_0_0_12),
                    new Generator(ROT_Z_Y_X, TR_0_0_12),
                    new Generator(ROT_Z_mY_mX, TR_0_0_12),
                    new Generator(ROT_mZ_Y_mX, TR_0_0_12),
                    new Generator(ROT_mZ_mY_X, TR_0_0_12) });

    /** Space group 220. */
    public static final SpaceGroup SG220 = new SpaceGroup(220, "I-43d", CUBIC,
            LGm3m, new Generator[] { new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_12_0_12),
                    new Generator(ROT_mX_Y_mZ, TR_0_12_12),
                    new Generator(ROT_X_mY_mZ, TR_12_12_0),
                    new Generator(ROT_Z_X_Y, TR_0_0_0),
                    new Generator(ROT_Z_mX_mY, TR_12_12_0),
                    new Generator(ROT_mZ_mX_Y, TR_12_0_12),
                    new Generator(ROT_mZ_X_mY, TR_0_12_12),
                    new Generator(ROT_Y_Z_X, TR_0_0_0),
                    new Generator(ROT_mY_Z_mX, TR_0_12_12),
                    new Generator(ROT_Y_mZ_mX, TR_12_12_0),
                    new Generator(ROT_mY_mZ_X, TR_12_0_12),
                    new Generator(ROT_Y_X_Z, TR_14_14_14),
                    new Generator(ROT_mY_mX_Z, TR_14_34_34),
                    new Generator(ROT_Y_mX_mZ, TR_34_14_34),
                    new Generator(ROT_mY_X_mZ, TR_34_34_14),
                    new Generator(ROT_X_Z_Y, TR_14_14_14),
                    new Generator(ROT_mX_Z_mY, TR_34_34_14),
                    new Generator(ROT_mX_mZ_Y, TR_14_34_34),
                    new Generator(ROT_X_mZ_mY, TR_34_14_34),
                    new Generator(ROT_Z_Y_X, TR_14_14_14),
                    new Generator(ROT_Z_mY_mX, TR_34_14_34),
                    new Generator(ROT_mZ_Y_mX, TR_34_34_14),
                    new Generator(ROT_mZ_mY_X, TR_14_34_34),
                    new Generator(ROT_X_Y_Z, TR_12_12_12),
                    new Generator(ROT_mX_mY_Z, TR_0_12_0),
                    new Generator(ROT_mX_Y_mZ, TR_12_0_0),
                    new Generator(ROT_X_mY_mZ, TR_0_0_12),
                    new Generator(ROT_Z_X_Y, TR_12_12_12),
                    new Generator(ROT_Z_mX_mY, TR_0_0_12),
                    new Generator(ROT_mZ_mX_Y, TR_0_12_0),
                    new Generator(ROT_mZ_X_mY, TR_12_0_0),
                    new Generator(ROT_Y_Z_X, TR_12_12_12),
                    new Generator(ROT_mY_Z_mX, TR_12_0_0),
                    new Generator(ROT_Y_mZ_mX, TR_0_0_12),
                    new Generator(ROT_mY_mZ_X, TR_0_12_0),
                    new Generator(ROT_Y_X_Z, TR_34_34_34),
                    new Generator(ROT_mY_mX_Z, TR_34_14_14),
                    new Generator(ROT_Y_mX_mZ, TR_14_34_14),
                    new Generator(ROT_mY_X_mZ, TR_14_14_34),
                    new Generator(ROT_X_Z_Y, TR_34_34_34),
                    new Generator(ROT_mX_Z_mY, TR_14_14_34),
                    new Generator(ROT_mX_mZ_Y, TR_34_14_14),
                    new Generator(ROT_X_mZ_mY, TR_14_34_14),
                    new Generator(ROT_Z_Y_X, TR_34_34_34),
                    new Generator(ROT_Z_mY_mX, TR_14_34_14),
                    new Generator(ROT_mZ_Y_mX, TR_14_14_34),
                    new Generator(ROT_mZ_mY_X, TR_34_14_14) });

    /** Space group 221. */
    public static final SpaceGroup SG221 = new SpaceGroup(221, "Pm-3m", CUBIC,
            LGm3m, new Generator[] { new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mX_Y_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_mZ, TR_0_0_0),
                    new Generator(ROT_Z_X_Y, TR_0_0_0),
                    new Generator(ROT_Z_mX_mY, TR_0_0_0),
                    new Generator(ROT_mZ_mX_Y, TR_0_0_0),
                    new Generator(ROT_mZ_X_mY, TR_0_0_0),
                    new Generator(ROT_Y_Z_X, TR_0_0_0),
                    new Generator(ROT_mY_Z_mX, TR_0_0_0),
                    new Generator(ROT_Y_mZ_mX, TR_0_0_0),
                    new Generator(ROT_mY_mZ_X, TR_0_0_0),
                    new Generator(ROT_Y_X_mZ, TR_0_0_0),
                    new Generator(ROT_mY_mX_mZ, TR_0_0_0),
                    new Generator(ROT_Y_mX_Z, TR_0_0_0),
                    new Generator(ROT_mY_X_Z, TR_0_0_0),
                    new Generator(ROT_X_Z_mY, TR_0_0_0),
                    new Generator(ROT_mX_Z_Y, TR_0_0_0),
                    new Generator(ROT_mX_mZ_mY, TR_0_0_0),
                    new Generator(ROT_X_mZ_Y, TR_0_0_0),
                    new Generator(ROT_Z_Y_mX, TR_0_0_0),
                    new Generator(ROT_Z_mY_X, TR_0_0_0),
                    new Generator(ROT_mZ_Y_X, TR_0_0_0),
                    new Generator(ROT_mZ_mY_mX, TR_0_0_0),
                    new Generator(ROT_mX_mY_mZ, TR_0_0_0),
                    new Generator(ROT_X_Y_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_Z, TR_0_0_0),
                    new Generator(ROT_mX_Y_Z, TR_0_0_0),
                    new Generator(ROT_mZ_mX_mY, TR_0_0_0),
                    new Generator(ROT_mZ_X_Y, TR_0_0_0),
                    new Generator(ROT_Z_X_mY, TR_0_0_0),
                    new Generator(ROT_Z_mX_Y, TR_0_0_0),
                    new Generator(ROT_mY_mZ_mX, TR_0_0_0),
                    new Generator(ROT_Y_mZ_X, TR_0_0_0),
                    new Generator(ROT_mY_Z_X, TR_0_0_0),
                    new Generator(ROT_Y_Z_mX, TR_0_0_0),
                    new Generator(ROT_mY_mX_Z, TR_0_0_0),
                    new Generator(ROT_Y_X_Z, TR_0_0_0),
                    new Generator(ROT_mY_X_mZ, TR_0_0_0),
                    new Generator(ROT_Y_mX_mZ, TR_0_0_0),
                    new Generator(ROT_mX_mZ_Y, TR_0_0_0),
                    new Generator(ROT_X_mZ_mY, TR_0_0_0),
                    new Generator(ROT_X_Z_Y, TR_0_0_0),
                    new Generator(ROT_mX_Z_mY, TR_0_0_0),
                    new Generator(ROT_mZ_mY_X, TR_0_0_0),
                    new Generator(ROT_mZ_Y_mX, TR_0_0_0),
                    new Generator(ROT_Z_mY_mX, TR_0_0_0),
                    new Generator(ROT_Z_Y_X, TR_0_0_0) });

    /** Space group 222. */
    public static final SpaceGroup SG222 = new SpaceGroup(222, "Pn-3n", CUBIC,
            LGm3m, new Generator[] { new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mX_Y_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_mZ, TR_0_0_0),
                    new Generator(ROT_Z_X_Y, TR_0_0_0),
                    new Generator(ROT_Z_mX_mY, TR_0_0_0),
                    new Generator(ROT_mZ_mX_Y, TR_0_0_0),
                    new Generator(ROT_mZ_X_mY, TR_0_0_0),
                    new Generator(ROT_Y_Z_X, TR_0_0_0),
                    new Generator(ROT_mY_Z_mX, TR_0_0_0),
                    new Generator(ROT_Y_mZ_mX, TR_0_0_0),
                    new Generator(ROT_mY_mZ_X, TR_0_0_0),
                    new Generator(ROT_Y_X_mZ, TR_0_0_0),
                    new Generator(ROT_mY_mX_mZ, TR_0_0_0),
                    new Generator(ROT_Y_mX_Z, TR_0_0_0),
                    new Generator(ROT_mY_X_Z, TR_0_0_0),
                    new Generator(ROT_X_Z_mY, TR_0_0_0),
                    new Generator(ROT_mX_Z_Y, TR_0_0_0),
                    new Generator(ROT_mX_mZ_mY, TR_0_0_0),
                    new Generator(ROT_X_mZ_Y, TR_0_0_0),
                    new Generator(ROT_Z_Y_mX, TR_0_0_0),
                    new Generator(ROT_Z_mY_X, TR_0_0_0),
                    new Generator(ROT_mZ_Y_X, TR_0_0_0),
                    new Generator(ROT_mZ_mY_mX, TR_0_0_0),
                    new Generator(ROT_mX_mY_mZ, TR_12_12_12),
                    new Generator(ROT_X_Y_mZ, TR_12_12_12),
                    new Generator(ROT_X_mY_Z, TR_12_12_12),
                    new Generator(ROT_mX_Y_Z, TR_12_12_12),
                    new Generator(ROT_mZ_mX_mY, TR_12_12_12),
                    new Generator(ROT_mZ_X_Y, TR_12_12_12),
                    new Generator(ROT_Z_X_mY, TR_12_12_12),
                    new Generator(ROT_Z_mX_Y, TR_12_12_12),
                    new Generator(ROT_mY_mZ_mX, TR_12_12_12),
                    new Generator(ROT_Y_mZ_X, TR_12_12_12),
                    new Generator(ROT_mY_Z_X, TR_12_12_12),
                    new Generator(ROT_Y_Z_mX, TR_12_12_12),
                    new Generator(ROT_mY_mX_Z, TR_12_12_12),
                    new Generator(ROT_Y_X_Z, TR_12_12_12),
                    new Generator(ROT_mY_X_mZ, TR_12_12_12),
                    new Generator(ROT_Y_mX_mZ, TR_12_12_12),
                    new Generator(ROT_mX_mZ_Y, TR_12_12_12),
                    new Generator(ROT_X_mZ_mY, TR_12_12_12),
                    new Generator(ROT_X_Z_Y, TR_12_12_12),
                    new Generator(ROT_mX_Z_mY, TR_12_12_12),
                    new Generator(ROT_mZ_mY_X, TR_12_12_12),
                    new Generator(ROT_mZ_Y_mX, TR_12_12_12),
                    new Generator(ROT_Z_mY_mX, TR_12_12_12),
                    new Generator(ROT_Z_Y_X, TR_12_12_12) });

    /** Space group 223. */
    public static final SpaceGroup SG223 = new SpaceGroup(223, "Pm-3n", CUBIC,
            LGm3m, new Generator[] { new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mX_Y_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_mZ, TR_0_0_0),
                    new Generator(ROT_Z_X_Y, TR_0_0_0),
                    new Generator(ROT_Z_mX_mY, TR_0_0_0),
                    new Generator(ROT_mZ_mX_Y, TR_0_0_0),
                    new Generator(ROT_mZ_X_mY, TR_0_0_0),
                    new Generator(ROT_Y_Z_X, TR_0_0_0),
                    new Generator(ROT_mY_Z_mX, TR_0_0_0),
                    new Generator(ROT_Y_mZ_mX, TR_0_0_0),
                    new Generator(ROT_mY_mZ_X, TR_0_0_0),
                    new Generator(ROT_Y_X_mZ, TR_12_12_12),
                    new Generator(ROT_mY_mX_mZ, TR_12_12_12),
                    new Generator(ROT_Y_mX_Z, TR_12_12_12),
                    new Generator(ROT_mY_X_Z, TR_12_12_12),
                    new Generator(ROT_X_Z_mY, TR_12_12_12),
                    new Generator(ROT_mX_Z_Y, TR_12_12_12),
                    new Generator(ROT_mX_mZ_mY, TR_12_12_12),
                    new Generator(ROT_X_mZ_Y, TR_12_12_12),
                    new Generator(ROT_Z_Y_mX, TR_12_12_12),
                    new Generator(ROT_Z_mY_X, TR_12_12_12),
                    new Generator(ROT_mZ_Y_X, TR_12_12_12),
                    new Generator(ROT_mZ_mY_mX, TR_12_12_12),
                    new Generator(ROT_mX_mY_mZ, TR_0_0_0),
                    new Generator(ROT_X_Y_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_Z, TR_0_0_0),
                    new Generator(ROT_mX_Y_Z, TR_0_0_0),
                    new Generator(ROT_mZ_mX_mY, TR_0_0_0),
                    new Generator(ROT_mZ_X_Y, TR_0_0_0),
                    new Generator(ROT_Z_X_mY, TR_0_0_0),
                    new Generator(ROT_Z_mX_Y, TR_0_0_0),
                    new Generator(ROT_mY_mZ_mX, TR_0_0_0),
                    new Generator(ROT_Y_mZ_X, TR_0_0_0),
                    new Generator(ROT_mY_Z_X, TR_0_0_0),
                    new Generator(ROT_Y_Z_mX, TR_0_0_0),
                    new Generator(ROT_mY_mX_Z, TR_12_12_12),
                    new Generator(ROT_Y_X_Z, TR_12_12_12),
                    new Generator(ROT_mY_X_mZ, TR_12_12_12),
                    new Generator(ROT_Y_mX_mZ, TR_12_12_12),
                    new Generator(ROT_mX_mZ_Y, TR_12_12_12),
                    new Generator(ROT_X_mZ_mY, TR_12_12_12),
                    new Generator(ROT_X_Z_Y, TR_12_12_12),
                    new Generator(ROT_mX_Z_mY, TR_12_12_12),
                    new Generator(ROT_mZ_mY_X, TR_12_12_12),
                    new Generator(ROT_mZ_Y_mX, TR_12_12_12),
                    new Generator(ROT_Z_mY_mX, TR_12_12_12),
                    new Generator(ROT_Z_Y_X, TR_12_12_12) });

    /** Space group 224. */
    public static final SpaceGroup SG224 = new SpaceGroup(224, "Pn-3m", CUBIC,
            LGm3m, new Generator[] { new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mX_Y_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_mZ, TR_0_0_0),
                    new Generator(ROT_Z_X_Y, TR_0_0_0),
                    new Generator(ROT_Z_mX_mY, TR_0_0_0),
                    new Generator(ROT_mZ_mX_Y, TR_0_0_0),
                    new Generator(ROT_mZ_X_mY, TR_0_0_0),
                    new Generator(ROT_Y_Z_X, TR_0_0_0),
                    new Generator(ROT_mY_Z_mX, TR_0_0_0),
                    new Generator(ROT_Y_mZ_mX, TR_0_0_0),
                    new Generator(ROT_mY_mZ_X, TR_0_0_0),
                    new Generator(ROT_Y_X_mZ, TR_12_12_12),
                    new Generator(ROT_mY_mX_mZ, TR_12_12_12),
                    new Generator(ROT_Y_mX_Z, TR_12_12_12),
                    new Generator(ROT_mY_X_Z, TR_12_12_12),
                    new Generator(ROT_X_Z_mY, TR_12_12_12),
                    new Generator(ROT_mX_Z_Y, TR_12_12_12),
                    new Generator(ROT_mX_mZ_mY, TR_12_12_12),
                    new Generator(ROT_X_mZ_Y, TR_12_12_12),
                    new Generator(ROT_Z_Y_mX, TR_12_12_12),
                    new Generator(ROT_Z_mY_X, TR_12_12_12),
                    new Generator(ROT_mZ_Y_X, TR_12_12_12),
                    new Generator(ROT_mZ_mY_mX, TR_12_12_12),
                    new Generator(ROT_mX_mY_mZ, TR_12_12_12),
                    new Generator(ROT_X_Y_mZ, TR_12_12_12),
                    new Generator(ROT_X_mY_Z, TR_12_12_12),
                    new Generator(ROT_mX_Y_Z, TR_12_12_12),
                    new Generator(ROT_mZ_mX_mY, TR_12_12_12),
                    new Generator(ROT_mZ_X_Y, TR_12_12_12),
                    new Generator(ROT_Z_X_mY, TR_12_12_12),
                    new Generator(ROT_Z_mX_Y, TR_12_12_12),
                    new Generator(ROT_mY_mZ_mX, TR_12_12_12),
                    new Generator(ROT_Y_mZ_X, TR_12_12_12),
                    new Generator(ROT_mY_Z_X, TR_12_12_12),
                    new Generator(ROT_Y_Z_mX, TR_12_12_12),
                    new Generator(ROT_mY_mX_Z, TR_0_0_0),
                    new Generator(ROT_Y_X_Z, TR_0_0_0),
                    new Generator(ROT_mY_X_mZ, TR_0_0_0),
                    new Generator(ROT_Y_mX_mZ, TR_0_0_0),
                    new Generator(ROT_mX_mZ_Y, TR_0_0_0),
                    new Generator(ROT_X_mZ_mY, TR_0_0_0),
                    new Generator(ROT_X_Z_Y, TR_0_0_0),
                    new Generator(ROT_mX_Z_mY, TR_0_0_0),
                    new Generator(ROT_mZ_mY_X, TR_0_0_0),
                    new Generator(ROT_mZ_Y_mX, TR_0_0_0),
                    new Generator(ROT_Z_mY_mX, TR_0_0_0),
                    new Generator(ROT_Z_Y_X, TR_0_0_0) });

    /** Space group 225. */
    public static final SpaceGroup SG225 = new SpaceGroup(225, "Fm-3m", CUBIC,
            LGm3m, new Generator[] { new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mX_Y_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_mZ, TR_0_0_0),
                    new Generator(ROT_Z_X_Y, TR_0_0_0),
                    new Generator(ROT_Z_mX_mY, TR_0_0_0),
                    new Generator(ROT_mZ_mX_Y, TR_0_0_0),
                    new Generator(ROT_mZ_X_mY, TR_0_0_0),
                    new Generator(ROT_Y_Z_X, TR_0_0_0),
                    new Generator(ROT_mY_Z_mX, TR_0_0_0),
                    new Generator(ROT_Y_mZ_mX, TR_0_0_0),
                    new Generator(ROT_mY_mZ_X, TR_0_0_0),
                    new Generator(ROT_Y_X_mZ, TR_0_0_0),
                    new Generator(ROT_mY_mX_mZ, TR_0_0_0),
                    new Generator(ROT_Y_mX_Z, TR_0_0_0),
                    new Generator(ROT_mY_X_Z, TR_0_0_0),
                    new Generator(ROT_X_Z_mY, TR_0_0_0),
                    new Generator(ROT_mX_Z_Y, TR_0_0_0),
                    new Generator(ROT_mX_mZ_mY, TR_0_0_0),
                    new Generator(ROT_X_mZ_Y, TR_0_0_0),
                    new Generator(ROT_Z_Y_mX, TR_0_0_0),
                    new Generator(ROT_Z_mY_X, TR_0_0_0),
                    new Generator(ROT_mZ_Y_X, TR_0_0_0),
                    new Generator(ROT_mZ_mY_mX, TR_0_0_0),
                    new Generator(ROT_mX_mY_mZ, TR_0_0_0),
                    new Generator(ROT_X_Y_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_Z, TR_0_0_0),
                    new Generator(ROT_mX_Y_Z, TR_0_0_0),
                    new Generator(ROT_mZ_mX_mY, TR_0_0_0),
                    new Generator(ROT_mZ_X_Y, TR_0_0_0),
                    new Generator(ROT_Z_X_mY, TR_0_0_0),
                    new Generator(ROT_Z_mX_Y, TR_0_0_0),
                    new Generator(ROT_mY_mZ_mX, TR_0_0_0),
                    new Generator(ROT_Y_mZ_X, TR_0_0_0),
                    new Generator(ROT_mY_Z_X, TR_0_0_0),
                    new Generator(ROT_Y_Z_mX, TR_0_0_0),
                    new Generator(ROT_mY_mX_Z, TR_0_0_0),
                    new Generator(ROT_Y_X_Z, TR_0_0_0),
                    new Generator(ROT_mY_X_mZ, TR_0_0_0),
                    new Generator(ROT_Y_mX_mZ, TR_0_0_0),
                    new Generator(ROT_mX_mZ_Y, TR_0_0_0),
                    new Generator(ROT_X_mZ_mY, TR_0_0_0),
                    new Generator(ROT_X_Z_Y, TR_0_0_0),
                    new Generator(ROT_mX_Z_mY, TR_0_0_0),
                    new Generator(ROT_mZ_mY_X, TR_0_0_0),
                    new Generator(ROT_mZ_Y_mX, TR_0_0_0),
                    new Generator(ROT_Z_mY_mX, TR_0_0_0),
                    new Generator(ROT_Z_Y_X, TR_0_0_0),
                    new Generator(ROT_X_Y_Z, TR_0_12_12),
                    new Generator(ROT_mX_mY_Z, TR_0_12_12),
                    new Generator(ROT_mX_Y_mZ, TR_0_12_12),
                    new Generator(ROT_X_mY_mZ, TR_0_12_12),
                    new Generator(ROT_Z_X_Y, TR_0_12_12),
                    new Generator(ROT_Z_mX_mY, TR_0_12_12),
                    new Generator(ROT_mZ_mX_Y, TR_0_12_12),
                    new Generator(ROT_mZ_X_mY, TR_0_12_12),
                    new Generator(ROT_Y_Z_X, TR_0_12_12),
                    new Generator(ROT_mY_Z_mX, TR_0_12_12),
                    new Generator(ROT_Y_mZ_mX, TR_0_12_12),
                    new Generator(ROT_mY_mZ_X, TR_0_12_12),
                    new Generator(ROT_Y_X_mZ, TR_0_12_12),
                    new Generator(ROT_mY_mX_mZ, TR_0_12_12),
                    new Generator(ROT_Y_mX_Z, TR_0_12_12),
                    new Generator(ROT_mY_X_Z, TR_0_12_12),
                    new Generator(ROT_X_Z_mY, TR_0_12_12),
                    new Generator(ROT_mX_Z_Y, TR_0_12_12),
                    new Generator(ROT_mX_mZ_mY, TR_0_12_12),
                    new Generator(ROT_X_mZ_Y, TR_0_12_12),
                    new Generator(ROT_Z_Y_mX, TR_0_12_12),
                    new Generator(ROT_Z_mY_X, TR_0_12_12),
                    new Generator(ROT_mZ_Y_X, TR_0_12_12),
                    new Generator(ROT_mZ_mY_mX, TR_0_12_12),
                    new Generator(ROT_mX_mY_mZ, TR_0_12_12),
                    new Generator(ROT_X_Y_mZ, TR_0_12_12),
                    new Generator(ROT_X_mY_Z, TR_0_12_12),
                    new Generator(ROT_mX_Y_Z, TR_0_12_12),
                    new Generator(ROT_mZ_mX_mY, TR_0_12_12),
                    new Generator(ROT_mZ_X_Y, TR_0_12_12),
                    new Generator(ROT_Z_X_mY, TR_0_12_12),
                    new Generator(ROT_Z_mX_Y, TR_0_12_12),
                    new Generator(ROT_mY_mZ_mX, TR_0_12_12),
                    new Generator(ROT_Y_mZ_X, TR_0_12_12),
                    new Generator(ROT_mY_Z_X, TR_0_12_12),
                    new Generator(ROT_Y_Z_mX, TR_0_12_12),
                    new Generator(ROT_mY_mX_Z, TR_0_12_12),
                    new Generator(ROT_Y_X_Z, TR_0_12_12),
                    new Generator(ROT_mY_X_mZ, TR_0_12_12),
                    new Generator(ROT_Y_mX_mZ, TR_0_12_12),
                    new Generator(ROT_mX_mZ_Y, TR_0_12_12),
                    new Generator(ROT_X_mZ_mY, TR_0_12_12),
                    new Generator(ROT_X_Z_Y, TR_0_12_12),
                    new Generator(ROT_mX_Z_mY, TR_0_12_12),
                    new Generator(ROT_mZ_mY_X, TR_0_12_12),
                    new Generator(ROT_mZ_Y_mX, TR_0_12_12),
                    new Generator(ROT_Z_mY_mX, TR_0_12_12),
                    new Generator(ROT_Z_Y_X, TR_0_12_12),
                    new Generator(ROT_X_Y_Z, TR_12_0_12),
                    new Generator(ROT_mX_mY_Z, TR_12_0_12),
                    new Generator(ROT_mX_Y_mZ, TR_12_0_12),
                    new Generator(ROT_X_mY_mZ, TR_12_0_12),
                    new Generator(ROT_Z_X_Y, TR_12_0_12),
                    new Generator(ROT_Z_mX_mY, TR_12_0_12),
                    new Generator(ROT_mZ_mX_Y, TR_12_0_12),
                    new Generator(ROT_mZ_X_mY, TR_12_0_12),
                    new Generator(ROT_Y_Z_X, TR_12_0_12),
                    new Generator(ROT_mY_Z_mX, TR_12_0_12),
                    new Generator(ROT_Y_mZ_mX, TR_12_0_12),
                    new Generator(ROT_mY_mZ_X, TR_12_0_12),
                    new Generator(ROT_Y_X_mZ, TR_12_0_12),
                    new Generator(ROT_mY_mX_mZ, TR_12_0_12),
                    new Generator(ROT_Y_mX_Z, TR_12_0_12),
                    new Generator(ROT_mY_X_Z, TR_12_0_12),
                    new Generator(ROT_X_Z_mY, TR_12_0_12),
                    new Generator(ROT_mX_Z_Y, TR_12_0_12),
                    new Generator(ROT_mX_mZ_mY, TR_12_0_12),
                    new Generator(ROT_X_mZ_Y, TR_12_0_12),
                    new Generator(ROT_Z_Y_mX, TR_12_0_12),
                    new Generator(ROT_Z_mY_X, TR_12_0_12),
                    new Generator(ROT_mZ_Y_X, TR_12_0_12),
                    new Generator(ROT_mZ_mY_mX, TR_12_0_12),
                    new Generator(ROT_mX_mY_mZ, TR_12_0_12),
                    new Generator(ROT_X_Y_mZ, TR_12_0_12),
                    new Generator(ROT_X_mY_Z, TR_12_0_12),
                    new Generator(ROT_mX_Y_Z, TR_12_0_12),
                    new Generator(ROT_mZ_mX_mY, TR_12_0_12),
                    new Generator(ROT_mZ_X_Y, TR_12_0_12),
                    new Generator(ROT_Z_X_mY, TR_12_0_12),
                    new Generator(ROT_Z_mX_Y, TR_12_0_12),
                    new Generator(ROT_mY_mZ_mX, TR_12_0_12),
                    new Generator(ROT_Y_mZ_X, TR_12_0_12),
                    new Generator(ROT_mY_Z_X, TR_12_0_12),
                    new Generator(ROT_Y_Z_mX, TR_12_0_12),
                    new Generator(ROT_mY_mX_Z, TR_12_0_12),
                    new Generator(ROT_Y_X_Z, TR_12_0_12),
                    new Generator(ROT_mY_X_mZ, TR_12_0_12),
                    new Generator(ROT_Y_mX_mZ, TR_12_0_12),
                    new Generator(ROT_mX_mZ_Y, TR_12_0_12),
                    new Generator(ROT_X_mZ_mY, TR_12_0_12),
                    new Generator(ROT_X_Z_Y, TR_12_0_12),
                    new Generator(ROT_mX_Z_mY, TR_12_0_12),
                    new Generator(ROT_mZ_mY_X, TR_12_0_12),
                    new Generator(ROT_mZ_Y_mX, TR_12_0_12),
                    new Generator(ROT_Z_mY_mX, TR_12_0_12),
                    new Generator(ROT_Z_Y_X, TR_12_0_12),
                    new Generator(ROT_X_Y_Z, TR_12_12_0),
                    new Generator(ROT_mX_mY_Z, TR_12_12_0),
                    new Generator(ROT_mX_Y_mZ, TR_12_12_0),
                    new Generator(ROT_X_mY_mZ, TR_12_12_0),
                    new Generator(ROT_Z_X_Y, TR_12_12_0),
                    new Generator(ROT_Z_mX_mY, TR_12_12_0),
                    new Generator(ROT_mZ_mX_Y, TR_12_12_0),
                    new Generator(ROT_mZ_X_mY, TR_12_12_0),
                    new Generator(ROT_Y_Z_X, TR_12_12_0),
                    new Generator(ROT_mY_Z_mX, TR_12_12_0),
                    new Generator(ROT_Y_mZ_mX, TR_12_12_0),
                    new Generator(ROT_mY_mZ_X, TR_12_12_0),
                    new Generator(ROT_Y_X_mZ, TR_12_12_0),
                    new Generator(ROT_mY_mX_mZ, TR_12_12_0),
                    new Generator(ROT_Y_mX_Z, TR_12_12_0),
                    new Generator(ROT_mY_X_Z, TR_12_12_0),
                    new Generator(ROT_X_Z_mY, TR_12_12_0),
                    new Generator(ROT_mX_Z_Y, TR_12_12_0),
                    new Generator(ROT_mX_mZ_mY, TR_12_12_0),
                    new Generator(ROT_X_mZ_Y, TR_12_12_0),
                    new Generator(ROT_Z_Y_mX, TR_12_12_0),
                    new Generator(ROT_Z_mY_X, TR_12_12_0),
                    new Generator(ROT_mZ_Y_X, TR_12_12_0),
                    new Generator(ROT_mZ_mY_mX, TR_12_12_0),
                    new Generator(ROT_mX_mY_mZ, TR_12_12_0),
                    new Generator(ROT_X_Y_mZ, TR_12_12_0),
                    new Generator(ROT_X_mY_Z, TR_12_12_0),
                    new Generator(ROT_mX_Y_Z, TR_12_12_0),
                    new Generator(ROT_mZ_mX_mY, TR_12_12_0),
                    new Generator(ROT_mZ_X_Y, TR_12_12_0),
                    new Generator(ROT_Z_X_mY, TR_12_12_0),
                    new Generator(ROT_Z_mX_Y, TR_12_12_0),
                    new Generator(ROT_mY_mZ_mX, TR_12_12_0),
                    new Generator(ROT_Y_mZ_X, TR_12_12_0),
                    new Generator(ROT_mY_Z_X, TR_12_12_0),
                    new Generator(ROT_Y_Z_mX, TR_12_12_0),
                    new Generator(ROT_mY_mX_Z, TR_12_12_0),
                    new Generator(ROT_Y_X_Z, TR_12_12_0),
                    new Generator(ROT_mY_X_mZ, TR_12_12_0),
                    new Generator(ROT_Y_mX_mZ, TR_12_12_0),
                    new Generator(ROT_mX_mZ_Y, TR_12_12_0),
                    new Generator(ROT_X_mZ_mY, TR_12_12_0),
                    new Generator(ROT_X_Z_Y, TR_12_12_0),
                    new Generator(ROT_mX_Z_mY, TR_12_12_0),
                    new Generator(ROT_mZ_mY_X, TR_12_12_0),
                    new Generator(ROT_mZ_Y_mX, TR_12_12_0),
                    new Generator(ROT_Z_mY_mX, TR_12_12_0),
                    new Generator(ROT_Z_Y_X, TR_12_12_0) });

    /** Space group 226. */
    public static final SpaceGroup SG226 = new SpaceGroup(226, "Fm-3c", CUBIC,
            LGm3m, new Generator[] { new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mX_Y_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_mZ, TR_0_0_0),
                    new Generator(ROT_Z_X_Y, TR_0_0_0),
                    new Generator(ROT_Z_mX_mY, TR_0_0_0),
                    new Generator(ROT_mZ_mX_Y, TR_0_0_0),
                    new Generator(ROT_mZ_X_mY, TR_0_0_0),
                    new Generator(ROT_Y_Z_X, TR_0_0_0),
                    new Generator(ROT_mY_Z_mX, TR_0_0_0),
                    new Generator(ROT_Y_mZ_mX, TR_0_0_0),
                    new Generator(ROT_mY_mZ_X, TR_0_0_0),
                    new Generator(ROT_Y_X_mZ, TR_12_12_12),
                    new Generator(ROT_mY_mX_mZ, TR_12_12_12),
                    new Generator(ROT_Y_mX_Z, TR_12_12_12),
                    new Generator(ROT_mY_X_Z, TR_12_12_12),
                    new Generator(ROT_X_Z_mY, TR_12_12_12),
                    new Generator(ROT_mX_Z_Y, TR_12_12_12),
                    new Generator(ROT_mX_mZ_mY, TR_12_12_12),
                    new Generator(ROT_X_mZ_Y, TR_12_12_12),
                    new Generator(ROT_Z_Y_mX, TR_12_12_12),
                    new Generator(ROT_Z_mY_X, TR_12_12_12),
                    new Generator(ROT_mZ_Y_X, TR_12_12_12),
                    new Generator(ROT_mZ_mY_mX, TR_12_12_12),
                    new Generator(ROT_mX_mY_mZ, TR_0_0_0),
                    new Generator(ROT_X_Y_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_Z, TR_0_0_0),
                    new Generator(ROT_mX_Y_Z, TR_0_0_0),
                    new Generator(ROT_mZ_mX_mY, TR_0_0_0),
                    new Generator(ROT_mZ_X_Y, TR_0_0_0),
                    new Generator(ROT_Z_X_mY, TR_0_0_0),
                    new Generator(ROT_Z_mX_Y, TR_0_0_0),
                    new Generator(ROT_mY_mZ_mX, TR_0_0_0),
                    new Generator(ROT_Y_mZ_X, TR_0_0_0),
                    new Generator(ROT_mY_Z_X, TR_0_0_0),
                    new Generator(ROT_Y_Z_mX, TR_0_0_0),
                    new Generator(ROT_mY_mX_Z, TR_12_12_12),
                    new Generator(ROT_Y_X_Z, TR_12_12_12),
                    new Generator(ROT_mY_X_mZ, TR_12_12_12),
                    new Generator(ROT_Y_mX_mZ, TR_12_12_12),
                    new Generator(ROT_mX_mZ_Y, TR_12_12_12),
                    new Generator(ROT_X_mZ_mY, TR_12_12_12),
                    new Generator(ROT_X_Z_Y, TR_12_12_12),
                    new Generator(ROT_mX_Z_mY, TR_12_12_12),
                    new Generator(ROT_mZ_mY_X, TR_12_12_12),
                    new Generator(ROT_mZ_Y_mX, TR_12_12_12),
                    new Generator(ROT_Z_mY_mX, TR_12_12_12),
                    new Generator(ROT_Z_Y_X, TR_12_12_12),
                    new Generator(ROT_X_Y_Z, TR_0_12_12),
                    new Generator(ROT_mX_mY_Z, TR_0_12_12),
                    new Generator(ROT_mX_Y_mZ, TR_0_12_12),
                    new Generator(ROT_X_mY_mZ, TR_0_12_12),
                    new Generator(ROT_Z_X_Y, TR_0_12_12),
                    new Generator(ROT_Z_mX_mY, TR_0_12_12),
                    new Generator(ROT_mZ_mX_Y, TR_0_12_12),
                    new Generator(ROT_mZ_X_mY, TR_0_12_12),
                    new Generator(ROT_Y_Z_X, TR_0_12_12),
                    new Generator(ROT_mY_Z_mX, TR_0_12_12),
                    new Generator(ROT_Y_mZ_mX, TR_0_12_12),
                    new Generator(ROT_mY_mZ_X, TR_0_12_12),
                    new Generator(ROT_Y_X_mZ, TR_12_0_0),
                    new Generator(ROT_mY_mX_mZ, TR_12_0_0),
                    new Generator(ROT_Y_mX_Z, TR_12_0_0),
                    new Generator(ROT_mY_X_Z, TR_12_0_0),
                    new Generator(ROT_X_Z_mY, TR_12_0_0),
                    new Generator(ROT_mX_Z_Y, TR_12_0_0),
                    new Generator(ROT_mX_mZ_mY, TR_12_0_0),
                    new Generator(ROT_X_mZ_Y, TR_12_0_0),
                    new Generator(ROT_Z_Y_mX, TR_12_0_0),
                    new Generator(ROT_Z_mY_X, TR_12_0_0),
                    new Generator(ROT_mZ_Y_X, TR_12_0_0),
                    new Generator(ROT_mZ_mY_mX, TR_12_0_0),
                    new Generator(ROT_mX_mY_mZ, TR_0_12_12),
                    new Generator(ROT_X_Y_mZ, TR_0_12_12),
                    new Generator(ROT_X_mY_Z, TR_0_12_12),
                    new Generator(ROT_mX_Y_Z, TR_0_12_12),
                    new Generator(ROT_mZ_mX_mY, TR_0_12_12),
                    new Generator(ROT_mZ_X_Y, TR_0_12_12),
                    new Generator(ROT_Z_X_mY, TR_0_12_12),
                    new Generator(ROT_Z_mX_Y, TR_0_12_12),
                    new Generator(ROT_mY_mZ_mX, TR_0_12_12),
                    new Generator(ROT_Y_mZ_X, TR_0_12_12),
                    new Generator(ROT_mY_Z_X, TR_0_12_12),
                    new Generator(ROT_Y_Z_mX, TR_0_12_12),
                    new Generator(ROT_mY_mX_Z, TR_12_0_0),
                    new Generator(ROT_Y_X_Z, TR_12_0_0),
                    new Generator(ROT_mY_X_mZ, TR_12_0_0),
                    new Generator(ROT_Y_mX_mZ, TR_12_0_0),
                    new Generator(ROT_mX_mZ_Y, TR_12_0_0),
                    new Generator(ROT_X_mZ_mY, TR_12_0_0),
                    new Generator(ROT_X_Z_Y, TR_12_0_0),
                    new Generator(ROT_mX_Z_mY, TR_12_0_0),
                    new Generator(ROT_mZ_mY_X, TR_12_0_0),
                    new Generator(ROT_mZ_Y_mX, TR_12_0_0),
                    new Generator(ROT_Z_mY_mX, TR_12_0_0),
                    new Generator(ROT_Z_Y_X, TR_12_0_0),
                    new Generator(ROT_X_Y_Z, TR_12_0_12),
                    new Generator(ROT_mX_mY_Z, TR_12_0_12),
                    new Generator(ROT_mX_Y_mZ, TR_12_0_12),
                    new Generator(ROT_X_mY_mZ, TR_12_0_12),
                    new Generator(ROT_Z_X_Y, TR_12_0_12),
                    new Generator(ROT_Z_mX_mY, TR_12_0_12),
                    new Generator(ROT_mZ_mX_Y, TR_12_0_12),
                    new Generator(ROT_mZ_X_mY, TR_12_0_12),
                    new Generator(ROT_Y_Z_X, TR_12_0_12),
                    new Generator(ROT_mY_Z_mX, TR_12_0_12),
                    new Generator(ROT_Y_mZ_mX, TR_12_0_12),
                    new Generator(ROT_mY_mZ_X, TR_12_0_12),
                    new Generator(ROT_Y_X_mZ, TR_0_12_0),
                    new Generator(ROT_mY_mX_mZ, TR_0_12_0),
                    new Generator(ROT_Y_mX_Z, TR_0_12_0),
                    new Generator(ROT_mY_X_Z, TR_0_12_0),
                    new Generator(ROT_X_Z_mY, TR_0_12_0),
                    new Generator(ROT_mX_Z_Y, TR_0_12_0),
                    new Generator(ROT_mX_mZ_mY, TR_0_12_0),
                    new Generator(ROT_X_mZ_Y, TR_0_12_0),
                    new Generator(ROT_Z_Y_mX, TR_0_12_0),
                    new Generator(ROT_Z_mY_X, TR_0_12_0),
                    new Generator(ROT_mZ_Y_X, TR_0_12_0),
                    new Generator(ROT_mZ_mY_mX, TR_0_12_0),
                    new Generator(ROT_mX_mY_mZ, TR_12_0_12),
                    new Generator(ROT_X_Y_mZ, TR_12_0_12),
                    new Generator(ROT_X_mY_Z, TR_12_0_12),
                    new Generator(ROT_mX_Y_Z, TR_12_0_12),
                    new Generator(ROT_mZ_mX_mY, TR_12_0_12),
                    new Generator(ROT_mZ_X_Y, TR_12_0_12),
                    new Generator(ROT_Z_X_mY, TR_12_0_12),
                    new Generator(ROT_Z_mX_Y, TR_12_0_12),
                    new Generator(ROT_mY_mZ_mX, TR_12_0_12),
                    new Generator(ROT_Y_mZ_X, TR_12_0_12),
                    new Generator(ROT_mY_Z_X, TR_12_0_12),
                    new Generator(ROT_Y_Z_mX, TR_12_0_12),
                    new Generator(ROT_mY_mX_Z, TR_0_12_0),
                    new Generator(ROT_Y_X_Z, TR_0_12_0),
                    new Generator(ROT_mY_X_mZ, TR_0_12_0),
                    new Generator(ROT_Y_mX_mZ, TR_0_12_0),
                    new Generator(ROT_mX_mZ_Y, TR_0_12_0),
                    new Generator(ROT_X_mZ_mY, TR_0_12_0),
                    new Generator(ROT_X_Z_Y, TR_0_12_0),
                    new Generator(ROT_mX_Z_mY, TR_0_12_0),
                    new Generator(ROT_mZ_mY_X, TR_0_12_0),
                    new Generator(ROT_mZ_Y_mX, TR_0_12_0),
                    new Generator(ROT_Z_mY_mX, TR_0_12_0),
                    new Generator(ROT_Z_Y_X, TR_0_12_0),
                    new Generator(ROT_X_Y_Z, TR_12_12_0),
                    new Generator(ROT_mX_mY_Z, TR_12_12_0),
                    new Generator(ROT_mX_Y_mZ, TR_12_12_0),
                    new Generator(ROT_X_mY_mZ, TR_12_12_0),
                    new Generator(ROT_Z_X_Y, TR_12_12_0),
                    new Generator(ROT_Z_mX_mY, TR_12_12_0),
                    new Generator(ROT_mZ_mX_Y, TR_12_12_0),
                    new Generator(ROT_mZ_X_mY, TR_12_12_0),
                    new Generator(ROT_Y_Z_X, TR_12_12_0),
                    new Generator(ROT_mY_Z_mX, TR_12_12_0),
                    new Generator(ROT_Y_mZ_mX, TR_12_12_0),
                    new Generator(ROT_mY_mZ_X, TR_12_12_0),
                    new Generator(ROT_Y_X_mZ, TR_0_0_12),
                    new Generator(ROT_mY_mX_mZ, TR_0_0_12),
                    new Generator(ROT_Y_mX_Z, TR_0_0_12),
                    new Generator(ROT_mY_X_Z, TR_0_0_12),
                    new Generator(ROT_X_Z_mY, TR_0_0_12),
                    new Generator(ROT_mX_Z_Y, TR_0_0_12),
                    new Generator(ROT_mX_mZ_mY, TR_0_0_12),
                    new Generator(ROT_X_mZ_Y, TR_0_0_12),
                    new Generator(ROT_Z_Y_mX, TR_0_0_12),
                    new Generator(ROT_Z_mY_X, TR_0_0_12),
                    new Generator(ROT_mZ_Y_X, TR_0_0_12),
                    new Generator(ROT_mZ_mY_mX, TR_0_0_12),
                    new Generator(ROT_mX_mY_mZ, TR_12_12_0),
                    new Generator(ROT_X_Y_mZ, TR_12_12_0),
                    new Generator(ROT_X_mY_Z, TR_12_12_0),
                    new Generator(ROT_mX_Y_Z, TR_12_12_0),
                    new Generator(ROT_mZ_mX_mY, TR_12_12_0),
                    new Generator(ROT_mZ_X_Y, TR_12_12_0),
                    new Generator(ROT_Z_X_mY, TR_12_12_0),
                    new Generator(ROT_Z_mX_Y, TR_12_12_0),
                    new Generator(ROT_mY_mZ_mX, TR_12_12_0),
                    new Generator(ROT_Y_mZ_X, TR_12_12_0),
                    new Generator(ROT_mY_Z_X, TR_12_12_0),
                    new Generator(ROT_Y_Z_mX, TR_12_12_0),
                    new Generator(ROT_mY_mX_Z, TR_0_0_12),
                    new Generator(ROT_Y_X_Z, TR_0_0_12),
                    new Generator(ROT_mY_X_mZ, TR_0_0_12),
                    new Generator(ROT_Y_mX_mZ, TR_0_0_12),
                    new Generator(ROT_mX_mZ_Y, TR_0_0_12),
                    new Generator(ROT_X_mZ_mY, TR_0_0_12),
                    new Generator(ROT_X_Z_Y, TR_0_0_12),
                    new Generator(ROT_mX_Z_mY, TR_0_0_12),
                    new Generator(ROT_mZ_mY_X, TR_0_0_12),
                    new Generator(ROT_mZ_Y_mX, TR_0_0_12),
                    new Generator(ROT_Z_mY_mX, TR_0_0_12),
                    new Generator(ROT_Z_Y_X, TR_0_0_12) });

    /** Space group 227. */
    public static final SpaceGroup SG227 = new SpaceGroup(227, "Fd-3m", CUBIC,
            LGm3m, new Generator[] { new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_12_12),
                    new Generator(ROT_mX_Y_mZ, TR_12_12_0),
                    new Generator(ROT_X_mY_mZ, TR_12_0_12),
                    new Generator(ROT_Z_X_Y, TR_0_0_0),
                    new Generator(ROT_Z_mX_mY, TR_12_0_12),
                    new Generator(ROT_mZ_mX_Y, TR_0_12_12),
                    new Generator(ROT_mZ_X_mY, TR_12_12_0),
                    new Generator(ROT_Y_Z_X, TR_0_0_0),
                    new Generator(ROT_mY_Z_mX, TR_12_12_0),
                    new Generator(ROT_Y_mZ_mX, TR_12_0_12),
                    new Generator(ROT_mY_mZ_X, TR_0_12_12),
                    new Generator(ROT_Y_X_mZ, TR_34_14_34),
                    new Generator(ROT_mY_mX_mZ, TR_14_14_14),
                    new Generator(ROT_Y_mX_Z, TR_14_34_34),
                    new Generator(ROT_mY_X_Z, TR_34_34_14),
                    new Generator(ROT_X_Z_mY, TR_34_14_34),
                    new Generator(ROT_mX_Z_Y, TR_34_34_14),
                    new Generator(ROT_mX_mZ_mY, TR_14_14_14),
                    new Generator(ROT_X_mZ_Y, TR_14_34_34),
                    new Generator(ROT_Z_Y_mX, TR_34_14_34),
                    new Generator(ROT_Z_mY_X, TR_14_34_34),
                    new Generator(ROT_mZ_Y_X, TR_34_34_14),
                    new Generator(ROT_mZ_mY_mX, TR_14_14_14),
                    new Generator(ROT_mX_mY_mZ, TR_14_14_14),
                    new Generator(ROT_X_Y_mZ, TR_14_34_34),
                    new Generator(ROT_X_mY_Z, TR_34_34_14),
                    new Generator(ROT_mX_Y_Z, TR_34_14_34),
                    new Generator(ROT_mZ_mX_mY, TR_14_14_14),
                    new Generator(ROT_mZ_X_Y, TR_34_14_34),
                    new Generator(ROT_Z_X_mY, TR_14_34_34),
                    new Generator(ROT_Z_mX_Y, TR_34_34_14),
                    new Generator(ROT_mY_mZ_mX, TR_14_14_14),
                    new Generator(ROT_Y_mZ_X, TR_34_34_14),
                    new Generator(ROT_mY_Z_X, TR_34_14_34),
                    new Generator(ROT_Y_Z_mX, TR_14_34_34),
                    new Generator(ROT_mY_mX_Z, TR_12_0_12),
                    new Generator(ROT_Y_X_Z, TR_0_0_0),
                    new Generator(ROT_mY_X_mZ, TR_0_12_12),
                    new Generator(ROT_Y_mX_mZ, TR_12_12_0),
                    new Generator(ROT_mX_mZ_Y, TR_12_0_12),
                    new Generator(ROT_X_mZ_mY, TR_12_12_0),
                    new Generator(ROT_X_Z_Y, TR_0_0_0),
                    new Generator(ROT_mX_Z_mY, TR_0_12_12),
                    new Generator(ROT_mZ_mY_X, TR_12_0_12),
                    new Generator(ROT_mZ_Y_mX, TR_0_12_12),
                    new Generator(ROT_Z_mY_mX, TR_12_12_0),
                    new Generator(ROT_Z_Y_X, TR_0_0_0),
                    new Generator(ROT_X_Y_Z, TR_0_12_12),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mX_Y_mZ, TR_12_0_12),
                    new Generator(ROT_X_mY_mZ, TR_12_12_0),
                    new Generator(ROT_Z_X_Y, TR_0_12_12),
                    new Generator(ROT_Z_mX_mY, TR_12_12_0),
                    new Generator(ROT_mZ_mX_Y, TR_0_0_0),
                    new Generator(ROT_mZ_X_mY, TR_12_0_12),
                    new Generator(ROT_Y_Z_X, TR_0_12_12),
                    new Generator(ROT_mY_Z_mX, TR_12_0_12),
                    new Generator(ROT_Y_mZ_mX, TR_12_12_0),
                    new Generator(ROT_mY_mZ_X, TR_0_0_0),
                    new Generator(ROT_Y_X_mZ, TR_34_34_14),
                    new Generator(ROT_mY_mX_mZ, TR_14_34_34),
                    new Generator(ROT_Y_mX_Z, TR_14_14_14),
                    new Generator(ROT_mY_X_Z, TR_34_14_34),
                    new Generator(ROT_X_Z_mY, TR_34_34_14),
                    new Generator(ROT_mX_Z_Y, TR_34_14_34),
                    new Generator(ROT_mX_mZ_mY, TR_14_34_34),
                    new Generator(ROT_X_mZ_Y, TR_14_14_14),
                    new Generator(ROT_Z_Y_mX, TR_34_34_14),
                    new Generator(ROT_Z_mY_X, TR_14_14_14),
                    new Generator(ROT_mZ_Y_X, TR_34_14_34),
                    new Generator(ROT_mZ_mY_mX, TR_14_34_34),
                    new Generator(ROT_mX_mY_mZ, TR_14_34_34),
                    new Generator(ROT_X_Y_mZ, TR_14_14_14),
                    new Generator(ROT_X_mY_Z, TR_34_14_34),
                    new Generator(ROT_mX_Y_Z, TR_34_34_14),
                    new Generator(ROT_mZ_mX_mY, TR_14_34_34),
                    new Generator(ROT_mZ_X_Y, TR_34_34_14),
                    new Generator(ROT_Z_X_mY, TR_14_14_14),
                    new Generator(ROT_Z_mX_Y, TR_34_14_34),
                    new Generator(ROT_mY_mZ_mX, TR_14_34_34),
                    new Generator(ROT_Y_mZ_X, TR_34_14_34),
                    new Generator(ROT_mY_Z_X, TR_34_34_14),
                    new Generator(ROT_Y_Z_mX, TR_14_14_14),
                    new Generator(ROT_mY_mX_Z, TR_12_12_0),
                    new Generator(ROT_Y_X_Z, TR_0_12_12),
                    new Generator(ROT_mY_X_mZ, TR_0_0_0),
                    new Generator(ROT_Y_mX_mZ, TR_12_0_12),
                    new Generator(ROT_mX_mZ_Y, TR_12_12_0),
                    new Generator(ROT_X_mZ_mY, TR_12_0_12),
                    new Generator(ROT_X_Z_Y, TR_0_12_12),
                    new Generator(ROT_mX_Z_mY, TR_0_0_0),
                    new Generator(ROT_mZ_mY_X, TR_12_12_0),
                    new Generator(ROT_mZ_Y_mX, TR_0_0_0),
                    new Generator(ROT_Z_mY_mX, TR_12_0_12),
                    new Generator(ROT_Z_Y_X, TR_0_12_12),
                    new Generator(ROT_X_Y_Z, TR_12_0_12),
                    new Generator(ROT_mX_mY_Z, TR_12_12_0),
                    new Generator(ROT_mX_Y_mZ, TR_0_12_12),
                    new Generator(ROT_X_mY_mZ, TR_0_0_0),
                    new Generator(ROT_Z_X_Y, TR_12_0_12),
                    new Generator(ROT_Z_mX_mY, TR_0_0_0),
                    new Generator(ROT_mZ_mX_Y, TR_12_12_0),
                    new Generator(ROT_mZ_X_mY, TR_0_12_12),
                    new Generator(ROT_Y_Z_X, TR_12_0_12),
                    new Generator(ROT_mY_Z_mX, TR_0_12_12),
                    new Generator(ROT_Y_mZ_mX, TR_0_0_0),
                    new Generator(ROT_mY_mZ_X, TR_12_12_0),
                    new Generator(ROT_Y_X_mZ, TR_14_14_14),
                    new Generator(ROT_mY_mX_mZ, TR_34_14_34),
                    new Generator(ROT_Y_mX_Z, TR_34_34_14),
                    new Generator(ROT_mY_X_Z, TR_14_34_34),
                    new Generator(ROT_X_Z_mY, TR_14_14_14),
                    new Generator(ROT_mX_Z_Y, TR_14_34_34),
                    new Generator(ROT_mX_mZ_mY, TR_34_14_34),
                    new Generator(ROT_X_mZ_Y, TR_34_34_14),
                    new Generator(ROT_Z_Y_mX, TR_14_14_14),
                    new Generator(ROT_Z_mY_X, TR_34_34_14),
                    new Generator(ROT_mZ_Y_X, TR_14_34_34),
                    new Generator(ROT_mZ_mY_mX, TR_34_14_34),
                    new Generator(ROT_mX_mY_mZ, TR_34_14_34),
                    new Generator(ROT_X_Y_mZ, TR_34_34_14),
                    new Generator(ROT_X_mY_Z, TR_14_34_34),
                    new Generator(ROT_mX_Y_Z, TR_14_14_14),
                    new Generator(ROT_mZ_mX_mY, TR_34_14_34),
                    new Generator(ROT_mZ_X_Y, TR_14_14_14),
                    new Generator(ROT_Z_X_mY, TR_34_34_14),
                    new Generator(ROT_Z_mX_Y, TR_14_34_34),
                    new Generator(ROT_mY_mZ_mX, TR_34_14_34),
                    new Generator(ROT_Y_mZ_X, TR_14_34_34),
                    new Generator(ROT_mY_Z_X, TR_14_14_14),
                    new Generator(ROT_Y_Z_mX, TR_34_34_14),
                    new Generator(ROT_mY_mX_Z, TR_0_0_0),
                    new Generator(ROT_Y_X_Z, TR_12_0_12),
                    new Generator(ROT_mY_X_mZ, TR_12_12_0),
                    new Generator(ROT_Y_mX_mZ, TR_0_12_12),
                    new Generator(ROT_mX_mZ_Y, TR_0_0_0),
                    new Generator(ROT_X_mZ_mY, TR_0_12_12),
                    new Generator(ROT_X_Z_Y, TR_12_0_12),
                    new Generator(ROT_mX_Z_mY, TR_12_12_0),
                    new Generator(ROT_mZ_mY_X, TR_0_0_0),
                    new Generator(ROT_mZ_Y_mX, TR_12_12_0),
                    new Generator(ROT_Z_mY_mX, TR_0_12_12),
                    new Generator(ROT_Z_Y_X, TR_12_0_12),
                    new Generator(ROT_X_Y_Z, TR_12_12_0),
                    new Generator(ROT_mX_mY_Z, TR_12_0_12),
                    new Generator(ROT_mX_Y_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_mZ, TR_0_12_12),
                    new Generator(ROT_Z_X_Y, TR_12_12_0),
                    new Generator(ROT_Z_mX_mY, TR_0_12_12),
                    new Generator(ROT_mZ_mX_Y, TR_12_0_12),
                    new Generator(ROT_mZ_X_mY, TR_0_0_0),
                    new Generator(ROT_Y_Z_X, TR_12_12_0),
                    new Generator(ROT_mY_Z_mX, TR_0_0_0),
                    new Generator(ROT_Y_mZ_mX, TR_0_12_12),
                    new Generator(ROT_mY_mZ_X, TR_12_0_12),
                    new Generator(ROT_Y_X_mZ, TR_14_34_34),
                    new Generator(ROT_mY_mX_mZ, TR_34_34_14),
                    new Generator(ROT_Y_mX_Z, TR_34_14_34),
                    new Generator(ROT_mY_X_Z, TR_14_14_14),
                    new Generator(ROT_X_Z_mY, TR_14_34_34),
                    new Generator(ROT_mX_Z_Y, TR_14_14_14),
                    new Generator(ROT_mX_mZ_mY, TR_34_34_14),
                    new Generator(ROT_X_mZ_Y, TR_34_14_34),
                    new Generator(ROT_Z_Y_mX, TR_14_34_34),
                    new Generator(ROT_Z_mY_X, TR_34_14_34),
                    new Generator(ROT_mZ_Y_X, TR_14_14_14),
                    new Generator(ROT_mZ_mY_mX, TR_34_34_14),
                    new Generator(ROT_mX_mY_mZ, TR_34_34_14),
                    new Generator(ROT_X_Y_mZ, TR_34_14_34),
                    new Generator(ROT_X_mY_Z, TR_14_14_14),
                    new Generator(ROT_mX_Y_Z, TR_14_34_34),
                    new Generator(ROT_mZ_mX_mY, TR_34_34_14),
                    new Generator(ROT_mZ_X_Y, TR_14_34_34),
                    new Generator(ROT_Z_X_mY, TR_34_14_34),
                    new Generator(ROT_Z_mX_Y, TR_14_14_14),
                    new Generator(ROT_mY_mZ_mX, TR_34_34_14),
                    new Generator(ROT_Y_mZ_X, TR_14_14_14),
                    new Generator(ROT_mY_Z_X, TR_14_34_34),
                    new Generator(ROT_Y_Z_mX, TR_34_14_34),
                    new Generator(ROT_mY_mX_Z, TR_0_12_12),
                    new Generator(ROT_Y_X_Z, TR_12_12_0),
                    new Generator(ROT_mY_X_mZ, TR_12_0_12),
                    new Generator(ROT_Y_mX_mZ, TR_0_0_0),
                    new Generator(ROT_mX_mZ_Y, TR_0_12_12),
                    new Generator(ROT_X_mZ_mY, TR_0_0_0),
                    new Generator(ROT_X_Z_Y, TR_12_12_0),
                    new Generator(ROT_mX_Z_mY, TR_12_0_12),
                    new Generator(ROT_mZ_mY_X, TR_0_12_12),
                    new Generator(ROT_mZ_Y_mX, TR_12_0_12),
                    new Generator(ROT_Z_mY_mX, TR_0_0_0),
                    new Generator(ROT_Z_Y_X, TR_12_12_0) });

    /** Space group 228. */
    public static final SpaceGroup SG228 = new SpaceGroup(228, "Fd-3c", CUBIC,
            LGm3m, new Generator[] { new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_12_12),
                    new Generator(ROT_mX_Y_mZ, TR_12_12_0),
                    new Generator(ROT_X_mY_mZ, TR_12_0_12),
                    new Generator(ROT_Z_X_Y, TR_0_0_0),
                    new Generator(ROT_Z_mX_mY, TR_12_0_12),
                    new Generator(ROT_mZ_mX_Y, TR_0_12_12),
                    new Generator(ROT_mZ_X_mY, TR_12_12_0),
                    new Generator(ROT_Y_Z_X, TR_0_0_0),
                    new Generator(ROT_mY_Z_mX, TR_12_12_0),
                    new Generator(ROT_Y_mZ_mX, TR_12_0_12),
                    new Generator(ROT_mY_mZ_X, TR_0_12_12),
                    new Generator(ROT_Y_X_mZ, TR_34_14_34),
                    new Generator(ROT_mY_mX_mZ, TR_14_14_14),
                    new Generator(ROT_Y_mX_Z, TR_14_34_34),
                    new Generator(ROT_mY_X_Z, TR_34_34_14),
                    new Generator(ROT_X_Z_mY, TR_34_14_34),
                    new Generator(ROT_mX_Z_Y, TR_34_34_14),
                    new Generator(ROT_mX_mZ_mY, TR_14_14_14),
                    new Generator(ROT_X_mZ_Y, TR_14_34_34),
                    new Generator(ROT_Z_Y_mX, TR_34_14_34),
                    new Generator(ROT_Z_mY_X, TR_14_34_34),
                    new Generator(ROT_mZ_Y_X, TR_34_34_14),
                    new Generator(ROT_mZ_mY_mX, TR_14_14_14),
                    new Generator(ROT_mX_mY_mZ, TR_34_34_34),
                    new Generator(ROT_X_Y_mZ, TR_34_14_14),
                    new Generator(ROT_X_mY_Z, TR_14_14_34),
                    new Generator(ROT_mX_Y_Z, TR_14_34_14),
                    new Generator(ROT_mZ_mX_mY, TR_34_34_34),
                    new Generator(ROT_mZ_X_Y, TR_14_34_14),
                    new Generator(ROT_Z_X_mY, TR_34_14_14),
                    new Generator(ROT_Z_mX_Y, TR_14_14_34),
                    new Generator(ROT_mY_mZ_mX, TR_34_34_34),
                    new Generator(ROT_Y_mZ_X, TR_14_14_34),
                    new Generator(ROT_mY_Z_X, TR_14_34_14),
                    new Generator(ROT_Y_Z_mX, TR_34_14_14),
                    new Generator(ROT_mY_mX_Z, TR_0_12_0),
                    new Generator(ROT_Y_X_Z, TR_12_12_12),
                    new Generator(ROT_mY_X_mZ, TR_12_0_0),
                    new Generator(ROT_Y_mX_mZ, TR_0_0_12),
                    new Generator(ROT_mX_mZ_Y, TR_0_12_0),
                    new Generator(ROT_X_mZ_mY, TR_0_0_12),
                    new Generator(ROT_X_Z_Y, TR_12_12_12),
                    new Generator(ROT_mX_Z_mY, TR_12_0_0),
                    new Generator(ROT_mZ_mY_X, TR_0_12_0),
                    new Generator(ROT_mZ_Y_mX, TR_12_0_0),
                    new Generator(ROT_Z_mY_mX, TR_0_0_12),
                    new Generator(ROT_Z_Y_X, TR_12_12_12),
                    new Generator(ROT_X_Y_Z, TR_0_12_12),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mX_Y_mZ, TR_12_0_12),
                    new Generator(ROT_X_mY_mZ, TR_12_12_0),
                    new Generator(ROT_Z_X_Y, TR_0_12_12),
                    new Generator(ROT_Z_mX_mY, TR_12_12_0),
                    new Generator(ROT_mZ_mX_Y, TR_0_0_0),
                    new Generator(ROT_mZ_X_mY, TR_12_0_12),
                    new Generator(ROT_Y_Z_X, TR_0_12_12),
                    new Generator(ROT_mY_Z_mX, TR_12_0_12),
                    new Generator(ROT_Y_mZ_mX, TR_12_12_0),
                    new Generator(ROT_mY_mZ_X, TR_0_0_0),
                    new Generator(ROT_Y_X_mZ, TR_34_34_14),
                    new Generator(ROT_mY_mX_mZ, TR_14_34_34),
                    new Generator(ROT_Y_mX_Z, TR_14_14_14),
                    new Generator(ROT_mY_X_Z, TR_34_14_34),
                    new Generator(ROT_X_Z_mY, TR_34_34_14),
                    new Generator(ROT_mX_Z_Y, TR_34_14_34),
                    new Generator(ROT_mX_mZ_mY, TR_14_34_34),
                    new Generator(ROT_X_mZ_Y, TR_14_14_14),
                    new Generator(ROT_Z_Y_mX, TR_34_34_14),
                    new Generator(ROT_Z_mY_X, TR_14_14_14),
                    new Generator(ROT_mZ_Y_X, TR_34_14_34),
                    new Generator(ROT_mZ_mY_mX, TR_14_34_34),
                    new Generator(ROT_mX_mY_mZ, TR_34_14_14),
                    new Generator(ROT_X_Y_mZ, TR_34_34_34),
                    new Generator(ROT_X_mY_Z, TR_14_34_14),
                    new Generator(ROT_mX_Y_Z, TR_14_14_34),
                    new Generator(ROT_mZ_mX_mY, TR_34_14_14),
                    new Generator(ROT_mZ_X_Y, TR_14_14_34),
                    new Generator(ROT_Z_X_mY, TR_34_34_34),
                    new Generator(ROT_Z_mX_Y, TR_14_34_14),
                    new Generator(ROT_mY_mZ_mX, TR_34_14_14),
                    new Generator(ROT_Y_mZ_X, TR_14_34_14),
                    new Generator(ROT_mY_Z_X, TR_14_14_34),
                    new Generator(ROT_Y_Z_mX, TR_34_34_34),
                    new Generator(ROT_mY_mX_Z, TR_0_0_12),
                    new Generator(ROT_Y_X_Z, TR_12_0_0),
                    new Generator(ROT_mY_X_mZ, TR_12_12_12),
                    new Generator(ROT_Y_mX_mZ, TR_0_12_0),
                    new Generator(ROT_mX_mZ_Y, TR_0_0_12),
                    new Generator(ROT_X_mZ_mY, TR_0_12_0),
                    new Generator(ROT_X_Z_Y, TR_12_0_0),
                    new Generator(ROT_mX_Z_mY, TR_12_12_12),
                    new Generator(ROT_mZ_mY_X, TR_0_0_12),
                    new Generator(ROT_mZ_Y_mX, TR_12_12_12),
                    new Generator(ROT_Z_mY_mX, TR_0_12_0),
                    new Generator(ROT_Z_Y_X, TR_12_0_0),
                    new Generator(ROT_X_Y_Z, TR_12_0_12),
                    new Generator(ROT_mX_mY_Z, TR_12_12_0),
                    new Generator(ROT_mX_Y_mZ, TR_0_12_12),
                    new Generator(ROT_X_mY_mZ, TR_0_0_0),
                    new Generator(ROT_Z_X_Y, TR_12_0_12),
                    new Generator(ROT_Z_mX_mY, TR_0_0_0),
                    new Generator(ROT_mZ_mX_Y, TR_12_12_0),
                    new Generator(ROT_mZ_X_mY, TR_0_12_12),
                    new Generator(ROT_Y_Z_X, TR_12_0_12),
                    new Generator(ROT_mY_Z_mX, TR_0_12_12),
                    new Generator(ROT_Y_mZ_mX, TR_0_0_0),
                    new Generator(ROT_mY_mZ_X, TR_12_12_0),
                    new Generator(ROT_Y_X_mZ, TR_14_14_14),
                    new Generator(ROT_mY_mX_mZ, TR_34_14_34),
                    new Generator(ROT_Y_mX_Z, TR_34_34_14),
                    new Generator(ROT_mY_X_Z, TR_14_34_34),
                    new Generator(ROT_X_Z_mY, TR_14_14_14),
                    new Generator(ROT_mX_Z_Y, TR_14_34_34),
                    new Generator(ROT_mX_mZ_mY, TR_34_14_34),
                    new Generator(ROT_X_mZ_Y, TR_34_34_14),
                    new Generator(ROT_Z_Y_mX, TR_14_14_14),
                    new Generator(ROT_Z_mY_X, TR_34_34_14),
                    new Generator(ROT_mZ_Y_X, TR_14_34_34),
                    new Generator(ROT_mZ_mY_mX, TR_34_14_34),
                    new Generator(ROT_mX_mY_mZ, TR_14_34_14),
                    new Generator(ROT_X_Y_mZ, TR_14_14_34),
                    new Generator(ROT_X_mY_Z, TR_34_14_14),
                    new Generator(ROT_mX_Y_Z, TR_34_34_34),
                    new Generator(ROT_mZ_mX_mY, TR_14_34_14),
                    new Generator(ROT_mZ_X_Y, TR_34_34_34),
                    new Generator(ROT_Z_X_mY, TR_14_14_34),
                    new Generator(ROT_Z_mX_Y, TR_34_14_14),
                    new Generator(ROT_mY_mZ_mX, TR_14_34_14),
                    new Generator(ROT_Y_mZ_X, TR_34_14_14),
                    new Generator(ROT_mY_Z_X, TR_34_34_34),
                    new Generator(ROT_Y_Z_mX, TR_14_14_34),
                    new Generator(ROT_mY_mX_Z, TR_12_12_12),
                    new Generator(ROT_Y_X_Z, TR_0_12_0),
                    new Generator(ROT_mY_X_mZ, TR_0_0_12),
                    new Generator(ROT_Y_mX_mZ, TR_12_0_0),
                    new Generator(ROT_mX_mZ_Y, TR_12_12_12),
                    new Generator(ROT_X_mZ_mY, TR_12_0_0),
                    new Generator(ROT_X_Z_Y, TR_0_12_0),
                    new Generator(ROT_mX_Z_mY, TR_0_0_12),
                    new Generator(ROT_mZ_mY_X, TR_12_12_12),
                    new Generator(ROT_mZ_Y_mX, TR_0_0_12),
                    new Generator(ROT_Z_mY_mX, TR_12_0_0),
                    new Generator(ROT_Z_Y_X, TR_0_12_0),
                    new Generator(ROT_X_Y_Z, TR_12_12_0),
                    new Generator(ROT_mX_mY_Z, TR_12_0_12),
                    new Generator(ROT_mX_Y_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_mZ, TR_0_12_12),
                    new Generator(ROT_Z_X_Y, TR_12_12_0),
                    new Generator(ROT_Z_mX_mY, TR_0_12_12),
                    new Generator(ROT_mZ_mX_Y, TR_12_0_12),
                    new Generator(ROT_mZ_X_mY, TR_0_0_0),
                    new Generator(ROT_Y_Z_X, TR_12_12_0),
                    new Generator(ROT_mY_Z_mX, TR_0_0_0),
                    new Generator(ROT_Y_mZ_mX, TR_0_12_12),
                    new Generator(ROT_mY_mZ_X, TR_12_0_12),
                    new Generator(ROT_Y_X_mZ, TR_14_34_34),
                    new Generator(ROT_mY_mX_mZ, TR_34_34_14),
                    new Generator(ROT_Y_mX_Z, TR_34_14_34),
                    new Generator(ROT_mY_X_Z, TR_14_14_14),
                    new Generator(ROT_X_Z_mY, TR_14_34_34),
                    new Generator(ROT_mX_Z_Y, TR_14_14_14),
                    new Generator(ROT_mX_mZ_mY, TR_34_34_14),
                    new Generator(ROT_X_mZ_Y, TR_34_14_34),
                    new Generator(ROT_Z_Y_mX, TR_14_34_34),
                    new Generator(ROT_Z_mY_X, TR_34_14_34),
                    new Generator(ROT_mZ_Y_X, TR_14_14_14),
                    new Generator(ROT_mZ_mY_mX, TR_34_34_14),
                    new Generator(ROT_mX_mY_mZ, TR_14_14_34),
                    new Generator(ROT_X_Y_mZ, TR_14_34_14),
                    new Generator(ROT_X_mY_Z, TR_34_34_34),
                    new Generator(ROT_mX_Y_Z, TR_34_14_14),
                    new Generator(ROT_mZ_mX_mY, TR_14_14_34),
                    new Generator(ROT_mZ_X_Y, TR_34_14_14),
                    new Generator(ROT_Z_X_mY, TR_14_34_14),
                    new Generator(ROT_Z_mX_Y, TR_34_34_34),
                    new Generator(ROT_mY_mZ_mX, TR_14_14_34),
                    new Generator(ROT_Y_mZ_X, TR_34_34_34),
                    new Generator(ROT_mY_Z_X, TR_34_14_14),
                    new Generator(ROT_Y_Z_mX, TR_14_34_14),
                    new Generator(ROT_mY_mX_Z, TR_12_0_0),
                    new Generator(ROT_Y_X_Z, TR_0_0_12),
                    new Generator(ROT_mY_X_mZ, TR_0_12_0),
                    new Generator(ROT_Y_mX_mZ, TR_12_12_12),
                    new Generator(ROT_mX_mZ_Y, TR_12_0_0),
                    new Generator(ROT_X_mZ_mY, TR_12_12_12),
                    new Generator(ROT_X_Z_Y, TR_0_0_12),
                    new Generator(ROT_mX_Z_mY, TR_0_12_0),
                    new Generator(ROT_mZ_mY_X, TR_12_0_0),
                    new Generator(ROT_mZ_Y_mX, TR_0_12_0),
                    new Generator(ROT_Z_mY_mX, TR_12_12_12),
                    new Generator(ROT_Z_Y_X, TR_0_0_12) });

    /** Space group 229. */
    public static final SpaceGroup SG229 = new SpaceGroup(229, "Im-3m", CUBIC,
            LGm3m, new Generator[] { new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_0_0_0),
                    new Generator(ROT_mX_Y_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_mZ, TR_0_0_0),
                    new Generator(ROT_Z_X_Y, TR_0_0_0),
                    new Generator(ROT_Z_mX_mY, TR_0_0_0),
                    new Generator(ROT_mZ_mX_Y, TR_0_0_0),
                    new Generator(ROT_mZ_X_mY, TR_0_0_0),
                    new Generator(ROT_Y_Z_X, TR_0_0_0),
                    new Generator(ROT_mY_Z_mX, TR_0_0_0),
                    new Generator(ROT_Y_mZ_mX, TR_0_0_0),
                    new Generator(ROT_mY_mZ_X, TR_0_0_0),
                    new Generator(ROT_Y_X_mZ, TR_0_0_0),
                    new Generator(ROT_mY_mX_mZ, TR_0_0_0),
                    new Generator(ROT_Y_mX_Z, TR_0_0_0),
                    new Generator(ROT_mY_X_Z, TR_0_0_0),
                    new Generator(ROT_X_Z_mY, TR_0_0_0),
                    new Generator(ROT_mX_Z_Y, TR_0_0_0),
                    new Generator(ROT_mX_mZ_mY, TR_0_0_0),
                    new Generator(ROT_X_mZ_Y, TR_0_0_0),
                    new Generator(ROT_Z_Y_mX, TR_0_0_0),
                    new Generator(ROT_Z_mY_X, TR_0_0_0),
                    new Generator(ROT_mZ_Y_X, TR_0_0_0),
                    new Generator(ROT_mZ_mY_mX, TR_0_0_0),
                    new Generator(ROT_mX_mY_mZ, TR_0_0_0),
                    new Generator(ROT_X_Y_mZ, TR_0_0_0),
                    new Generator(ROT_X_mY_Z, TR_0_0_0),
                    new Generator(ROT_mX_Y_Z, TR_0_0_0),
                    new Generator(ROT_mZ_mX_mY, TR_0_0_0),
                    new Generator(ROT_mZ_X_Y, TR_0_0_0),
                    new Generator(ROT_Z_X_mY, TR_0_0_0),
                    new Generator(ROT_Z_mX_Y, TR_0_0_0),
                    new Generator(ROT_mY_mZ_mX, TR_0_0_0),
                    new Generator(ROT_Y_mZ_X, TR_0_0_0),
                    new Generator(ROT_mY_Z_X, TR_0_0_0),
                    new Generator(ROT_Y_Z_mX, TR_0_0_0),
                    new Generator(ROT_mY_mX_Z, TR_0_0_0),
                    new Generator(ROT_Y_X_Z, TR_0_0_0),
                    new Generator(ROT_mY_X_mZ, TR_0_0_0),
                    new Generator(ROT_Y_mX_mZ, TR_0_0_0),
                    new Generator(ROT_mX_mZ_Y, TR_0_0_0),
                    new Generator(ROT_X_mZ_mY, TR_0_0_0),
                    new Generator(ROT_X_Z_Y, TR_0_0_0),
                    new Generator(ROT_mX_Z_mY, TR_0_0_0),
                    new Generator(ROT_mZ_mY_X, TR_0_0_0),
                    new Generator(ROT_mZ_Y_mX, TR_0_0_0),
                    new Generator(ROT_Z_mY_mX, TR_0_0_0),
                    new Generator(ROT_Z_Y_X, TR_0_0_0),
                    new Generator(ROT_X_Y_Z, TR_12_12_12),
                    new Generator(ROT_mX_mY_Z, TR_12_12_12),
                    new Generator(ROT_mX_Y_mZ, TR_12_12_12),
                    new Generator(ROT_X_mY_mZ, TR_12_12_12),
                    new Generator(ROT_Z_X_Y, TR_12_12_12),
                    new Generator(ROT_Z_mX_mY, TR_12_12_12),
                    new Generator(ROT_mZ_mX_Y, TR_12_12_12),
                    new Generator(ROT_mZ_X_mY, TR_12_12_12),
                    new Generator(ROT_Y_Z_X, TR_12_12_12),
                    new Generator(ROT_mY_Z_mX, TR_12_12_12),
                    new Generator(ROT_Y_mZ_mX, TR_12_12_12),
                    new Generator(ROT_mY_mZ_X, TR_12_12_12),
                    new Generator(ROT_Y_X_mZ, TR_12_12_12),
                    new Generator(ROT_mY_mX_mZ, TR_12_12_12),
                    new Generator(ROT_Y_mX_Z, TR_12_12_12),
                    new Generator(ROT_mY_X_Z, TR_12_12_12),
                    new Generator(ROT_X_Z_mY, TR_12_12_12),
                    new Generator(ROT_mX_Z_Y, TR_12_12_12),
                    new Generator(ROT_mX_mZ_mY, TR_12_12_12),
                    new Generator(ROT_X_mZ_Y, TR_12_12_12),
                    new Generator(ROT_Z_Y_mX, TR_12_12_12),
                    new Generator(ROT_Z_mY_X, TR_12_12_12),
                    new Generator(ROT_mZ_Y_X, TR_12_12_12),
                    new Generator(ROT_mZ_mY_mX, TR_12_12_12),
                    new Generator(ROT_mX_mY_mZ, TR_12_12_12),
                    new Generator(ROT_X_Y_mZ, TR_12_12_12),
                    new Generator(ROT_X_mY_Z, TR_12_12_12),
                    new Generator(ROT_mX_Y_Z, TR_12_12_12),
                    new Generator(ROT_mZ_mX_mY, TR_12_12_12),
                    new Generator(ROT_mZ_X_Y, TR_12_12_12),
                    new Generator(ROT_Z_X_mY, TR_12_12_12),
                    new Generator(ROT_Z_mX_Y, TR_12_12_12),
                    new Generator(ROT_mY_mZ_mX, TR_12_12_12),
                    new Generator(ROT_Y_mZ_X, TR_12_12_12),
                    new Generator(ROT_mY_Z_X, TR_12_12_12),
                    new Generator(ROT_Y_Z_mX, TR_12_12_12),
                    new Generator(ROT_mY_mX_Z, TR_12_12_12),
                    new Generator(ROT_Y_X_Z, TR_12_12_12),
                    new Generator(ROT_mY_X_mZ, TR_12_12_12),
                    new Generator(ROT_Y_mX_mZ, TR_12_12_12),
                    new Generator(ROT_mX_mZ_Y, TR_12_12_12),
                    new Generator(ROT_X_mZ_mY, TR_12_12_12),
                    new Generator(ROT_X_Z_Y, TR_12_12_12),
                    new Generator(ROT_mX_Z_mY, TR_12_12_12),
                    new Generator(ROT_mZ_mY_X, TR_12_12_12),
                    new Generator(ROT_mZ_Y_mX, TR_12_12_12),
                    new Generator(ROT_Z_mY_mX, TR_12_12_12),
                    new Generator(ROT_Z_Y_X, TR_12_12_12) });

    /** Space group 230. */
    public static final SpaceGroup SG230 = new SpaceGroup(230, "Ia-3d", CUBIC,
            LGm3m, new Generator[] { new Generator(ROT_X_Y_Z, TR_0_0_0),
                    new Generator(ROT_mX_mY_Z, TR_12_0_12),
                    new Generator(ROT_mX_Y_mZ, TR_0_12_12),
                    new Generator(ROT_X_mY_mZ, TR_12_12_0),
                    new Generator(ROT_Z_X_Y, TR_0_0_0),
                    new Generator(ROT_Z_mX_mY, TR_12_12_0),
                    new Generator(ROT_mZ_mX_Y, TR_12_0_12),
                    new Generator(ROT_mZ_X_mY, TR_0_12_12),
                    new Generator(ROT_Y_Z_X, TR_0_0_0),
                    new Generator(ROT_mY_Z_mX, TR_0_12_12),
                    new Generator(ROT_Y_mZ_mX, TR_12_12_0),
                    new Generator(ROT_mY_mZ_X, TR_12_0_12),
                    new Generator(ROT_Y_X_mZ, TR_34_14_14),
                    new Generator(ROT_mY_mX_mZ, TR_34_34_34),
                    new Generator(ROT_Y_mX_Z, TR_14_14_34),
                    new Generator(ROT_mY_X_Z, TR_14_34_14),
                    new Generator(ROT_X_Z_mY, TR_34_14_14),
                    new Generator(ROT_mX_Z_Y, TR_14_34_14),
                    new Generator(ROT_mX_mZ_mY, TR_34_34_34),
                    new Generator(ROT_X_mZ_Y, TR_14_14_34),
                    new Generator(ROT_Z_Y_mX, TR_34_14_14),
                    new Generator(ROT_Z_mY_X, TR_14_14_34),
                    new Generator(ROT_mZ_Y_X, TR_14_34_14),
                    new Generator(ROT_mZ_mY_mX, TR_34_34_34),
                    new Generator(ROT_mX_mY_mZ, TR_0_0_0),
                    new Generator(ROT_X_Y_mZ, TR_12_0_12),
                    new Generator(ROT_X_mY_Z, TR_0_12_12),
                    new Generator(ROT_mX_Y_Z, TR_12_12_0),
                    new Generator(ROT_mZ_mX_mY, TR_0_0_0),
                    new Generator(ROT_mZ_X_Y, TR_12_12_0),
                    new Generator(ROT_Z_X_mY, TR_12_0_12),
                    new Generator(ROT_Z_mX_Y, TR_0_12_12),
                    new Generator(ROT_mY_mZ_mX, TR_0_0_0),
                    new Generator(ROT_Y_mZ_X, TR_0_12_12),
                    new Generator(ROT_mY_Z_X, TR_12_12_0),
                    new Generator(ROT_Y_Z_mX, TR_12_0_12),
                    new Generator(ROT_mY_mX_Z, TR_14_34_34),
                    new Generator(ROT_Y_X_Z, TR_14_14_14),
                    new Generator(ROT_mY_X_mZ, TR_34_34_14),
                    new Generator(ROT_Y_mX_mZ, TR_34_14_34),
                    new Generator(ROT_mX_mZ_Y, TR_14_34_34),
                    new Generator(ROT_X_mZ_mY, TR_34_14_34),
                    new Generator(ROT_X_Z_Y, TR_14_14_14),
                    new Generator(ROT_mX_Z_mY, TR_34_34_14),
                    new Generator(ROT_mZ_mY_X, TR_14_34_34),
                    new Generator(ROT_mZ_Y_mX, TR_34_34_14),
                    new Generator(ROT_Z_mY_mX, TR_34_14_34),
                    new Generator(ROT_Z_Y_X, TR_14_14_14),
                    new Generator(ROT_X_Y_Z, TR_12_12_12),
                    new Generator(ROT_mX_mY_Z, TR_0_12_0),
                    new Generator(ROT_mX_Y_mZ, TR_12_0_0),
                    new Generator(ROT_X_mY_mZ, TR_0_0_12),
                    new Generator(ROT_Z_X_Y, TR_12_12_12),
                    new Generator(ROT_Z_mX_mY, TR_0_0_12),
                    new Generator(ROT_mZ_mX_Y, TR_0_12_0),
                    new Generator(ROT_mZ_X_mY, TR_12_0_0),
                    new Generator(ROT_Y_Z_X, TR_12_12_12),
                    new Generator(ROT_mY_Z_mX, TR_12_0_0),
                    new Generator(ROT_Y_mZ_mX, TR_0_0_12),
                    new Generator(ROT_mY_mZ_X, TR_0_12_0),
                    new Generator(ROT_Y_X_mZ, TR_14_34_34),
                    new Generator(ROT_mY_mX_mZ, TR_14_14_14),
                    new Generator(ROT_Y_mX_Z, TR_34_34_14),
                    new Generator(ROT_mY_X_Z, TR_34_14_34),
                    new Generator(ROT_X_Z_mY, TR_14_34_34),
                    new Generator(ROT_mX_Z_Y, TR_34_14_34),
                    new Generator(ROT_mX_mZ_mY, TR_14_14_14),
                    new Generator(ROT_X_mZ_Y, TR_34_34_14),
                    new Generator(ROT_Z_Y_mX, TR_14_34_34),
                    new Generator(ROT_Z_mY_X, TR_34_34_14),
                    new Generator(ROT_mZ_Y_X, TR_34_14_34),
                    new Generator(ROT_mZ_mY_mX, TR_14_14_14),
                    new Generator(ROT_mX_mY_mZ, TR_12_12_12),
                    new Generator(ROT_X_Y_mZ, TR_0_12_0),
                    new Generator(ROT_X_mY_Z, TR_12_0_0),
                    new Generator(ROT_mX_Y_Z, TR_0_0_12),
                    new Generator(ROT_mZ_mX_mY, TR_12_12_12),
                    new Generator(ROT_mZ_X_Y, TR_0_0_12),
                    new Generator(ROT_Z_X_mY, TR_0_12_0),
                    new Generator(ROT_Z_mX_Y, TR_12_0_0),
                    new Generator(ROT_mY_mZ_mX, TR_12_12_12),
                    new Generator(ROT_Y_mZ_X, TR_12_0_0),
                    new Generator(ROT_mY_Z_X, TR_0_0_12),
                    new Generator(ROT_Y_Z_mX, TR_0_12_0),
                    new Generator(ROT_mY_mX_Z, TR_34_14_14),
                    new Generator(ROT_Y_X_Z, TR_34_34_34),
                    new Generator(ROT_mY_X_mZ, TR_14_14_34),
                    new Generator(ROT_Y_mX_mZ, TR_14_34_14),
                    new Generator(ROT_mX_mZ_Y, TR_34_14_14),
                    new Generator(ROT_X_mZ_mY, TR_14_34_14),
                    new Generator(ROT_X_Z_Y, TR_34_34_34),
                    new Generator(ROT_mX_Z_mY, TR_14_14_34),
                    new Generator(ROT_mZ_mY_X, TR_34_14_14),
                    new Generator(ROT_mZ_Y_mX, TR_14_14_34),
                    new Generator(ROT_Z_mY_mX, TR_14_34_14),
                    new Generator(ROT_Z_Y_X, TR_34_34_34) });



    /**
     * Initialises the crystal systems lookup table.
     */
    public void initCrystalSystems();



    /**
     * Initialises the indexes lookup table.
     */
    public void initIndexes();



    /**
     * Initialises the Laue group lookup table.
     */
    public void initLaueGroups();



    /**
     * Initialises the symbols lookup table.
     */
    public void initSymbols();
}
